@@ -162,11 +162,9 @@ int main(int argc, char **argv)
     } else if(strncasecmp(cptr, "k2max=", 6)==0) {
       if(atofCheck(cptr+6, &k2max)==0 && k2max>=0.0) continue;
     } else if(strncasecmp(cptr, "fmin=", 5)==0) {
-      if(atofCheck(cptr+5, &flowMin)==0 && flowMin>=0.0) {
-        flowMin*=0.01; continue;}
+      if(atofCheck(cptr+5, &flowMin)==0 && flowMin>=0.0) {flowMin*=0.01; continue;}
     } else if(strncasecmp(cptr, "fmax=", 5)==0) {
-      if(atofCheck(cptr+5, &flowMax)==0 && flowMax>=0.0) {
-        flowMax*=0.01; continue;}
+      if(atofCheck(cptr+5, &flowMax)==0 && flowMax>=0.0) {flowMax*=0.01; continue;}
     } else if(strncasecmp(cptr, "pmin=", 5)==0) {
       if(atofCheck(cptr+5, &pWaterMin)==0 && pWaterMin>0.0) continue;
     } else if(strncasecmp(cptr, "pmax=", 5)==0) {
@@ -234,12 +232,12 @@ int main(int argc, char **argv)
   if(flowMin>=flowMax) {
     fprintf(stderr, "Error: invalid range for perfusion (%g - %g).\n",
     100.*flowMin, 100.*flowMax);
-    return(1);    
+    return(1);
   }
   if(pWaterMin>=pWaterMax) {
     fprintf(stderr, "Error: invalid range for p (%g - %g).\n",
     pWaterMin, pWaterMax);
-    return(1);    
+    return(1);
   }
   if(isnan(k2min)) {
     k2min=flowMin/pWaterMax;
@@ -251,7 +249,7 @@ int main(int argc, char **argv)
   }
   if(k2max<=k2min || k2min<=0.) {
     fprintf(stderr, "Error: invalid range for k2 (%g - %g).\n", k2min, k2max);
-    return(1);    
+    return(1);
   }
   /* Convert k2 from 1/min to 1/sec */
   k2min/=60.; k2max/=60.0;
@@ -323,10 +321,9 @@ int main(int argc, char **argv)
    */
   if(verbose>1) printf("calculating basis functions\n");
   TAC bf; tacInit(&bf);
-  ret=bfmRadiowater(&btac, &ttac, bfNr, k2min, k2max, &bf, &status);
+  ret=bfm1TCM(&btac, &ttac, bfNr, k2min, k2max, 0, &bf, &status);
   if(ret!=TPCERROR_OK) {
-    if(verbose>1) 
-      fprintf(stderr, "Error: cannot calculate basis functions.\n");
+    if(verbose>1) fprintf(stderr, "Error: cannot calculate basis functions.\n");
     fprintf(stderr, "Error: %s\n", errorMsg(status.error));
     tacFree(&ttac); tacFree(&btac); tacFree(&tbtac); return(3);
   }
@@ -450,12 +447,10 @@ int main(int argc, char **argv)
    */
   if(verbose>1) printf("BFM fitting to TACs.\n");
   double r2_min;
-  //, f, wss;
   int bi, bi_min;
   for(int i=0; i<ttac.tacNr; i++) {
 
-    if(verbose>1 && ttac.tacNr>1) 
-      printf("Region %d %s\n", i+1, ttac.c[i].name);
+    if(verbose>1 && ttac.tacNr>1) printf("Region %d %s\n", i+1, ttac.c[i].name);
 
     /* Go through all basis functions */
     bi_min=-1; r2_min=nan("");
@@ -494,8 +489,7 @@ int main(int argc, char **argv)
         r2_min=r2; bi_min=bi;
       }
     } /* next basis function */
-    if(verbose>2)
-      printf("Min basis function nr %d with R2=%g\n", bi_min+1, r2_min);
+    if(verbose>2) printf("Min basis function nr %d with R2=%g\n", bi_min+1, r2_min);
 
     /* Compute the best BF again to retrieve the solution */
     bi=bi_min;
@@ -536,12 +530,10 @@ int main(int argc, char **argv)
     k2=bf.c[bi_min].size; //printf("k2=%g\n", k2);
     if(isnan(fVaFixed)) Va=sol[1]; else Va=fVaFixed; //printf("Va=%g\n", Va);
     if(pWaterTrue>0) {
-      /* True p for radiowater is given, therefore lets calculate flow
-         from k2 */
+      /* True p for radiowater is given, therefore lets calculate flow from k2 */
       Flow=k2*pWaterTrue;
     } else {
-      /* True p for radiowater is not given, therefore lets assume
-         that flow=K1 */
+      /* True p for radiowater is not given, therefore lets assume that flow=K1 */
       Flow=sol[0]/(1.0-Va);
     }
     // printf("Flow=%g\n", Flow);
@@ -564,8 +556,7 @@ int main(int argc, char **argv)
   /*
    *  Print results on screen
    */
-  if(verbose>0 && par.tacNr<50) 
-    parWrite(&par, stdout, PAR_FORMAT_RES, 0, &status);
+  if(verbose>0 && par.tacNr<50) parWrite(&par, stdout, PAR_FORMAT_RES, 0, &status);
 
   /*
    *  Save results
@@ -608,8 +599,7 @@ int main(int argc, char **argv)
     i=iftFindKey(&ttac.h, "studynr", 0);
     if(i<0) i=iftFindKey(&ttac.h, "study_number", 0);
     if(i>0) {strcat(buf, ": "); strcat(buf, ttac.h.item[i].value);}
-    ret=tacPlotFitSVG(&ttac, &ftac, buf, 0.0, nan(""), 0.0, nan(""),
-                      svgfile, &status);
+    ret=tacPlotFitSVG(&ttac, &ftac, buf, 0.0, nan(""), 0.0, nan(""), svgfile, &status);
     if(ret!=TPCERROR_OK) {
       fprintf(stderr, "Error: %s\n", errorMsg(status.error));
       tacFree(&ttac); tacFree(&btac); tacFree(&tbtac); tacFree(&bf);
