@@ -526,15 +526,15 @@ int main(int argc, char **argv)
      simulated tissue TAC (at input sample times) */
   simdc=btac.voi[sim_index].y3;
   for(int fi=0; fi<btac.frameNr; fi++)
-    simdc[fi]=lambda2factor(-lambda, btac.x[fi], -1.0);
+    simdc[fi]=hlLambda2factor(-lambda, btac.x[fi], -1.0);
   /* Calculate decay correction factors for making decay correction for
      simulated tissue TAC (at PET sample times) */
   petdc=ttac.voi[simpet_index].y;
   for(int fi=0; fi<ttac.frameNr; fi++) {
     if(ttac.timetype==DFT_TIME_STARTEND)
-      petdc[fi]=lambda2factor(lambda, ttac.x1[fi], ttac.x2[fi]-ttac.x1[fi]);
+      petdc[fi]=hlLambda2factor(lambda, ttac.x1[fi], ttac.x2[fi]-ttac.x1[fi]);
     else
-      petdc[fi]=lambda2factor(lambda, ttac.x[fi], -1.0);
+      petdc[fi]=hlLambda2factor(lambda, ttac.x[fi], -1.0);
   }
   /* One region at a time */
   if(verbose>0) {
