@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_fit_h2o
-#: Date       : 2018-02-18
+#: Date       : 2022-03-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -1046,7 +1046,7 @@ printf " Test case: Datafile contains weights.\n"
 printf " Expected result: correct weights are printed in test mode. \n\n"
 
 cp -f quick.tac temp.tac
-dftweigh -wf temp.tac
+tacweigh -wf temp.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
 rm -f stdout.txt
