@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_fit_srtm
-#: Date       : 2020-02-03
+#: Date       : 2022-03-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -73,42 +73,42 @@ fi
 if [ ! -f rpsim.tac ]; then
   simframe rpsim_full.tac frames1.dat rpsim.tac C-11
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-  dftweigh rpsim.tac
+  tacweigh -i=C-11 rpsim.tac
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 fi
 
 if [ ! -f rpsim_smallgap.tac ]; then
   simframe rpsim_full.tac frames1_smallgap.dat rpsim_smallgap.tac C-11
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-  dftweigh rpsim_smallgap.tac
+  tacweigh -i=C-11 rpsim_smallgap.tac
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 fi
 
 if [ ! -f rpsim_biggap.tac ]; then
   simframe rpsim_full.tac frames1_biggap.dat rpsim_biggap.tac C-11
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-  dftweigh rpsim_biggap.tac
+  tacweigh -i=C-11 rpsim_biggap.tac
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 fi
 
 if [ ! -f rpsim_smalloverlap.tac ]; then
   simframe rpsim_full.tac frames1_smalloverlap.dat rpsim_smalloverlap.tac C-11
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-  dftweigh rpsim_smalloverlap.tac
+  tacweigh -i=C-11 rpsim_smalloverlap.tac
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 fi
 
 if [ ! -f rpsim_bigoverlap.tac ]; then
   simframe rpsim_full.tac frames1_bigoverlap.dat rpsim_bigoverlap.tac C-11
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-  dftweigh rpsim_bigoverlap.tac
+  tacweigh -i=C-11 rpsim_bigoverlap.tac
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 fi
 
 if [ ! -f rpsim_fewframes.tac ]; then
   simframe rpsim_full.tac frames1_few.dat rpsim_fewframes.tac C-11
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-  dftweigh rpsim_fewframes.tac
+  tacweigh -i=C-11 rpsim_fewframes.tac
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 fi
 
@@ -140,7 +140,7 @@ if [ ! -f basicsim.tac ]; then
   rm -f basicsim.tac basicsim.dat
   simframe basicsim_full.tac frames2.dat basicsim.tac C-11
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-  dftweigh basicsim.tac
+  tacweigh -i=C-11 basicsim.tac
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 fi
 
@@ -204,7 +204,7 @@ printf "\n ok \n"
 resmatch -abs=0.05 -header=y -param=y -regions=y -res=2 correct_basic1.res fit_1_0_0.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-resmatch -abs=0.1 -header=y -param=y -regions=y -res=4 correct_basic1.res fit_1_0_0.res
+resmatch -roughly -header=y -param=y -regions=y -res=4 correct_basic1.res fit_1_0_0.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -299,7 +299,7 @@ printf "\n ok \n"
 resmatch -abs=0.3 -header=y -param=y -regions=y -res=2 correct_rpsim.res fit_1_2_0.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-resmatch -abs=0.02 -header=y -param=y -regions=y -res=4 correct_rpsim.res fit_1_2_0.res
+resmatch -roughly -header=y -param=y -regions=y -res=4 correct_rpsim.res fit_1_2_0.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -321,7 +321,10 @@ $PROGRAM -dvr basicsim.tac "refer lowk" 120 fit_1_3_0.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-resmatch -abs=0.1 -header=y -param=y -regions=y -res=1-4 correct_basicdvr.res fit_1_3_0.res
+resmatch -roughly -header=y -param=y -regions=y -res=1,4 correct_basicdvr.res fit_1_3_0.res
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+resmatch -abs=0.05 -header=y -param=y -regions=y -res=2,3 correct_basicdvr.res fit_1_3_0.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -412,7 +415,7 @@ printf "\n ok \n"
 resmatch -abs=0.05 -header=n -param=y -regions=y -res=2 test.res fit_2_0_0.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-resmatch -abs=0.1 -header=n -param=y -regions=y -res=4 test.res fit_2_0_0.res
+resmatch -roughly -header=n -param=y -regions=y -res=4 test.res fit_2_0_0.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -458,7 +461,10 @@ iftisval stdout.txt "Warning" "several reference regions found: refer lowk selec
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-resmatch -abs=0.2 -header=y -param=y -regions=y correct_basic1.res fit_2_1_0.res
+resmatch -abs=0.2 -header=y -param=y -regions=y -res=1-3 correct_basic1.res fit_2_1_0.res
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+resmatch -roughly -header=y -param=y -regions=y -res=4 correct_basic1.res fit_2_1_0.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -516,7 +522,10 @@ iftisval stdout.txt "Warning"
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-resmatch -abs=0.2 -header=y -param=y -regions=y correct_basic1.res fit_2_2_0.res
+resmatch -abs=0.05 -header=y -param=y -regions=y -res=2,3 correct_basic1.res fit_2_2_0.res
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+resmatch -roughly -header=y -param=y -regions=y -res=1,4 correct_basic1.res fit_2_2_0.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -580,7 +589,10 @@ iftisval fit_3_0_0.res "Reference region" "refer lowk"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-resmatch -abs=0.2 -header=n -param=y -regions=y -res=1-4 correct_basic1.res fit_3_0_0.res
+resmatch -roughly -header=n -param=y -regions=y -res=1,4 correct_basic1.res fit_3_0_0.res
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+resmatch -abs=0.05 -header=n -param=y -regions=y -res=2,3 correct_basic1.res fit_3_0_0.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -595,7 +607,10 @@ $PROGRAM basicsim.dat 2 120 fit_3_1_0.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-resmatch -abs=0.2 -header=n -param=y -regions=n -res=1-4 correct_basic2.res fit_3_1_0.res
+resmatch -abs=0.05 -header=n -param=y -regions=n -res=2,3 correct_basic2.res fit_3_1_0.res
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+resmatch -roughly -header=n -param=y -regions=n -res=1,4 correct_basic2.res fit_3_1_0.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -614,7 +629,10 @@ $PROGRAM test.tac 2 120 fit_3_2_0.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-resmatch -abs=0.2 -header=n -param=y -regions=n -res=1-4 correct_basic2.res fit_3_2_0.res
+resmatch -abs=0.05 -header=n -param=y -regions=n -res=2,3 correct_basic2.res fit_3_2_0.res
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+resmatch -roughly -header=n -param=y -regions=n -res=1,4 correct_basic2.res fit_3_2_0.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -1169,7 +1187,7 @@ printf " Expected result: correct weights are printed in test mode. \n\n"
 
 rm -f stdout.txt
 cp -f rpsim_fewframes.tac test.tac
-dftweigh -rm test.tac
+tacweigh -rm test.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -1188,7 +1206,7 @@ printf "\n 7.0.1 \n"
 printf " Test case: Datafile contains weights.\n"
 printf " Expected result: correct weights are printed in test mode. \n\n"
 
-dftweigh -wf test.tac
+tacweigh -wf test.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -1222,7 +1240,7 @@ printf "\n 7.0.3 \n"
 printf " Test case: Datafile contains weights but set based on frame lengths optionally.\n"
 printf " Expected result: correct weights are printed in test mode. \n\n"
 
-dftweigh test.tac
+tacweigh -i=C-11 test.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -1241,7 +1259,7 @@ printf "\n 7.0.4 \n"
 printf " Test case: Datafile does not contain weights but set based on frame lengths optionally.\n"
 printf " Expected result: correct weights are printed in test mode. \n\n"
 
-dftweigh -rm test.tac
+tacweigh -rm test.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
