@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_fitk3
-#: Date       : 2019-08-26
+#: Date       : 2022-03-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -774,7 +774,7 @@ printf " Test case: Datafile contains weights.\n"
 printf " Expected result: correct weights are printed in test mode. \n\n"
 
 cp -f k3reg3_long.dft temp.tac
-dftweigh -wf temp.tac
+tacweigh -wf temp.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
 rm -f stdout.txt
