@@ -263,6 +263,8 @@ int main(int argc, char **argv)
     return(2);
   }
   fittime*=60.;
+  if(imgNaNs(&img, 1)>0)
+    if(verbose>0) fprintf(stderr, "Warning: missing pixel values.\n");
   /* Half-life ok? */
   if(img.isotopeHalflife<1.0) {
     fprintf(stderr, "Error: image does not contain isotope halflife.\n");
