@@ -176,8 +176,7 @@ int main(int argc, char **argv)
       per_gram=1; continue; /* if plain -density, then use default density */
     } else if(strncasecmp(cptr, "DENSITY=", 8)==0) {
       per_gram=1; density=atof_dpi(cptr+8); if(density>0.0) continue;
-    } else if(strncasecmp(cptr, "VA=", 3)==0 ||
-              strncasecmp(cptr, "VB=", 3)==0) {
+    } else if(strncasecmp(cptr, "VA=", 3)==0 || strncasecmp(cptr, "VB=", 3)==0) {
       strlcpy(vafile, cptr+3, FILENAME_MAX); if(strlen(vafile)) continue;
     } else if(strncasecmp(cptr, "k2min=", 6)==0) {
       if(atof_with_check(cptr+6, &k2min)==0 && k2min>=0.0) continue;
@@ -310,6 +309,8 @@ int main(int argc, char **argv)
     if(verbose>1) printf("  ret := %d\n", ret);
     return(2);
   }
+  if(imgNaNs(&img, 1)>0)
+    if(verbose>0) fprintf(stderr, "Warning: missing pixel values.\n");
   //printf("last x2 = %g\n", tac.x2[tac.frameNr-1]);
   /* Set time unit to min */
   dftTimeunitConversion(&blood, TUNIT_MIN);
