@@ -290,6 +290,8 @@ int main(int argc, char **argv)
     return(2);
   }
   int origDataNr=tac.frameNr;
+  if(imgNaNs(&img, 1)>0)
+    if(verbose>0) fprintf(stderr, "Warning: missing pixel values.\n");
   /* Set time unit to min, also for integrals in y2[] */
   if(tac.timeunit==TUNIT_SEC) {
     for(int fi=0; fi<tac.frameNr; fi++) tac.voi[0].y2[fi]/=60.0;
