@@ -47,12 +47,13 @@ static char *info[] = {
   "mL O2/(100g * min) and fit time is set to 300 s or less [3].",
   " ",
   "Arterial blood TAC must be corrected for decay and delay, with sample times",
-  "in seconds. Dynamic PET image must be corrected for decay. Fit time must",
-  "be given in seconds.",
+  "in seconds. Dynamic PET image must be corrected for decay.",
   " ",
-  "Usage: @P [Options] btacfile imgfile fittime flowfile",
+  "Usage: @P [Options] btacfile imgfile flowfile",
   " ",
   "Options:",
+  " -end=<Fit end time (sec)>",
+  "     Use data from 0 to end time; by default, all of it.",
   " -k2=<filename>",
   "     Parametric k2 image is saved; in some situations perfusion calculation",
   "     from k2 can be more accurate than the default assumption of f=K1.",
@@ -61,10 +62,10 @@ static char *info[] = {
   " -Va=<filename>",
   "     Parametric Va image is saved.",
   "     Set -Va=0, if Va=0 is assumed; otherwise Va is always fitted.",
-  " -Vd=<filename>",
-  "     Parametric K1/k2 image (apparent pH2O) is saved.",
-  " -wss=<filename>",
-  "     Weighted sum-of-squares are written in specified image file.",
+//  " -Vd=<filename>", // option to be removed
+//  "     Parametric K1/k2 image (apparent pH2O) is saved.",
+//  " -wss=<filename>", // option to be removed
+//  "     Weighted sum-of-squares are written in specified image file.",
   " -thr=<threshold%>",
   "     Pixels with AUC less than (threshold/100 x max AUC) are set to zero.",
   "     Default is 5%.",
@@ -91,11 +92,11 @@ static char *info[] = {
   " ",
   "Example 1. Calculation of perfusion and arterial blood volume image,",
   "           stopping fit at 180 s:",
-  "  @P -Va=s2345va.v s2345abfit.kbq s2345dy1.v 180 s2345flow.v",
+  "  @P -Va=s2345va.v -end=180 s2345abfit.kbq s2345dy1.v s2345flow.v",
   " ",
   "Example 2. Dynamic image is precorrected for vascular activity,",
   "           and all available data is used:",
-  "  @P -Va=0 s2345abfit.kbq s2345dy1_vacorr.v 9999 s2345flow.v",
+  "  @P -Va=0 s2345abfit.kbq s2345dy1_vacorr.v s2345flow.v",
   " ",
   "References:",
   "1. Blomqvist G. On the construction of functional maps in positron",
@@ -106,7 +107,7 @@ static char *info[] = {
   "   living human brain measured after a single inhalation of positron",
   "   emitting oxygen. J Cereb Blood Flow Metab. 1992;12:179-192.",
   " ",
-  "See also: imgbfh2o, imgcbv, fit_h2o, b2t_h2o, imglhdv, fitdelay, eabaort",
+  "See also: imgflowm, imgbfh2o, imgcbv, fit_h2o, b2t_h2o, imglhdv, fitdelay",
   " ",
   "Keywords: image, modelling, perfusion, blood flow, radiowater, NNLS",
   0};
@@ -139,7 +140,7 @@ int main(int argc, char *argv[])
   double  upperLimit=-1.0;
   int     per_gram=0;
   double  density=1.04;
-  double  fittime=0.0;
+  double  fittime=nan("");
   int     fitVa=1;
   int     k1_nn_constraint=0;
   int     per_dl=0;
@@ -209,14 +210,6 @@ int main(int argc, char *argv[])
   /* Process other arguments, starting from the first non-option */
   if(ai<argc) strlcpy(inpfile, argv[ai++], FILENAME_MAX);
   if(ai<argc) strlcpy(petfile, argv[ai++], FILENAME_MAX);
-  if(ai<argc) {
-    if(!atof_with_check(argv[ai], &fittime)) fittime/=60.0;
-    else {
-      fprintf(stderr, "Error: invalid fit time '%s'.\n", argv[ai]);
-      return(1);
-    }
-    ai++;
-  }
   if(ai<argc) strlcpy(k1file, argv[ai++], FILENAME_MAX);
   if(ai<argc) {fprintf(stderr, "Error: invalid argument '%s'.\n", argv[ai]); return(1);}
   /* Did we get all the information that we need? */
@@ -224,7 +217,7 @@ int main(int argc, char *argv[])
     fprintf(stderr, "Error: missing command-line argument; use option --help\n");
     return(1);
   }
-  if(fittime<=0.0) fittime=1.0E+020;
+  if(!(fittime>0.0)) fittime=1.0E+020;
   /* Check if Va=0 is assumed */
   if(strcasecmp(vafile, "NONE")==0 || strcasecmp(vafile, "ZERO")==0 || strcasecmp(vafile, "0")==0) 
     {vafile[0]=(char)0; fitVa=0;}
@@ -240,7 +233,7 @@ int main(int argc, char *argv[])
     if(wssfile[0]) printf("wssfile := %s\n", wssfile);
     printf("calcThreshold := %g\n", calcThreshold);
     printf("max := %f\n", upperLimit);
-    printf("fittime := %g [min]\n", fittime);
+    printf("fittime := %g [sec]\n", 60.0*fittime);
     printf("per_dl := %d\n", per_dl);
     printf("per_gram := %d\n", per_gram);
     printf("density := %g\n", density);
@@ -262,11 +255,13 @@ int main(int argc, char *argv[])
     if(verbose>1) printf("  ret := %d\n", ret);
     return(2);
   }
+  if(imgNaNs(&img, 1)>0)
+    if(verbose>0) fprintf(stderr, "Warning: missing pixel values.\n");
   /* Set time unit to min, also for integrals in y2[] */
   if(tac.timeunit==TUNIT_SEC) for(fi=0; fi<tac.frameNr; fi++) tac.voi[0].y2[fi]/=60.0;
   ret=dftTimeunitConversion(&tac, TUNIT_MIN);
   if(verbose>1) {
-    printf("fittimeFinal := %g min\n", fittime);
+    printf("fittimeFinal := %g s\n", 60.*fittime);
     printf("dataNr := %d\n", dataNr);
   }
   /* Check that image is dynamic */
@@ -388,7 +383,7 @@ int main(int argc, char *argv[])
 
         /* Initiate pixel output values */
         k1img.m[pi][yi][xi][0]=0.0;
-        if(k2file[0]) k1img.m[pi][yi][xi][0]=0.0;
+        if(k2file[0]) k2img.m[pi][yi][xi][0]=0.0;
         if(vafile[0]) vaimg.m[pi][yi][xi][0]=0.0;
         if(dvfile[0]) dvimg.m[pi][yi][xi][0]=0.0;
 
@@ -509,8 +504,7 @@ int main(int argc, char *argv[])
             }
           }
           /* NNLS */
-          ret=nnls(nnls_a, nnls_m, nnls_n, nnls_b, nnls_x, &nnls_rnorm,
-                   nnls_wp, nnls_zz, nnls_index);
+          ret=nnls(nnls_a, nnls_m, nnls_n, nnls_b, nnls_x, &nnls_rnorm, nnls_wp, nnls_zz, nnls_index);
           if(ret>1) continue; /* no solution is possible */
           dvimg.m[pi][yi][xi][0]=nnls_x[1];
           if(verbose>6 && pi==img.dimz/2 && yi==img.dimy/3 && xi==img.dimx/3) {
