@@ -240,6 +240,8 @@ int main(int argc, char **argv)
     if(verbose>1) printf("  ret := %d\n", ret);
     return(2);
   }
+  if(imgNaNs(&pet, 1)>0)
+    if(verbose>0) fprintf(stderr, "Warning: missing pixel values.\n");
   /* Set time unit to min, also for integrals in y2[] */
   if(tac.timeunit==TUNIT_SEC)
     for(fi=0; fi<tac.frameNr; fi++) tac.voi[0].y2[fi]/=60.0;
