@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_imgflow
-#: Date       : 2022-08-09
+#: Date       : 2023-03-26
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -25,7 +25,7 @@ if [ ! -f $PROGRAM ]; then
   exit 1
 fi
 
-if [ ! -f blood.dat ] || [ ! -f frames.dat ]; then
+if [ ! -f blood.dat ] || [ ! -f frames.sif ]; then
   printf "Failed: required data does not exist.\n"
   exit 1
 fi
@@ -36,7 +36,8 @@ if [ ! -f blood_delayed.dat ]; then
 fi
 
 
-if [ ! -f lowmid.v ] || [ ! -f correct_lowmid_flow.v ]; then
+if [ ! -f lowmid.v ] || [ ! -f correct_lowmid_flow.v ] ||
+   [ ! -f lowmid.nii ] || [ ! -f correct_lowmid_flow.nii ]; then
   printf "\n Simulate low-to-mid range flow image with Vb=3 \n"
   b2t_h2o --silent      -voiname="f1" blood.dat   1 0.8 1 3 100 temp.dft
   b2t_h2o --silent -add -voiname="f2" blood.dat   2 0.8 1 3 100 temp.dft
@@ -64,7 +65,7 @@ if [ ! -f lowmid.v ] || [ ! -f correct_lowmid_flow.v ]; then
   b2t_h2o --silent -add -voiname="f24" blood.dat  24 0.8 1 3 100 temp.dft
   b2t_h2o --silent -add -voiname="f25" blood.dat  25 0.8 1 3 100 temp.dft
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-  simframe --silent temp.dft frames.dat lowmid.dft
+  simframe --silent temp.dft frames.sif lowmid.dft
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
   tacstudy --silent -force lowmid.dft lowmid01 
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -73,6 +74,8 @@ if [ ! -f lowmid.v ] || [ ! -f correct_lowmid_flow.v ]; then
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
   imgdecay --silent -i=O-15 -dc lowmid.v
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+  ecat2nii -sif lowmid.v
+  if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
   printf "\n ok \n"
   printf "\n Make image with correct flow values \n"
   printf "180 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25\n" > temp.dft
@@ -84,11 +87,13 @@ if [ ! -f lowmid.v ] || [ ! -f correct_lowmid_flow.v ]; then
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
   e7emhdr correct_lowmid_flow.v data_units := "mL/(mL*min)"
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+  ecat2nii correct_lowmid_flow_dl.v correct_lowmid_flow.v
+  if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
   printf "\n ok \n"
 fi
 
 
-if [ ! -f lowmid_va0.v ]; then
+if [ ! -f lowmid_va0.v ] ||  [ ! -f lowmid_va0.nii ]; then
   printf "\n Simulate low-to-mid range flow image with Vb=0 \n"
   b2t_h2o --silent      -voiname="f1" blood.dat   1 0.8 1 0 100 temp.dft
   b2t_h2o --silent -add -voiname="f2" blood.dat   2 0.8 1 0 100 temp.dft
@@ -116,7 +121,7 @@ if [ ! -f lowmid_va0.v ]; then
   b2t_h2o --silent -add -voiname="f24" blood.dat  24 0.8 1 0 100 temp.dft
   b2t_h2o --silent -add -voiname="f25" blood.dat  25 0.8 1 0 100 temp.dft
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-  simframe --silent temp.dft frames.dat lowmid_va0.dft
+  simframe --silent temp.dft frames.sif lowmid_va0.dft
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
   tacstudy --silent -force lowmid_va0.dft lowmid02 
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -125,11 +130,14 @@ if [ ! -f lowmid_va0.v ]; then
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
   imgdecay --silent -i=O-15 -dc lowmid_va0.v
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+  ecat2nii -sif lowmid_va0.v
+  if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
   printf "\n ok \n"
 fi
 
 
-if [ ! -f midhigh.v ] || [ ! -f correct_midhigh_flow.v ]; then
+if [ ! -f midhigh.v ] || [ ! -f correct_midhigh_flow.v ] ||
+   [ ! -f midhigh.nii ] || [ ! -f correct_midhigh_flow.nii ]; then
   printf "\n Simulate mid-to-high range flow image with Vb=3 \n"
   b2t_h2o --silent      -voiname="f30" blood.dat   30 0.8 1 3 100 temp.dft
   b2t_h2o --silent -add -voiname="f40" blood.dat   40 0.8 1 3 100 temp.dft
@@ -157,7 +165,7 @@ if [ ! -f midhigh.v ] || [ ! -f correct_midhigh_flow.v ]; then
   b2t_h2o --silent -add -voiname="f350" blood.dat 350 0.8 1 3 100 temp.dft
   b2t_h2o --silent -add -voiname="f400" blood.dat 400 0.8 1 3 100 temp.dft
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-  simframe --silent temp.dft frames.dat midhigh.dft
+  simframe --silent temp.dft frames.sif midhigh.dft
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
   tacstudy --silent -force midhigh.dft midhigh01 
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -166,6 +174,8 @@ if [ ! -f midhigh.v ] || [ ! -f correct_midhigh_flow.v ]; then
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
   imgdecay --silent -i=O-15 -dc midhigh.v
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+  ecat2nii -sif midhigh.v
+  if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
   printf "\n ok \n"
   printf "\n Make image with correct flow values \n"
   printf "180 30 40 50 60 70 80 90 100 110 120 130 140 150 160 170 180 190 200 220 240 260 280 300 350 400\n" > temp.dft
@@ -177,11 +187,14 @@ if [ ! -f midhigh.v ] || [ ! -f correct_midhigh_flow.v ]; then
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
   e7emhdr correct_midhigh_flow.v data_units := "mL/(mL*min)"
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+  ecat2nii correct_midhigh_flow_dl.v correct_midhigh_flow.v
+  if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
   printf "\n ok \n"
 fi
 
 
-if [ ! -f correct_va3.v ] || [ ! -f correct_va3_dl.v ] || [ ! -f correct_va0.v ]; then
+if [ ! -f correct_va3.v ] || [ ! -f correct_va3_dl.v ] || [ ! -f correct_va0.v ] ||
+   [ ! -f correct_va3.nii ] || [ ! -f correct_va3_dl.nii ] || [ ! -f correct_va0.nii ]; then
   printf "\n Make image with correct Va values \n"
   printf "180 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3\n" > temp.dft
   printf "# timeunit := sec\n" >> temp.dft
@@ -198,24 +211,31 @@ if [ ! -f correct_va3.v ] || [ ! -f correct_va3_dl.v ] || [ ! -f correct_va0.v ]
   printf "# unit := mL/dL\n" >> temp.dft
   dft2img -Scanner=HRRT -Dim=50 -zoom=2.0 temp.dft correct_va0.v
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+  ecat2nii correct_va3_dl.v correct_va3.v correct_va0.v
+  if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 fi
 
-if [ ! -f correct_vd.v ]; then
+if [ ! -f correct_vd.v ] || [ ! -f correct_vd.nii ]; then
   printf "\n Make image with correct Vd values \n"
   printf "180 0.8 0.8 0.8 0.8 0.8 0.8 0.8 0.8 0.8 0.8 0.8 0.8 0.8 0.8 0.8 0.8 0.8 0.8 0.8 0.8 0.8 0.8 0.8 0.8 0.8\n" > temp.dft
   printf "# timeunit := sec\n" >> temp.dft
   printf "# unit := mL/mL\n" >> temp.dft
   dft2img -Scanner=HRRT -Dim=50 -zoom=2.0 temp.dft correct_vd.v
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+  ecat2nii correct_vd.v
+  if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
   printf "\n ok \n"
 fi
 
-if [ ! -f correct_lowmid_k2.v ] || [ ! -f correct_midhigh_k2.v ]; then
+if [ ! -f correct_lowmid_k2.v ] || [ ! -f correct_midhigh_k2.v ] || 
+   [ ! -f correct_lowmid_k2.nii ] || [ ! -f correct_midhigh_k2.nii ]; then
   printf "\n Make images with correct k2 values \n"
   imgcalc correct_lowmid_flow.v : correct_vd.v correct_lowmid_k2.v
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
   imgcalc correct_midhigh_flow.v : correct_vd.v correct_midhigh_k2.v
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+  ecat2nii correct_lowmid_k2.v correct_midhigh_k2.v
+  if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
   printf "\n ok \n"
 fi
 
@@ -233,7 +253,7 @@ printf " Expected result: Correct results calculated. \n\n"
 
 rm -f flow.v va.v k2.v vd.v
 
-$PROGRAM -thr=0 -va=va.v -k2=k2.v -vd=vd.v blood.dat lowmid.v 99999 flow.v
+$PROGRAM -thr=0 -va=va.v -k2=k2.v -vd=vd.v blood.dat lowmid.v flow.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 imgmatch -abs=0.0001 -rel=1 correct_lowmid_flow.v flow.v
@@ -259,7 +279,7 @@ printf " Expected result: Correct results calculated. \n\n"
 
 rm -f flow.v va.v k2.v vd.v
 
-$PROGRAM -thr=0 -va=va.v -k2=k2.v -vd=vd.v blood.dat midhigh.v 99999 flow.v
+$PROGRAM -thr=0 -va=va.v -k2=k2.v -vd=vd.v blood.dat midhigh.v flow.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 imgmatch -abs=0.01 -rel=1 correct_midhigh_flow.v flow.v
@@ -276,6 +296,50 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 
+printf "\n 1.0.2 \n"
+printf " Test case: The same as 1.0.0 and 1.0.1 but with NIfTI format. \n"
+printf " Expected result: Correct results calculated. \n\n"
+
+rm -f flow.nii va.nii k2.nii vd.nii
+
+$PROGRAM -thr=0 -va=va.nii -k2=k2.nii -vd=vd.nii blood.dat lowmid.nii flow.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+imgmatch -abs=0.0001 -rel=1 -frames=n correct_lowmid_flow.nii flow.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+imgmatch -abs=0.0001 -rel=1 -frames=n correct_va3.nii va.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+imgmatch -abs=0.001 -rel=5 -frames=n correct_vd.nii vd.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+imgmatch -abs=0.001 -rel=5 -frames=n correct_lowmid_k2.nii k2.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n\n"
+
+rm -f flow.nii va.nii k2.nii vd.nii
+
+$PROGRAM -thr=0 -va=va.nii -k2=k2.nii -vd=vd.nii blood.dat midhigh.nii flow.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+imgmatch -abs=0.01 -rel=1 -frames=n correct_midhigh_flow.nii flow.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+imgmatch -abs=0.0015 -rel=5 -frames=n correct_va3.nii va.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+imgmatch -abs=0.001 -rel=5 -frames=n correct_vd.nii vd.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+imgmatch -abs=0.001 -rel=5 -frames=n correct_midhigh_k2.nii k2.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n\n"
+
+
+
+
+
 printf "\n 1.1.0 \n"
 printf " Test case 1: Low-to-mid range flow with Va=0 in the data. \n"
 printf " Test case 2: Va not fixed to zero. \n"
@@ -285,7 +349,7 @@ printf " Expected result: Correct results calculated. \n\n"
 
 rm -f flow.v va.v k2.v vd.v
 
-$PROGRAM -thr=0 -va=va.v -k2=k2.v -vd=vd.v blood.dat lowmid_va0.v 99999 flow.v
+$PROGRAM -thr=0 -va=va.v -k2=k2.v -vd=vd.v blood.dat lowmid_va0.v flow.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 imgmatch -abs=0.0001 -rel=1 correct_lowmid_flow.v flow.v
@@ -311,7 +375,7 @@ printf " Expected result: Correct results calculated. \n\n"
 
 rm -f flow.v va.v k2.v vd.v
 
-$PROGRAM -thr=0 -va=0 -k2=k2.v -vd=vd.v blood.dat lowmid_va0.v 99999 flow.v
+$PROGRAM -thr=0 -va=0 -k2=k2.v -vd=vd.v blood.dat lowmid_va0.v flow.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 imgmatch -abs=0.0001 -rel=1 correct_lowmid_flow.v flow.v
@@ -326,6 +390,45 @@ printf "\n passed. \n\n"
 
 
 
+printf "\n 1.1.2 \n"
+printf " Test case: The same as 1.1.0 and 1.1.1 but with NIfTI format. \n"
+printf " Expected result: Correct results calculated. \n\n"
+
+rm -f flow.nii va.nii k2.nii vd.nii
+
+$PROGRAM -thr=0 -va=va.nii -k2=k2.nii -vd=vd.nii blood.dat lowmid_va0.nii flow.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+imgmatch -abs=0.0001 -rel=1 -frames=n correct_lowmid_flow.nii flow.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+imgmatch -abs=0.0002 -rel=1 -frames=n correct_va0.nii va.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+imgmatch -abs=0.001 -rel=5 -frames=n correct_vd.nii vd.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+imgmatch -abs=0.001 -rel=5 -frames=n correct_lowmid_k2.nii k2.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n\n"
+
+rm -f flow.nii va.nii k2.nii vd.nii
+
+$PROGRAM -thr=0 -va=0 -k2=k2.nii -vd=vd.nii blood.dat lowmid_va0.nii flow.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+imgmatch -abs=0.0001 -rel=1 -frames=n correct_lowmid_flow.nii flow.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+imgmatch -abs=0.001 -rel=5 -frames=n correct_vd.nii vd.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+imgmatch -abs=0.001 -rel=5 -frames=n correct_lowmid_k2.nii k2.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n\n"
+
+
+
 printf "\n===================================================================\n"
 
 
@@ -336,7 +439,7 @@ printf " Expected result: Correct results calculated. \n\n"
 
 rm -f flow.v va.v k2.v vd.v
 
-$PROGRAM -dL -thr=0 -va=va.v -k2=k2.v -vd=vd.v blood.dat lowmid.v 99999 flow.v
+$PROGRAM -dL -thr=0 -va=va.v -k2=k2.v -vd=vd.v blood.dat lowmid.v flow.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 imgmax -both --verbose flow.v
@@ -364,7 +467,7 @@ imgcalc correct_lowmid_flow_dl.v : 1.1 test.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM -dL -density=1.1 -thr=0 -va=va.v -k2=k2.v -vd=vd.v blood.dat lowmid.v 99999 flow.v
+$PROGRAM -dL -density=1.1 -thr=0 -va=va.v -k2=k2.v -vd=vd.v blood.dat lowmid.v flow.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 imgmax -both --verbose flow.v
@@ -390,7 +493,7 @@ printf " Expected result: Resulting flow values do not exceed specified max. \n\
 
 rm -f flow.v stdout.txt
 
-$PROGRAM -thr=0 -max=0.041 blood.dat lowmid.v 99999 flow.v
+$PROGRAM -thr=0 -max=0.041 blood.dat lowmid.v flow.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -408,7 +511,7 @@ printf " Expected result: Resulting flow values do not exceed specified max. \n\
 
 rm -f flow.v stdout.txt
 
-$PROGRAM -thr=0 -dL -max=4.1 blood.dat lowmid.v 99999 flow.v
+$PROGRAM -thr=0 -dL -max=4.1 blood.dat lowmid.v flow.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -430,7 +533,7 @@ taccut blood.dat 0 340 test.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 rm -f flow.v
 
-$PROGRAM -thr=0 test.dat lowmid.v 360 flow.v
+$PROGRAM -thr=0 -end=360 test.dat lowmid.v flow.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 imgmax -both --verbose flow.v
@@ -447,7 +550,7 @@ taccut blood.dat 0 240 test.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 rm -f flow.v stdout.txt
 
-$PROGRAM -thr=0 test.dat lowmid.v 360 flow.v &> stdout.txt
+$PROGRAM -thr=0 -end=360 test.dat lowmid.v flow.v &> stdout.txt
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 iftlist stdout.txt error
 printf "\n passed. \n\n"
@@ -462,7 +565,7 @@ taccut blood.dat 0 240 test.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 rm -f flow.v stdout.txt output.ift
 
-$PROGRAM -d2 -thr=0 test.dat midhigh.v 240 flow.v &> stdout.txt
+$PROGRAM -d2 -thr=0 -end=240 test.dat midhigh.v flow.v &> stdout.txt
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 imgmax -both --verbose flow.v
@@ -492,7 +595,7 @@ printf "\n ok \n"
 
 rm -f flow.v
 
-$PROGRAM -thr=0 blood.dat movement.v 300 flow.v
+$PROGRAM -thr=0 -end=300 blood.dat movement.v flow.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 imgmatch -abs=0.0002 -rel=2 -header=n -frames=n correct_midhigh_flow.v flow.v
@@ -511,7 +614,7 @@ tacunit -xconv=min test.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 rm -f flow.v stdout.txt
 
-$PROGRAM -d -thr=0 test.dat lowmid.v 9999 flow.v &> stdout.txt
+$PROGRAM -d -thr=0 test.dat lowmid.v flow.v &> stdout.txt
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 imgmatch -abs=0.0001 -rel=1 -header=n correct_lowmid_flow.v flow.v
@@ -519,6 +622,20 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 
+printf "\n 1.6.1 \n"
+printf " Test case: Same as 1.6.0 but with NIfTI format. \n"
+printf " Expected result: Correct results are saved. \n\n"
+
+rm -f flow.nii stdout.txt
+
+$PROGRAM -d -thr=0 test.dat lowmid.nii flow.nii &> stdout.txt
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+imgmatch -abs=0.0001 -rel=1 -header=n -frames=n correct_lowmid_flow.nii flow.nii
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n\n"
+
+
 printf "\n===================================================================\n"
 
 printf "\n 1.7.0 \n"
@@ -528,7 +645,7 @@ printf " Expected result 2: Delayed BTAC should lead to higher WSS. \n\n"
 
 rm -f flow.v wss1.v wss2.v dif.v dif.txt
 
-$PROGRAM -thr=0 -wss=wss1.v blood.dat lowmid.v 99999 flow.v
+$PROGRAM -thr=0 -wss=wss1.v blood.dat lowmid.v flow.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -536,7 +653,7 @@ img2tif -rb wss1.v wss1.tif
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-$PROGRAM -thr=0 -wss=wss2.v blood_delayed.dat lowmid.v 99999 flow.v
+$PROGRAM -thr=0 -wss=wss2.v blood_delayed.dat lowmid.v flow.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -563,7 +680,7 @@ printf " Test case: Invalid option. \n"
 printf " Expected result: Error. \n\n"
 
 rm -f stdout.txt
-$PROGRAM -stupidoption blood.dat lowmid.v 9999 flow.v &> stdout.txt
+$PROGRAM -stupidoption blood.dat lowmid.v flow.v &> stdout.txt
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -575,7 +692,7 @@ printf " Test case: Extra argument. \n"
 printf " Expected result: Error. \n\n"
 
 rm -f stdout.txt
-$PROGRAM blood.dat lowmid.v 9999 flow.v extra &> stdout.txt
+$PROGRAM blood.dat lowmid.v flow.v extra &> stdout.txt
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -587,7 +704,7 @@ printf " Test case: Missing argument. \n"
 printf " Expected result: Error. \n\n"
 
 rm -f stdout.txt
-$PROGRAM  lowmid.v 9999 flow.v &> stdout.txt
+$PROGRAM  lowmid.v flow.v &> stdout.txt
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
@@ -595,7 +712,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 rm -f stdout.txt
-$PROGRAM blood.dat  9999 flow.v &> stdout.txt
+$PROGRAM blood.dat  flow.v &> stdout.txt
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
@@ -603,7 +720,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 rm -f stdout.txt
-$PROGRAM blood.dat lowmid.v 9999  &> stdout.txt
+$PROGRAM blood.dat lowmid.v  &> stdout.txt
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "missing command-line argument; use option --help"
@@ -618,7 +735,7 @@ printf " Test case: Input file does not exist. \n"
 printf " Expected result: Error. \n\n"
 
 rm -f stdout.txt
-$PROGRAM nonexistingfile.bld lowmid.v 9999 flow.v &> stdout.txt
+$PROGRAM nonexistingfile.bld lowmid.v flow.v &> stdout.txt
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
@@ -626,7 +743,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 rm -f stdout.txt
-$PROGRAM blood.dat nonexistingfile.v 9999 flow.v &> stdout.txt
+$PROGRAM blood.dat nonexistingfile.v flow.v &> stdout.txt
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
