@@ -576,6 +576,8 @@ int main(int argc, char **argv)
     fprintf(stderr, "Error: image must be static (one frame).\n");
     imgEmpty(&img); return(2);
   }
+  if(imgNaNs(&img, 1)>0)
+    if(verbose>0) fprintf(stderr, "Warning: missing pixel values.\n");
 
 
   /*
