@@ -56,12 +56,14 @@ static char *info[] = {
   "    dCw(t)/dt = k1*Cb(t-delay) - (k1+k3)*Cw(t) + k4*Ct(t) ",
   "    dCt(t)/dt = k3*Cw(t) - k4*Ct(t)                       ",
   ", where Cb(t)=Co(t)+Cw(t)                                 ",
-  "Macroparameter k2=k1+k3 was used by Iida et al.",
+  "If k4 is assumed to zero, then:",
+  "    dCw(t)/dt = k1*Cb(t-delay) - (k1+k3)*Cw(t)",
   " ",
   "Total arterial blood curve Cb(t), and Cw(t) are required for the fitting.",
   "TAC files must be corrected for physical decay.",
-  "Cw(t) can be calculated from measured arterial plasma curve by multiplying",
-  "it with [O-15]H2O blood-to-plasma ratio, for example using program o2_p2w.",
+  "Cw(t) can be calculated from measured arterial plasma curve Ca(t), because",
+  "oxygen concentration in plasma is negligible, by multiplying it with",
+  "[O-15]H2O blood-to-plasma ratio, for example using program o2_p2w.",
   " ",
   "The estimated model parameters, or population averages, can then be used to",
   "calculate the [O-15]O2 and [O-15]H2O blood curves using program o2metab.",
