@@ -22,18 +22,20 @@
 /*****************************************************************************/
 
 /*****************************************************************************/
-#define MAX_FUNC_NR 5
+#define MAX_FUNC_NR 7
 #define MAX_METAB_NR 3 
-enum {MODEL_UNKNOWN, MODEL_PF, MODEL_HILL, MODEL_MPF, MODEL_MHILL};
+enum {MODEL_UNKNOWN, MODEL_PF, MODEL_HILL, MODEL_GCDF, MODEL_EP, MODEL_MPF, MODEL_MHILL};
 int model=MODEL_UNKNOWN;
-int func_par_nr[MAX_FUNC_NR]={0,5,5,5,5};
-int func_type[MAX_FUNC_NR]={0,863,846,MF_PF3M_PAR,MF_HILL3M_PAR};
+int func_par_nr[MAX_FUNC_NR]={0,5,5,5,6,5,5};
+int func_type[MAX_FUNC_NR]={0,MF_EMAYER_PAR,MF_EHILL_PAR,MF_PPFIGAM,MF_PF_MU,MF_PF3M_PAR,MF_HILL3M_PAR};
 double func_pf(int parNr, double *p, void*);
 double func_hill(int parNr, double *p, void*);
+double func_gcdf(int parNr, double *p, void*);
+double func_ep(int parNr, double *p, void*);
 double func_mpf(int parNr, double *p, void*);
 double func_mhill(int parNr, double *p, void*);
 double (*func_list[MAX_FUNC_NR])(int parNr, double *p, void*)=
-  {NULL,func_pf,func_hill,func_mpf,func_mhill};
+  {NULL,func_pf,func_hill,func_gcdf,func_ep,func_mpf,func_mhill};
 /*****************************************************************************/
 #define MAX_MINMEAS_NR 4
 enum {MINMEAS_UNKNOWN, MINMEAS_OLS, MINMEAS_LAD, MINMEAS_ODR};
@@ -54,7 +56,7 @@ static char *info[] = {
   "Usage: @P [Options] fractionfile [fitfile]",
   " ",
   "Options:",
-  " -model=<PF | HILL | MPF | MHILL>",
+  " -model=<PF | HILL | GCDF | EP | MPF | MHILL>",
   "     Select the function (see descriptions below); default is HILL.",
   "     Use MPF or MHILL to fit functions to 2-3 metabolite fraction curves",
   "     instead of parent fraction curve.",
@@ -76,7 +78,7 @@ static char *info[] = {
   "     Parent fraction at time zero is fixed to zero sample, if available.",
   " -a=<value>, -b=<value>, -c=<value>, ...",
   "     Specified parameter is fixed to given (population mean) value.",
-  "     Option -fix0 overrides option -d=<value> when possible.",
+  "     Option -fix0 overrides other options when possible.",
   " -WC",
   "     The last data column contains sample weights.",
   " -W1",
@@ -113,6 +115,12 @@ static char *info[] = {
   "  where 0<=A<=D, 1<=B, 0<C, 0<D<=1, 0<=E.",
   "  With options -d=1 -e=0 this is the traditional Hill type function (6)",
   "  f(x) = 1 - {(1-A)x^B}/(C+x^B)",
+  "  where C>0<=A<=D, 1<=B, 0<C, 0<D<=1, 0<=E.",
+  "GCDF - Inverted Gamma CDF (7)",
+  "  f(x) = A{1-B*gcdf(C(x-E),D)}, where 0<A<=1,0<=B<=1,C>0,D>0.",
+  "EP - Exponential/Power function based on Mu et al (8)",
+  "  f(x) = B*(C*exp(-D*(x-A)^3/(E+(x-A)^2)) + (1-C)*exp(-F*(x-A))), when x>A,",
+  "  f(x) = B                                                      , when x<=A ,",
   "MPF - Extended power function is fitted to 1-3 metabolite fractions.",
   "MHILL - Extended Hill type function is fitted to 1-3 metabolite fractions.",
   " ",
@@ -121,14 +129,16 @@ static char *info[] = {
   "   http://www.turkupetcentre.net/petanalysis/input_parent_fitting.html",
   "2. http://www.turkupetcentre.net/petanalysis/format_tpc_dft.html",
   "3. http://www.turkupetcentre.net/petanalysis/format_tpc_fit.html",
-  "4. Meyer PT, Bier D, Holschbach MH, Boy C, Olsson RA, Coenen HH, Zilles K,",
-  "   Bauer A. Quantification of cerebral A1 adenosine receptors in humans",
-  "   using [18F]CPFPX and PET. J Cereb Blood Flow Metab. 2004;24(3):323-333.",
-  "5. Watabe H, Channing MA, Der MG, Adams HR, Jagoda E, Herscovitch P,",
-  "   Eckelman WC, Carson RE. Kinetic analysis of the 5-HT2A ligand",
-  "   ([11C]MDL 100,907. J Cereb Blood Flow Metab 2000;20:899-909.",
-  "6. Wu S, Ogden RT, Mann JJ, Parsey RV. Optimal metabolite curve fitting for", 
-  "   kinetic modeling of 11C-WAY-100635. J Nucl Med 2007;48:926-931.",
+  "4. Meyer PT, et al. J Cereb Blood Flow Metab. 2004;24(3):323-333.",
+  "   https://doi.org/10.1097/01.wcb.0000110531.48786.9d",
+  "5. Watabe H, et al. J Cereb Blood Flow Metab 2000;20:899-909.",
+  "   https://doi.org/10.1097/00004647-200006000-00002",
+  "6. Wu S, et al. J Nucl Med 2007;48:926-931.",
+  "   https://doi.org/10.2967/jnumed.106.038075",
+  "7. Naganawa M, et al. J Cereb Blood Flow Metab. 2014;34:1818-1825.",
+  "   https://doi.org/10.1038/jcbfm.2014.150",
+  "8. Mu L et al. EJNMMI Res. 2020;10:114.",
+  "   https://doi.org/10.1186/s13550-020-00700-7",
   " ",
   "See also: fit2dat, metabcor, avgfract, fitedit, fit_fexp, fith2met, tac2svg",
   " ",
@@ -160,8 +170,8 @@ int main(int argc, char **argv)
   double     fixed_p[MAX_PARAMETERS]; // values <0 mean not fixed
   double     min_delay=-1.0;   // <0 not set
   int        fixed0=0; // fix fraction at time zero to measured value at time zero, if available
-  int        delay_par_index=0;
-  int        iscale_par_index=0;
+  int        delay_par_index=0; // Which parameter represents delay time
+  int        iscale_par_index=0; // Which parameter represents scale
   int        ffile_type=1; // Parameters are saved in 1=usual or 2=Hill#2
                            // format; fitting is still the same. 
   int        mdelay_joint=1; // 0=separated, 1=joint
@@ -200,6 +210,8 @@ int main(int argc, char **argv)
       if(strncasecmp(cptr, "PF", 1)==0) {model=MODEL_PF; continue;}
       if(strcasecmp(cptr, "HILL2")==0) {model=MODEL_HILL; ffile_type=2; continue;}
       if(strncasecmp(cptr, "HILL", 1)==0) {model=MODEL_HILL; continue;}
+      if(strncasecmp(cptr, "GCDF", 1)==0) {model=MODEL_GCDF; continue;}
+      if(strcasecmp(cptr, "EP")==0) {model=MODEL_EP; continue;}
       if(strncasecmp(cptr, "MPF", 3)==0) {model=MODEL_MPF; continue;}
       if(strncasecmp(cptr, "MHILL", 3)==0) {model=MODEL_MHILL; continue;}
       fprintf(stderr, "Error: invalid model selection.\n"); return(1);
@@ -288,13 +300,15 @@ int main(int argc, char **argv)
   type=func_type[model];
   if(model==MODEL_HILL && ffile_type==2) type=MF_EHILL2_PAR;
   parNr=func_par_nr[model];
-  delay_par_index=parNr-1; iscale_par_index=parNr-2;
+  delay_par_index=parNr-1;
+  if(model!=MODEL_GCDF) iscale_par_index=parNr-2;
+  if(model==MODEL_EP) {delay_par_index=0; iscale_par_index=1;}
   for(pi=0, n=0; pi<parNr; pi++) if(fixed_p[pi]>=0.0) n++;
   if((parNr-n)<1) {
     fprintf(stderr, "Error: too many parameters were fixed.\n");
     return(1);
   }
-  if(fixed_p[4]>=0.0 && mdelay_joint==0)
+  if(fixed_p[delay_par_index]>=0.0 && mdelay_joint==0)
     fprintf(stderr, "Warning: option -mdelay is not effective with option -e\n");
   if(!ffile[0]) strcpy(ffile, "stdout");
 
@@ -364,13 +378,14 @@ int main(int argc, char **argv)
   }
 
   /* Ignore extra columns, if parent fraction is fitted */
-  if(model==MODEL_PF || model==MODEL_HILL) {
+  if(model==MODEL_PF || model==MODEL_HILL || model==MODEL_GCDF || model==MODEL_EP) {
     if(dft.voiNr>1) {
       fprintf(stderr, "Warning: extra columns in %s are ignored.\n", dfile);
       dft.voiNr=1;
     }
   } else { /* Metabolite fraction(s) will be fitted */
     if(dft.voiNr==1) {
+      if(verbose>1) printf("calculating metabolite fractions\n");
       /* If no metabolite fractions were found, then add one */
       ret=dftAddmem(&dft, 1); if(ret!=0) {
         fprintf(stderr, "Error: cannot allocate memory for metabolite.\n");
@@ -509,6 +524,20 @@ int main(int argc, char **argv)
       pmin[2]=1.0e-06;  pmax[2]=1.0e+05;
       pmin[3]=1.0e-06;  pmax[3]=1.0e+00;
       break;
+    case MODEL_GCDF:
+      pmin[0]=0.0;      pmax[0]=1.0e+00;
+      pmin[1]=0.1;      pmax[1]=1.0e+00;
+      pmin[2]=1.0e-06;  pmax[2]=1.0e+01;
+      pmin[3]=1.0e-06;  pmax[3]=1.0e+02;
+      break;
+    case MODEL_EP:
+      pmin[0]=0.0;      pmax[0]=1.0; // delay
+      pmin[1]=0.1;      pmax[1]=1.0; // max
+      pmin[2]=0.001;    pmax[2]=1.0;
+      pmin[3]=0.001;    pmax[3]=1.0;
+      pmin[4]=1.0;      pmax[4]=1.0e+03;
+      pmin[5]=1.0e-06;  pmax[5]=0.2;
+      break;
   }
   /* Delay parameter limits; first the min */
   if(min_delay>=0) {
@@ -524,7 +553,7 @@ int main(int argc, char **argv)
     }
   }
   /* then the max delay */
-  if(model==MODEL_PF || model==MODEL_HILL || mdelay_joint==1) {
+  if(model==MODEL_PF || model==MODEL_HILL || model==MODEL_GCDF || model==MODEL_EP || mdelay_joint==1) {
     /* parent fraction is fitted, or if metabolite fraction(s) are fitted, then
        common delay time for all metabolites is assumed */ 
     if(fixed_p[iscale_par_index]==1.0) {
@@ -570,13 +599,13 @@ int main(int argc, char **argv)
     double y0=0.0; int n=0;
     for(int i=0; i<fitdataNr; i++) if(fabs(dft.x[i])<1.0E-08) {y0+=dft.voi[0].y[i]; n++;}
     if(n>1) y0/=(double)n;
-    if(!(y0>0.0) /*|| fixed_p[3]>0.0*/) {
+    if(!(y0>0.0)) {
       fprintf(stderr, "Warning: initial fraction is not fixed to sample zero.\n");
       fflush(stderr);
     } else {
       if(verbose>1) {printf("Note: initial fraction fixed to %g\n", y0); fflush(stdout);}
-      pmin[3]=pmax[3]=y0;
-      if(fixed_p[3]>0.0) {
+      pmin[iscale_par_index]=pmax[iscale_par_index]=y0;
+      if(fixed_p[iscale_par_index]>0.0) {
         fprintf(stderr, "Warning: non-effective option -d for initial fraction.\n");
         fflush(stderr);
       }
@@ -640,7 +669,7 @@ int main(int argc, char **argv)
   if(verbose>1) printf("fitting\n");
   TGO_LOCAL_INSIDE=1;
   TGO_LOCAL_OPT=0; // 0=Powell-Brent, 1=Bobyqa
-  TGO_SQUARED_TRANSF=1; 
+  TGO_SQUARED_TRANSF=1; //if(model==MODEL_GCDF) TGO_SQUARED_TRANSF=0;
   int neighNr=6, iterNr=1, sampleNr=800;
   if(model==MODEL_MPF || model==MODEL_PF) {
     TGO_LOCAL_INSIDE=1;
@@ -752,8 +781,7 @@ int main(int argc, char **argv)
     if(verbose>4) for(pi=0; pi<parNr; pi++)
       printf(" par[%d]:  %g  [%g, %g]\n", pi+1, fit.voi[ri].p[pi], pmin[pi], pmax[pi]);
   }
-  /* In case of metabolite fitting, convert fitted delay parameter differences
-     to actual delays */
+  /* In case of metabolite fitting, convert fitted delay parameter differences to actual delays */
   if(model==MODEL_MPF || model==MODEL_MHILL) {
     n=parNr/metabNr;
     ri=0;
@@ -766,8 +794,7 @@ int main(int argc, char **argv)
     for(pi=0; pi<fit.voi[0].parNr; pi++) fit.voi[ri].p[pi]=fit.voi[0].p[pi];
     fit.voi[ri].wss=fit.voi[0].wss;
   }
-  /* In case of Hill function when function format #2 is required
-     divide a with d */
+  /* In case of Hill function when function format #2 is required divide a with d */
   if(model==MODEL_HILL && ffile_type==2) {
     fit.voi[0].p[0]/=fit.voi[0].p[3];
   }
@@ -807,12 +834,7 @@ int main(int argc, char **argv)
       yfit[ri]=adft.voi[ri].y;
       ymeas[ri]=adft.voi[ri].y2;
     }
-/*  // This would be faster but its also good to use library function
-    int n;
-    n=fitdataNr; fitdataNr=adft.frameNr;
-    func_list[model](fit.voi[0].p); //func_mhill(fit.voi[0].p);
-    fitdataNr=n;
-*/
+    // use library function
     for(ri=0, ret=0; ri<adft.voiNr; ri++) {
       for(fi=0; fi<adft.frameNr; fi++) {
         ret=fitEval(&fit.voi[ri], adft.x[fi], &a); if(ret!=0) break;
@@ -937,6 +959,71 @@ double func_hill(int parNr, double *p, void *fdata)
   return(wss);
 }
 
+double func_gcdf(int parNr, double *p, void *fdata)
+{
+  int i;
+  double a, b, c, d, dt, v, wss;
+  double pa[MAX_PARAMETERS], penalty=1.0;
+
+  /* Check parameters against the constraints */
+  if(0) {
+    for(i=0; i<parNr; i++) printf(" p[%d]=%g", i, p[i]);
+    printf("\n");
+  }
+  modelCheckParameters(parNr, pmin, pmax, p, pa, &penalty);
+  if(fdata) {}
+  a=pa[0]; b=pa[1]; c=pa[2]; d=pa[3]; dt=pa[4];
+  /* Calculate the curve values and weighted SS */
+  for(i=0, wss=0.0; i<fitdataNr; i++) if(w[i]>0.0) {
+    if(x[i]<=dt)
+      yfit[0][i]=a;
+    else {
+      yfit[0][i]= a*(1.0-b*igam(d, c*(x[i]-dt)));
+    }
+    v=yfit[0][i]-ymeas[0][i];
+    if(min_meas==MINMEAS_LAD) v=fabs(v);
+    else v*=v;
+    wss+=w[i]*v;
+    //printf("    x=%g ymeas=%g yfit=%g v=%g wss=%g\n", x[i], ymeas[0][i], yfit[0][i], v, wss);
+  }
+  lastWSS=wss; wss*=penalty;
+  //printf("   objfunc(): lastWSS=%g WSS=%g\n", lastWSS, wss);
+  if(0) printf("%g %g %g %g %g -> %g\n", a, b, c, d, dt, wss);
+  return(wss);
+}
+
+double func_ep(int parNr, double *p, void *fdata) // Based on Mu et al 2020
+{
+  int i;
+  double a, b, c, d, dt, s, v, wss;
+  double pa[MAX_PARAMETERS], penalty=1.0;
+
+  /* Check parameters against the constraints */
+  if(0) {
+    for(i=0; i<parNr; i++) printf(" p[%d]=%g", i, p[i]);
+    printf("\n");
+  }
+  modelCheckParameters(parNr, pmin, pmax, p, pa, &penalty);
+  if(fdata) {}
+  dt=pa[0]; s=pa[1]; a=pa[2]; b=pa[3]; c=pa[4]; d=pa[5];
+  /* Calculate the curve values and weighted SS */
+  for(i=0, wss=0.0; i<fitdataNr; i++) if(w[i]>0.0) {
+    double xt=x[i]-dt;
+    if(xt<=0.0)
+      yfit[0][i]=s;
+    else {
+      yfit[0][i]= a*exp(-b*xt*xt*xt/(xt*xt+c)) + (1.0-a)*exp(-d*xt);
+      yfit[0][i]*=s;
+    }
+    v=yfit[0][i]-ymeas[0][i];
+    if(min_meas==MINMEAS_LAD) v=fabs(v);
+    else v*=v;
+    wss+=w[i]*v;
+  }
+  lastWSS=wss; wss*=penalty;
+  return(wss);
+}
+
 double func_mpf(int parNr, double *p, void *fdata)
 {
   int i, m, pn;
