@@ -2,7 +2,7 @@
  *  @brief estimation and correction of delay-time between PET tissue TACs and input plasma or blood TACs.
  *  @copyright (c) Turku PET Centre
  *  @author Vesa Oikonen
- *  @todo Option to give smaller delay time limits, especially to prevent negative delay in case of image derived input from heart.
+ *  @todo Option to set delay time limits.
  */
 /// @cond
 /*****************************************************************************/
@@ -60,6 +60,9 @@ static char *info[] = {
   " -L[og]",
   "     Time delay and other log information is written as comments in",
   "     the corrected TAC file, if format supports comments.",
+  " -matrix=<Filename>",
+  "     Filename for saving NNLS matrix in CSV format for testing purposes.",
+  "     With this option the tissue file must contain one TAC only.",
   " -stdoptions", // List standard options like --help, -v, etc
   " ",
   "As tissue data, the scanner countrate curve is recommended, unless scanned",
@@ -140,6 +143,7 @@ int main(int argc, char **argv)
   char p2file[FILENAME_MAX], p3file[FILENAME_MAX], p4file[FILENAME_MAX];
   char r2file[FILENAME_MAX], r3file[FILENAME_MAX], r4file[FILENAME_MAX];
   char ffile[FILENAME_MAX];
+  char matfile[FILENAME_MAX];
   DFT pdata, data, ipdata, fdata;
   /* nnls */
   int NNLS_N=5;
@@ -154,6 +158,7 @@ int main(int argc, char **argv)
   if(argc==1) {tpcPrintUsage(argv[0], info, stderr); return(1);}
   pfile[0]=rfile[0]=tfile[0]=p2file[0]=p3file[0]=r2file[0]=r3file[0]=(char)0;
   p4file[0]=r4file[0]=ffile[0]=(char)0;
+  matfile[0]=(char)0;
   dftInit(&pdata); dftInit(&data); dftInit(&ipdata); dftInit(&fdata);
   orig_tissue_time_unit=orig_input_time_unit=TUNIT_UNKNOWN;
 
@@ -172,6 +177,8 @@ int main(int argc, char **argv)
       cptr+=3; if(strlen(cptr)>0) {strcpy(r3file, cptr); continue;}
     } else if(strncasecmp(cptr, "O4=", 3)==0) {
       cptr+=3; if(strlen(cptr)>0) {strcpy(r4file, cptr); continue;}
+    } else if(strncasecmp(cptr, "MATRIX=", 7)==0) {
+      cptr+=7; if(strlen(cptr)>0) {strcpy(matfile, cptr); continue;}
     } else if(strncasecmp(cptr, "TIMEUNIT=", 9)==0) {
       cptr+=9;
       if(strncasecmp(cptr, "S", 1)==0) {time_unit=TUNIT_SEC; continue;}
@@ -237,6 +244,7 @@ int main(int argc, char **argv)
     printf("r3file := %s\n", r3file);
     printf("r4file := %s\n", r4file);
     printf("ffile := %s\n", ffile);
+    if(matfile[0]) printf("matfile := %s\n", matfile);
     printf("output_format := %d\n", output_format);
     printf("make_log := %d\n", make_log);
     printf("time_unit := %s\n", petTunit(time_unit));
@@ -288,6 +296,12 @@ int main(int argc, char **argv)
     if(verbose>2) printf("last_t := %g\n", data.x[data.frameNr-1]);
   }
 
+  /* If more than one tissue TAC then do not allow saving NNLS matrix */
+  if(data.voiNr>1 && matfile[0]) {
+    matfile[0]=(char)0;
+    fprintf(stderr, "Warning: option -matrix disabled because more than one tissue TAC found.\n");
+  }
+
   /*
    *  Check time units and convert times to sec when necessary
    */
@@ -306,8 +320,7 @@ int main(int argc, char **argv)
         if(pdata.x[pdata.frameNr-1]>=180) pdata.timeunit=TUNIT_SEC;
         else pdata.timeunit=TUNIT_MIN;
       }
-      fprintf(stderr, "Warning: assuming input time_unit := %s\n",
-        petTunit(pdata.timeunit));
+      fprintf(stderr, "Warning: assuming input time_unit := %s\n", petTunit(pdata.timeunit));
     }
   }
   /* Make sure that tissue time unit is set */
@@ -324,8 +337,7 @@ int main(int argc, char **argv)
         if(data.x[data.frameNr-1]>=180) data.timeunit=TUNIT_SEC;
         else data.timeunit=TUNIT_MIN;
       }
-      fprintf(stderr, "Warning: assuming tissue time_unit := %s\n",
-        petTunit(data.timeunit));
+      fprintf(stderr, "Warning: assuming tissue time_unit := %s\n", petTunit(data.timeunit));
     }
   }
   /* Save the original unit, so that units can be converted back */
@@ -338,25 +350,21 @@ int main(int argc, char **argv)
   /* Convert data times to sec */
   if(data.timeunit!=TUNIT_SEC) {
     if(verbose>0)
-      fprintf(stdout, 
-        "Note: tissue sample times are converted to seconds for fitting.\n");
+      fprintf(stdout, "Note: tissue sample times are converted to seconds for fitting.\n");
     dftTimeunitConversion(&data, TUNIT_SEC);
   }  
   if(pdata.timeunit!=TUNIT_SEC) {
     if(verbose>0)
-      fprintf(stdout, 
-        "Note: input sample times are converted to seconds for fitting.\n");
+      fprintf(stdout, "Note: input sample times are converted to seconds for fitting.\n");
     dftTimeunitConversion(&pdata, TUNIT_SEC);    
   }
   /* Check fit time */
   if(length<data.x[data.frameNr-1]/60.0 || length<pdata.x[pdata.frameNr-1]/60.0)
-    fprintf(stderr, 
-      "Warning: fit time (%g s) is short, compared with data.\n", length);
+    fprintf(stderr, "Warning: fit time (%g s) is short, compared with data.\n", length);
 
 
-  /* Check if the ascending part of TAC has been missed */
-  if(verbose>1)
-    printf("checking if the ascending part of plasma TAC has been missed\n");
+  /* Check if the ascending part of PTAC has been missed */
+  if(verbose>1) printf("checking if the ascending part of plasma TAC has been missed\n");
   for(fi=1, n=0, maxv=pdata.voi[0].y[0]; fi<pdata.frameNr; fi++) {
     v=pdata.voi[0].y[fi];
     if(fi>1 && fi<pdata.frameNr-2) { 
@@ -371,8 +379,7 @@ int main(int argc, char **argv)
     }
     if(v>maxv) {maxv=v; n=fi;}
   }
-  if(verbose>2)
-    printf("maxv := %g\nmax_index := %d\nmax_time := %g\n", maxv, n, pdata.x[n]);
+  if(verbose>2) printf("maxv := %g\nmax_index := %d\nmax_time := %g\n", maxv, n, pdata.x[n]);
   if(n==0) {  /* the first or second value is the highest */
     fprintf(stderr, "Error: missed the ascending phase of plasma/blood data.\n");
     dftEmpty(&pdata); dftEmpty(&data); return(2);
@@ -383,8 +390,7 @@ int main(int argc, char **argv)
     dftEmpty(&pdata); dftEmpty(&data); return(2);
   }
   /* check tissue data (first TAC) */
-  if(verbose>1)
-    printf("checking if the ascending part of tissue TAC has been missed\n");
+  if(verbose>1) printf("checking if the ascending part of tissue TAC has been missed\n");
   for(fi=1, n=0, maxv=data.voi[0].y[0]; fi<data.frameNr; fi++)
     if(data.voi[0].y[fi]>maxv) {maxv=data.voi[0].y[fi]; n=fi;}
   if(verbose>2) printf("maxv := %g\nmax_index := %d\n", maxv, n);
@@ -416,8 +422,7 @@ int main(int argc, char **argv)
     if(data.timetype==3) length=data.x2[data.frameNr-1];
     else length=data.x[data.frameNr-1];
   }
-  if(verbose>3)
-    printf("fit_frameNr := %d\nfit_length := %g\n", data.frameNr, length);
+  if(verbose>3) printf("fit_frameNr := %d\nfit_length := %g\n", data.frameNr, length);
   if(verbose>2) {
     if(verbose>10) dftPrint(&data);
     printf("pdata_time_unit := %s\n", petTunit(pdata.timeunit));
@@ -450,19 +455,16 @@ int main(int argc, char **argv)
     }
   }
 
-  /* Find the time where plasma curve starts to rise by integrating original */
-  /* plasma data and searching the time where integral is >= 1/1000 of       */
-  /* final integral                                                          */
+  /* Find the time where plasma curve starts to rise by integrating original plasma data 
+     and searching the time where integral is >= 1/1000 of final integral */
   ret=integrate(pdata.x, pdata.voi[0].y, pdata.frameNr, pdata.voi[0].y2);
   if(ret) {
     fprintf(stderr, "Error in integration of plasma data (%d).\n", ret);
     dftEmpty(&data); dftEmpty(&pdata); return(2);
   }
   for(fi=0, onep=0.0; fi<pdata.frameNr-1; fi++)
-    if(pdata.voi[0].y2[fi]>=0.001*pdata.voi[0].y2[pdata.frameNr-1]) {
-      onep=pdata.x[fi]; break;}
-  if(verbose>1)
-    fprintf(stdout, "Plasma curve starts to rise at about %g s.\n", onep);
+    if(pdata.voi[0].y2[fi]>=0.001*pdata.voi[0].y2[pdata.frameNr-1]) {onep=pdata.x[fi]; break;}
+  if(verbose>1) fprintf(stdout, "Plasma curve starts to rise at about %g s.\n", onep);
 
   /*
    *  Interpolate and integrate plasma TAC at frame mid times
@@ -504,11 +506,11 @@ int main(int argc, char **argv)
     if(ipdata.timetype==3)
       ret=interpolate4pet(pdata.x, pdata.voi[0].y, pdata.frameNr,
           ipdata.x1, ipdata.x2, ipdata.voi[ri].y, ipdata.voi[ri].y2,
-	  ipdata.voi[ri].y3, ipdata.frameNr);
+      ipdata.voi[ri].y3, ipdata.frameNr);
     else
       ret=interpolate(pdata.x, pdata.voi[0].y, pdata.frameNr,
         ipdata.x, ipdata.voi[ri].y, ipdata.voi[ri].y2, ipdata.voi[ri].y3, 
-	ipdata.frameNr);
+      ipdata.frameNr);
     if(ret) {
       fprintf(stderr, "Error (%d) in interpolation.\n", ret);
       dftEmpty(&data); dftEmpty(&pdata); dftEmpty(&ipdata); return(4);
@@ -529,7 +531,7 @@ int main(int argc, char **argv)
     if(ipdata.timetype==DFT_TIME_STARTEND) {
       ret=interpolate4pet(pdata.x, pdata.voi[0].y, pdata.frameNr,
                ipdata.x1, ipdata.x2, ipdata.voi[ri].y, ipdata.voi[ri].y2,
-	       ipdata.voi[ri].y3, ipdata.frameNr);
+               ipdata.voi[ri].y3, ipdata.frameNr);
       if(ret==3) { /* time ranges do not match any more */
         for(fi=0; fi<ipdata.frameNr; fi++)
           ipdata.voi[ri].y[fi]=ipdata.voi[ri].y2[fi]=ipdata.voi[ri].y3[fi]=0.0;
@@ -537,8 +539,7 @@ int main(int argc, char **argv)
       }
     } else {
       ret=interpolate(pdata.x, pdata.voi[0].y, pdata.frameNr,
-              ipdata.x, ipdata.voi[ri].y, ipdata.voi[ri].y2, ipdata.voi[ri].y3, 
-	      ipdata.frameNr);
+              ipdata.x, ipdata.voi[ri].y, ipdata.voi[ri].y2, ipdata.voi[ri].y3, ipdata.frameNr);
     }
     if(ret!=0) {
       fprintf(stderr, "Error in interpolation (%d).\n", ret);
@@ -596,6 +597,19 @@ int main(int argc, char **argv)
   if(data.voiNr>1) printf("Regional time delays:\n");
   for(ri=0; ri<data.voiNr; ri++) {
 
+
+    /* If requested, open file to save NNLS matrix in */
+    FILE *mfp=NULL;
+    if(matfile[0]) {
+      mfp=fopen(matfile, "w");
+      if(mfp==NULL) {
+        fprintf(stderr, "Error: cannot write file '%s'.\n", matfile);
+        dftEmpty(&data); dftEmpty(&pdata); dftEmpty(&ipdata); 
+        free(nnls_mat); free(regional_delay);
+        return(30);
+      }
+    }
+
     /* Fit with different delays */
     min=-1; minv=9.9e+99;
     for(di=0; di<=2*MAX_DELAY; di++) {
@@ -618,14 +632,29 @@ int main(int argc, char **argv)
           nnls_b[m]=data.voi[ri].y[m];
         }
       }
+
+      /* Add weights */
       if(data.isweight) for(m=0; m<nnls_m; m++) {
         nnls_b[m]*=data.w[m];
         for(n=0; n<nnls_n; n++) nnls_a[n][m]*=data.w[m];
       }
 
+      /* If requested, save NNLS matrix in file */
+      if(matfile[0]) {
+        int dt;
+        if(di<=MAX_DELAY) dt=-di; else dt=di-MAX_DELAY;
+        fprintf(mfp, "%d\nB", dt);
+        for(int n=0; n<nnls_n; n++) fprintf(mfp, ",A%d", n+1);
+        fprintf(mfp, "\n");
+        for(int m=0; m<nnls_m; m++) {
+          fprintf(mfp, "%g", nnls_b[m]);
+          for(int n=0; n<nnls_n; n++) fprintf(mfp, ",%g", nnls_a[n][m]);
+          fprintf(mfp, "\n");
+        }
+      }
+
       /* NNLS */
-      ret=nnls(nnls_a, nnls_m, nnls_n, nnls_b, nnls_x, &nnls_rnorm,
-               nnls_wp, nnls_zz, nnls_index);
+      ret=nnls(nnls_a, nnls_m, nnls_n, nnls_b, nnls_x, &nnls_rnorm, nnls_wp, nnls_zz, nnls_index);
       if(ret>1) { /* no solution is possible */
         continue;
       } else if(ret==1) { /* max iteration count exceeded */ }
@@ -666,32 +695,29 @@ int main(int argc, char **argv)
 
       if(verbose>4) {
         if(model==1) {
-          printf("Fit %2d -> SS=%12.3e Vb=%g K1+Vb*k2=%g k2=%g\n",
-            di, ss, coeff[0], coeff[1], coeff[2]);
+          printf("Fit %2d -> SS=%12.3e Vb=%g K1+Vb*k2=%g k2=%g\n", di, ss, coeff[0], coeff[1], coeff[2]);
         } else {
-          printf("Fit %2d -> SS=%12.3e Vb=%g K1+Vb*(k2+k3+k4)=%g\n",
-            di, ss, coeff[0], coeff[1]);
-          printf("           K1*(k3+k4)=%g k2+k3+k4=%g k2k4=%g\n",
-            coeff[2], coeff[3], coeff[4]);
+          printf("Fit %2d -> SS=%12.3e Vb=%g K1+Vb*(k2+k3+k4)=%g\n", di, ss, coeff[0], coeff[1]);
+          printf("           K1*(k3+k4)=%g k2+k3+k4=%g k2k4=%g\n", coeff[2], coeff[3], coeff[4]);
         }
       }
 
       /* Check if minimum SS */
       if(ss<minv) {
         minv=ss; min=di;
-        if(ffile[0]) 
-	  for(m=0; m<nnls_m; m++) fdata.voi[ri].y[m]=fdata.voi[ri].y2[m];
+        if(ffile[0]) for(m=0; m<nnls_m; m++) fdata.voi[ri].y[m]=fdata.voi[ri].y2[m];
       }
 
     } /* next delay time */
 
+    if(matfile[0]) fclose(mfp);
+
     /* what delay times the minima are? */
     if(verbose>5) printf("  min TAC (%s) := %d\n", data.voi[ri].name, min);
     if(min<=MAX_DELAY) min=-min; else min-=MAX_DELAY;
     regional_delay[ri]=(double)min;
     if(verbose>=0 && data.voiNr>1)
-      printf("  time_delay for %s := %g s\n", 
-             data.voi[ri].name, regional_delay[ri]);
+      printf("  time_delay for %s := %g s\n", data.voi[ri].name, regional_delay[ri]);
 
   } /* next region */
 
@@ -708,8 +734,7 @@ int main(int argc, char **argv)
   free(regional_delay);
   if(verbose>=0) {
     printf("Estimated tracer appearance time in plasma := %.1f s\n", onep);
-    printf("Estimated tracer appearance time in tissue := %.1f s\n", 
-           onep+(double)v);
+    printf("Estimated tracer appearance time in tissue := %.1f s\n", onep+(double)v);
     printf("Median time delay := %g s\n", v);
   }
 
@@ -720,10 +745,8 @@ int main(int argc, char **argv)
   printf("Applied delay %g s\n", v);
   */
   if(-v>onep) {
-    fprintf(stderr, 
-      "Warning: possible error in determined tracer appearance time.\n");
-    fprintf(stderr, 
-      "         Please check the delay corrected input against tissue data.\n");
+    fprintf(stderr, "Warning: possible error in determined tracer appearance time.\n");
+    fprintf(stderr, "         Please check the delay corrected input against tissue data.\n");
   }
 
   /* Ok this is the final delay time (in seconds) */
@@ -853,7 +876,7 @@ int main(int argc, char **argv)
       if(pdata.x[fi]>=0.0) break;
       for(fj=fi+1; fj<pdata.frameNr; fj++) {
         for(ri=0; ri<pdata.voiNr; ri++) 
-	  pdata.voi[ri].y[fj-1]=pdata.voi[ri].y[fj];
+          pdata.voi[ri].y[fj-1]=pdata.voi[ri].y[fj];
         pdata.x[fj-1]=pdata.x[fj]; pdata.x1[fj-1]=pdata.x1[fj];
         pdata.x2[fj-1]=pdata.x2[fj];
       }
@@ -913,7 +936,7 @@ int main(int argc, char **argv)
       if(pdata.x[fi]>=0.0) break;
       for(fj=fi+1; fj<pdata.frameNr; fj++) {
         for(ri=0; ri<pdata.voiNr; ri++) 
-	  pdata.voi[ri].y[fj-1]=pdata.voi[ri].y[fj];
+          pdata.voi[ri].y[fj-1]=pdata.voi[ri].y[fj];
         pdata.x[fj-1]=pdata.x[fj]; pdata.x1[fj-1]=pdata.x1[fj];
         pdata.x2[fj-1]=pdata.x2[fj];
       }
