@@ -369,7 +369,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 tacmatch -abs=1 tissue.tac bkg201.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-tacmatch -abs=3 blood.tac output201.tac
+tacmatch -abs=3 -rel=3 blood.tac output201.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
