@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_fit_ppf
-#: Date       : 2022-03-29
+#: Date       : 2023-04-21
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -39,6 +39,14 @@ if [ ! -f orig_ppf.fit ] || [ ! -f orig_ppf2.fit ] ; then
   printf "Failed: required data does not exist.\n"
   exit 1
 fi
+if [ ! -f orig_gcdf.fit ] ; then
+  printf "Failed: required data does not exist.\n"
+  exit 1
+fi
+if [ ! -f orig_ep.fit ] ; then
+  printf "Failed: required data does not exist.\n"
+  exit 1
+fi
 
 
 
@@ -241,6 +249,15 @@ if [ ! -f data_pfm3delay.dat ] ; then
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 fi
 
+if [ ! -f data_gcdf.dat ] ; then
+  fit2dat -x=0.5,1,1.5,2.5,5,10,15,20,30,40,50,60 orig_gcdf.fit data_gcdf.dat
+  if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+fi
+
+if [ ! -f data_ep.dat ] ; then
+  fit2dat -x=0.5,1,1.5,2.5,5,7.5,10,15,20,30,40,50,60 orig_ep.fit data_ep.dat
+  if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+fi
 
 
 
@@ -885,6 +902,73 @@ printf "\n passed. \n\n"
 
 
 
+printf "\n\n---------------------------------------------------------------\n\n"
+
+
+printf "\n 2.2.0 \n"
+printf " Test case: Gamma CDF function. \n"
+printf " Expected result: Fitted curve and parameters are close to correct. \n\n"
+
+rm -f output.fit output.res output.dat
+
+$PROGRAM -model=GCDF data_gcdf.dat output.fit
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+fit2dat -f=data_gcdf.dat output.fit output.dat 
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+tacmatch -abs=0.01 -rel=2 data_gcdf.dat output.dat
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n\n"
+
+fit2res output.fit orig_gcdf.fit
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+resmatch -roughly -res=2,5,6 orig_gcdf.res output.res
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+resmatch -abs=0.01 -res=4 orig_gcdf.res output.res
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+resmatch -abs=0.0001 -res=7 orig_gcdf.res output.res
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n\n"
+
+
+
+printf "\n\n---------------------------------------------------------------\n\n"
+
+
+printf "\n 2.3.0 \n"
+printf " Test case: Exp/Power function. \n"
+printf " Expected result: Fitted curve and parameters are close to correct. \n\n"
+
+rm -f output.fit output.res output.dat
+
+$PROGRAM -model=EP data_ep.dat output.fit
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+fit2dat -f=data_ep.dat output.fit output.dat 
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+tacmatch -abs=0.01 -rel=2 data_ep.dat output.dat
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n\n"
+
+fit2res output.fit orig_ep.fit
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+resmatch -roughly -res=2,5,6 orig_ep.res output.res
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+resmatch -abs=0.01 -res=4 orig_ep.res output.res
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+resmatch -abs=0.0001 -res=7 orig_ep.res output.res
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n\n"
+
+
 
 # MHILL and MPF too slow to test every time, and MPF does not work well
 if [ 0 -eq 1 ]; then
