@@ -348,6 +348,30 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 
+
+printf "=====================================================================\n"
+
+printf "\n 2.2.0 \n"
+printf " Test case: Option -matrix to save NNLS matrix. \n"
+printf " Expected result: Matrix file saved. \n\n"
+
+tacadd -ovr matrix_tissue.tac radiowater.tac 2
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+tactime -nogap radiowater.bld +20 matrix_input.bld
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+
+rm -f matrix.csv matrix_input.delay.bld
+
+$PROGRAM -matrix=matrix.csv -LOG matrix_input.bld matrix_tissue.tac 420
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+iftisval -abs=0.5 matrix_input.delay.bld time_delay -10
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+if [ ! -f matrix.csv ]; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n\n"
+
+
 printf "\n\n"
 printf "=====================================================================\n"
 printf "testing errors\n"
