@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_pbconv
-#: Date       : 2020-05-03
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -872,6 +872,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 tac2svg -mt="[F-18]FTHA" -y1=0 -xt="Time (min)" -yt="Plasma/blood" p2b_ftha.svg -l p2b_ftha.dat 
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
+
 $PROGRAM3 MEAIB 0.40 60 p2b_meaib.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 tac2svg -mt="[C-11]MeAIB" -y1=0 -xt="Time (min)" -yt="Plasma/blood" p2b_meaib.svg -l p2b_meaib.dat 
@@ -930,6 +931,17 @@ tac2svg -mt="[C-11]SMW139" -y1=0 -xt="Time (min)" -yt="Plasma/blood" p2b_smw139.
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
+$PROGRAM3 UCB-J 0.43 90 p2b_ucb-j.dat
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+tac2svg -mt="[C-11]UCB-J" -y1=0 -xt="Time (min)" -yt="Plasma/blood" p2b_ucb-j.svg -l p2b_ucb-j.dat 
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+fit2dat -f=p2b_ucb-j.dat UCB-J_p2b_median.fit temp.dat
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+tacmatch -abs=0.0001 temp.dat p2b_ucb-j.dat
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+
 $PROGRAM3 MOUSEFDG1 0.40 60 p2b_mousefdg1.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 tac2svg -mt="[F-18]FDG in mice" -y1=0 -xt="Time (min)" -yt="Plasma/blood" p2b_mousefdg1.svg -l p2b_mousefdg1.dat 
