@@ -75,7 +75,7 @@ int csvRead(
     while((ret=fgetc(fp))!=EOF) {
       if(ret=='"') {
         if(inside_quotes==0) inside_quotes=1; else inside_quotes=0;
-	continue;
+        continue;
       }
       if(inside_quotes==1) continue;
       if(ret==';') nr++;
@@ -100,6 +100,7 @@ int csvRead(
   /* We will not accept space as separator for CSV */
   if(csv->separator==' ') {fclose(fp); return CSV_INVALIDFORMAT;}
 
+
   /* Determine the number of fields in CSV file */
   inside_quotes=0; nr=0; previous=0;
   while((ret=fgetc(fp))!=EOF) {
@@ -111,12 +112,21 @@ int csvRead(
     if(inside_quotes==0) {
       if(ret==csv->separator) {
         nr++; previous=ret;
-	continue;
+        continue;
       }
       if( (ret==13 || ret==10) && previous!=13 && previous!=10) {
         nr++; previous=ret;
-	continue;
+        continue;
       }
+
+      int next=fgetc(fp);
+      if(next!=EOF) {
+        ungetc(next, fp);
+      } else {
+        nr++; previous=ret;
+        continue;
+      }
+
     } //printf("%c", (char)ret);
     previous=ret;
   }
@@ -141,34 +151,35 @@ int csvRead(
         buf[i]=(char)0; strCleanSpaces(buf); if(CSV_TEST>10) printf("'%s'\n", buf);
         if(nr>=csv->nr) {printf("  index overflow\n"); break;}
         csv->c[nr].content=strdup(buf);
-/*
-        if(i>0) {
-          if(nr>=csv->nr) {printf("  index overflow\n"); break;}
-          csv->c[nr].content=(char*)malloc(i+1);
-          if(csv->c[nr].content!=NULL) strcpy(csv->c[nr].content, buf);
-        } //if(CSV_TEST>10) printf("---\n");
-*/
         csv->c[nr].row=1+csv->row_nr; csv->c[nr].col=1+col_nr;
-	i=0; nr++; col_nr++; previous=ret;
-	continue;
+        i=0; nr++; col_nr++; previous=ret;
+        continue;
       }
       if( (ret==13 || ret==10) && previous!=13 && previous!=10) {
         buf[i]=(char)0; strCleanSpaces(buf); if(CSV_TEST>10) printf("'%s'\n", buf); 
         if(nr>=csv->nr) {printf("   index overflow\n"); break;}
         csv->c[nr].content=strdup(buf);
         if(CSV_TEST>10) printf("===\n");
-/*
-        if(i>0) {
-          if(nr>=csv->nr) {printf("   index overflow\n"); break;}
-          csv->c[nr].content=(char*)malloc(i+1);
-          if(csv->c[nr].content!=NULL) strcpy(csv->c[nr].content, buf);
-        } if(CSV_TEST>10) printf("===\n");
-*/
         col_nr++; if(col_nr>csv->col_nr) csv->col_nr=col_nr;
         csv->c[nr].row=1+csv->row_nr; csv->c[nr].col=col_nr;
         i=0; nr++; col_nr=0; previous=ret; csv->row_nr++;
-	continue;
+        continue;
       }
+
+      int next=fgetc(fp);
+      if(next!=EOF) {
+        ungetc(next, fp);
+      } else {
+        buf[i]=(char)0; strCleanSpaces(buf); if(CSV_TEST>10) printf("'%s'\n", buf); 
+        if(nr>=csv->nr) {printf("   index overflow\n"); break;}
+        csv->c[nr].content=strdup(buf);
+        if(CSV_TEST>10) printf("===\n");
+        col_nr++; if(col_nr>csv->col_nr) csv->col_nr=col_nr;
+        csv->c[nr].row=1+csv->row_nr; csv->c[nr].col=col_nr;
+        i=0; nr++; col_nr=0; previous=ret; csv->row_nr++;
+        continue;
+      }
+
     }
     if(i<MAX_CSV_FIELD_LENGTH) buf[i]=(char)ret;
     i++;
@@ -176,6 +187,7 @@ int csvRead(
   }
   if(CSV_TEST>0) printf("  ... copied: nr=%d\n", nr);
 
+
   fclose(fp);
   return CSV_OK;
 }
@@ -309,14 +321,15 @@ int csv2dft_a(
     if(!isdigit(csv->c[ii].content[0]) && csv->c[ii].content[0]!='-') {
       if(strstr(csv->c[ii].content, "Time")==NULL &&
          strstr(csv->c[ii].content, "TIME")==NULL &&
-         strstr(csv->c[ii].content, "time")==NULL) {
-        if(CSV_TEST>11) {
-          printf("  not a numerical value or title\n"); fflush(stdout);}
+         strstr(csv->c[ii].content, "time")==NULL)
+      {
+        if(CSV_TEST>11) {printf("  not a numerical value or title\n"); fflush(stdout);}
         ii++; continue;
       }
       dft->_type=DFT_FORMAT_STANDARD;
       if(strncasecmp(csv->c[ii].content, "Start time", 10)==0 &&
-         strncasecmp(csv->c[ii+1].content, "End time", 8)==0) {
+         strncasecmp(csv->c[ii+1].content, "End time", 8)==0) 
+      {
         dft->timetype=DFT_TIME_STARTEND;
         if(CSV_TEST>6) printf("timetype := %d\n", dft->timetype);
       }
@@ -383,8 +396,7 @@ int csv2dft_a(
           strncpy(dft->voi[ci-sci].name, csv->c[ii].content, MAX_REGIONNAME_LEN);
           dft->voi[ci-sci].name[MAX_REGIONNAME_LEN]=(char)0;
           rnameSplit(csv->c[ii].content, dft->voi[ci-sci].voiname,
-  	  dft->voi[ci-sci].hemisphere, dft->voi[ci-sci].place,
-          MAX_REGIONSUBNAME_LEN);
+  	                 dft->voi[ci-sci].hemisphere, dft->voi[ci-sci].place, MAX_REGIONSUBNAME_LEN);
         }
         if(CSV_TEST>8) printf("name[%d]=%s\n", ci-sci, dft->voi[ci-sci].name);
       }
@@ -400,8 +412,7 @@ int csv2dft_a(
       dft->x1[ri]=atof_dpi(csv->c[ii++].content);
       dft->x2[ri]=atof_dpi(csv->c[ii++].content);
       dft->x[ri]=0.5*(dft->x1[ri]+dft->x2[ri]);
-      if(CSV_TEST>3)
-        printf("x1[%d]=%g x2[%d]=%g\n", ri, dft->x1[ri], ri, dft->x2[ri]);
+      if(CSV_TEST>3) printf("x1[%d]=%g x2[%d]=%g\n", ri, dft->x1[ri], ri, dft->x2[ri]);
     }
     // read the sample values
     if(dft->timetype==DFT_TIME_MIDDLE) sci=2; else sci=3;
@@ -543,8 +554,7 @@ int csv2dft_b(
     //printf("ri=%d cell[%d] := '%s'\n", ri, ii, csv->c[ii].content); fflush(stdout);
     strncpy(dft->voi[ri].name, csv->c[ii].content, MAX_REGIONNAME_LEN);
     dft->voi[ri].name[MAX_REGIONNAME_LEN]=(char)0;
-    rnameSplit(csv->c[ii].content, dft->voi[ri].voiname,
-  	       dft->voi[ri].hemisphere, dft->voi[ri].place,
+    rnameSplit(csv->c[ii].content, dft->voi[ri].voiname, dft->voi[ri].hemisphere, dft->voi[ri].place,
                MAX_REGIONSUBNAME_LEN);
     /* Volume */
     ii++; if(ii>=csv->nr) {dftEmpty(dft); return CSV_INVALIDFORMAT;}
@@ -624,8 +634,7 @@ int csv2dft_linkset(
     }
     if(sci!=ri+1) break; // not found
     // ii is not the index of the start of data for one VOI
-    if(CSV_TEST>5) printf("  ri=%d ii=%d row=%d col=%d\n",
-                          ri, ii, csv->c[ii].row, csv->c[ii].col);
+    if(CSV_TEST>5) printf("  ri=%d ii=%d row=%d col=%d\n", ri, ii, csv->c[ii].row, csv->c[ii].col);
     /* Take the ROI number from there in case better name is not found later */
     strncpy(dft->voi[ri].name, csv->c[ii].content+4, MAX_REGIONNAME_LEN);
     dft->voi[ri].name[MAX_REGIONNAME_LEN]=(char)0;
@@ -661,8 +670,7 @@ int csv2dft_linkset(
       strncpy(dft->voi[ri].name, cptr, MAX_REGIONNAME_LEN);
       dft->voi[ri].name[MAX_REGIONNAME_LEN]=(char)0;
     } // default name was set before
-    rnameSplit(dft->voi[ri].name, dft->voi[ri].voiname,
-  	       dft->voi[ri].hemisphere, dft->voi[ri].place,
+    rnameSplit(dft->voi[ri].name, dft->voi[ri].voiname, dft->voi[ri].hemisphere, dft->voi[ri].place,
                MAX_REGIONSUBNAME_LEN);
     /* VOI average values should be two rows below this */
     if(CSV_TEST>4) printf("reading VOI values\n");
@@ -682,8 +690,7 @@ int csv2dft_linkset(
         if(CSV_TEST>0) printf("different concentration units.\n");
         return CSV_INVALIDFORMAT;
       }
-      if(CSV_TEST>5 && ri==0)
-        printf("unit := %s (%d)\n", petCunit(ci), ci);
+      if(CSV_TEST>5 && ri==0) printf("unit := %s (%d)\n", petCunit(ci), ci);
     }
     /* then read the concentrations */
     for(fi=0; fi<dft->frameNr; fi++) {
