@@ -100,9 +100,8 @@ int fitWrite(
   fprintf(fp, "Date:\t%s\n", tmp);
   /* Write the name of the original datafile */
   fprintf(fp, "Data file:\t%s\n", fit->datafile);
-  /* Write the studynr; NOT YET because all SW reading these should be
-     recompiled*/
-  //if(fit->studynr[0]) fprintf(fp, "Study:\t%s\n", fit->studynr);
+  /* Write the studynr */
+  if(fit->studynr[0]) fprintf(fp, "Study number:\t%s\n", fit->studynr);
   /* Write the 'activity' unit */
   fprintf(fp, "Data unit:\t%s\n", fit->unit);
   /* Write the time unit */
@@ -115,8 +114,7 @@ int fitWrite(
   fprintf(fp, "Nr of VOIs:\t%d\n", savedNr);
   /* Write the Fit title */
   fprintf(fp, "%s %s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\n",
-    "Region", "Plane", "Start", "End", "dataNr", "WSS", "parNr", "Type",
-    "Parameters");
+    "Region", "Plane", "Start", "End", "dataNr", "WSS", "parNr", "Type", "Parameters");
   /* Write regional fits */
   for(i=0; i<fit->voiNr; i++) {
     if(isnan(fit->voi[i].wss) || fit->voi[i].type<=0) continue;
@@ -231,6 +229,55 @@ int fitRead(
   lptr=line; cptr=strtok(lptr, " \t\n\r");
   if(cptr!=NULL) cptr=strtok(NULL, " \t\n\r");
   if(cptr!=NULL && strlen(cptr)<1024) strcpy(fit->program, cptr);
+#if(1)
+  /* Read optional fields until "Nr of VOIs:" */
+  while(1) {
+    /* Read title field */
+    while(fgets(line, 1024, fp)!=NULL) if(strlen(line)>2 && line[0]!='#') break;
+    /* Stop when "Nr of VOIs" is reached */
+    if(strncasecmp(line, "Nr of VOIs:", 11)==0) break;
+    /* Read fit date and time */
+    if(strncasecmp(line, "Date:", 5)==0) {
+      cptr=line+5; while(*cptr && !isdigit(*cptr)) cptr++;
+      if(get_datetime(cptr, &st, verbose-3)==0) fit->time=timegm(&st);
+      continue;
+    }
+    /* Read the name of the original datafile */
+    if(strncasecmp(line, "Data file:", 10)==0) {
+      lptr=&line[10]; cptr=strtok(lptr, " \t\n\r");
+      if(cptr!=NULL && strlen(cptr)<FILENAME_MAX) strcpy(fit->datafile, cptr);
+      continue;
+    }
+    /* Read study number */
+    if(strncasecmp(line, "Study number:", 13)==0) {
+      lptr=&line[13]; cptr=strtok(lptr, " \t\n\r");
+      if(cptr!=NULL && strlen(cptr)<MAX_STUDYNR_LEN+1) strcpy(fit->studynr, cptr);
+      continue;
+    }
+    /* Read the activity unit */
+    if(strncasecmp(line, "Data unit:", 10)==0) {
+      lptr=&line[10]; cptr=strtok(lptr, " \t\n\r");
+      if(cptr!=NULL && strlen(cptr)<1024) strcpy(fit->unit, cptr);
+      continue;
+    }
+    /* Read the time unit */
+    if(strncasecmp(line, "Time unit:", 10)==0) {
+      lptr=&line[10]; cptr=strtok(lptr, " \t\n\r");
+      fit->timeunit=petTunitId(cptr);
+      continue;
+    }
+    if(strncasecmp(line, "Distance unit:", 14)==0) {
+      lptr=&line[14]; cptr=strtok(lptr, " \t\n\r");
+      fit->timeunit=petTunitId(cptr);
+      continue;
+    }
+    fclose(fp); return 8;
+  }
+  /* Read the nr of regions */
+  if(strncasecmp(line, "Nr of VOIs:", 11)) {fclose(fp); return 8;}
+  lptr=&line[11]; cptr=strtok(lptr, " \t\n\r");
+  n=atoi(cptr); if(n<1 || n>32000) {fclose(fp); return 8;}
+#else
   /* Read fit date and time */
   while(fgets(line, 1024, fp)!=NULL) if(strlen(line)>2 && line[0]!='#') break;
   if(strncasecmp(line, "Date:", 5)) {fclose(fp); return 4;}
@@ -258,6 +305,7 @@ int fitRead(
   if(strncasecmp(line, "Nr of VOIs:", 11)) {fclose(fp); return 8;}
   lptr=&line[11]; cptr=strtok(lptr, " \t\n\r");
   n=atoi(cptr); if(n<1 || n>32000) {fclose(fp); return 8;}
+#endif
   /* Allocate memory for regions */
   if(fitSetmem(fit, n)) {strcpy(fiterrmsg, "out of memory"); fclose(fp); return 9;}
   fit->voiNr=n;
@@ -356,6 +404,8 @@ int fitFunctionformat(
     case 232: strcpy(str, "f(x)=(A+C*x+E*x^2+G*x^3)/(B+D*x+F*x^2)"); break;
     case 233: strcpy(str, "f(x)=(A+C*x+E*x^2+G*x^3)/(B+D*x+F*x^2+H*x^3)"); break;
     case 1232: strcpy(str, "f(x)=(A+C*(x-t)+E*(x-t)^2+G*(x-t)^3)/(B+D*(x-t)+F*(x-t)^2)"); break;
+    /* Rational function for plasma-to-blood ratio */
+    case 2233: strcpy(str, "f(x)=1/(1-H*(1-r(x))), where r(x) is 3/3 order rational function for RBC-to-plasma"); break;
     /* Exponential functions */
     case 301: strcpy(str, "f(x)=A*exp(B*x)"); break;
     case 302: strcpy(str, "f(x)=A*exp(B*x)+C*exp(D*x)"); break;
@@ -366,6 +416,7 @@ int fitFunctionformat(
     case 1312: strcpy(str, "f(x)=(A*(x-t)-C)*exp(B*(x-t))+C*exp(D*(x-t))"); break;
     case 1313: strcpy(str, "f(x)=(A*(x-t)-C-E)*exp(B*(x-t))+C*exp(D*(x-t))+E*exp(F*(x-t))"); break;
     case 1314: strcpy(str, "f(x)=(A*(x-t)-C-E-G)*exp(B*(x-t))+C*exp(D*(x-t))+E*exp(F*(x-t))+G*exp(H*(x-t))"); break;
+    case 2313: strcpy(str, "f(x)=1/(1-A*(1-((B*x-D-F)*exp(C*x)+D*exp(E*x)+F*exp(G*x))))"); break;
     /* Lundqvist function */
     case 321: strcpy(str, "f(x)=A*exp(B*x)*(1-exp(C*x))"); break;
     case 322: strcpy(str, "f(x)=A*exp(B*x)*(1-exp(C*x))+D*exp(E*x)*(1-exp(F*x))"); break;
@@ -382,6 +433,8 @@ int fitFunctionformat(
       break;
     /* Exponential functions for plasma fractions */
     case 351: strcpy(str, "f(x)=1-a*(2-exp(-b*x)-exp(-c*x))"); break;
+    /* Inverted gamma cdf for plasma parent fraction */
+    case 403: strcpy(str, "f(x)=A*(1-B*gammacdf(D,C*(x-t)))"); break;
     /* Gamma variate function */
     case 1401: strcpy(str, "f(x)=A*((x-D)^B)*exp(-(x-D)/C) , when x>=D, else f(x)=0"); break;
     /* Gamma variate function with background */
@@ -408,9 +461,13 @@ int fitFunctionformat(
     case 1801: strcpy(str, "f(x)=[A*(x-t)^B]/[(x-t)^B+C^B]"); break;
     case 1811: strcpy(str, "f(x)=A*{[B*(x-t)^(B-1)]/[C^B+(x-t)^B] - [B*(x-t)^(2*B-1)]/[C^B+(x-t)^B]^2}"); break;
     case 1821: strcpy(str, "f(x)=A*{[B*(x-t)^(B-1)]/[C^B+(x-t)^B] - [B*(x-t)^(2*B-1)]/[C^B+(x-t)^B]^2 + K*(x-t)^B]/[(x-t)^B+C^B}"); break;
+    /* Surge function with recirculation and delay */
+    case 1833: strcpy(str, "f(x)=A*[(x-D)*exp(-B*(x-D)) + (A*C/B^2)*(1-(B*(x-D)+1)*exp(-B*(x-D)))], when x>D, else f(x)=0"); break;
     /* Hill functions for dose-response curves */
     case 2801: strcpy(str, "f(x)=B+[A-B]/[1+(C/x)^D]"); break;
     case 2802: strcpy(str, "f(x)=B+[A-B]/[1+10^{(C-x)*D}]"); break;
+    /* Exponential/power type functions for parent fractions */
+    case 831: strcpy(str, "f(x)=B*(C*exp(-D*(x-A)^3/((x-A)^2+E))+(1-C)*exp(-F*(x-A))), when x>A, else f(x)=B"); break;
     /* Hill type functions for fractions */
     case 841: strcpy(str, "f(x)=(A*x^B)/(x^B+C)"); break;
     case 842: strcpy(str, "f(x)=1-((A*x^B)/(x^B+C))"); break;
@@ -421,6 +478,8 @@ int fitFunctionformat(
     case 847: strcpy(str, "f(x)=1-D-((A-D)*(x-t)^B)/((x-t)^B+C), when x>t, else f(x)=1-A"); break;
     case 848: strcpy(str, "f(x)=D*((1-A)*(x-t)^B)/((x-t)^B+C), when x>t, else f(x)=D"); break;
     case 849: strcpy(str, "f(x)=1-D*((1-A)*(x-t)^B)/((x-t)^B+C), when x>t, else f(x)=1-A"); break;
+    /* Hill function for plasma-to-blood ratio */
+    case 2841: strcpy(str, "f(x)=1/(1-H*(1-r(x))), where r(x) is Hill function for RBC-to-plasma"); break;
     /* Mamede/Watabe function for fractions */
     case 851: strcpy(str, "f(x)=1/(1+(A*x)^2)^B"); break;
     case 852: strcpy(str, "f(x)=1-1/(1+(A*x)^2)^B"); break;
@@ -443,6 +502,9 @@ int fitFunctionformat(
     case 874:
     case 884:
       strcpy(str, "f3(x)=c(x)(1-a(x)-b(x)+a(x)b(x))/(1-a(x)b(x)-a(x)c(x)-b(x)c(x)+2a(x)b(x)c(x))"); break;
+    case 1010:
+      strcpy(str, "f(x)=p2 when x>=p1, f(x)=p4 when x>=p2, ..."); break;
+      break;
     /* PET profile functions */
     case 2111: strcpy(str, "P(x)=(C/2)*(erf((x-d+R)/(sqrt(2)*FWHM/2355))-erf((x-d-R)/(sqrt(2)*FWHM/2355)))+bkg");
       break;
@@ -498,6 +560,7 @@ int fitFunctionname(
     case 232: strcpy(str, "3/2 order rational function"); break;
     case 233: strcpy(str, "3/3 order rational function"); break;
     case 1232: strcpy(str, "3/2 order rational function with delay"); break;
+    case 2233: strcpy(str, "3/3 order rational function for plasma-to-blood ratio"); break;
     case 301: strcpy(str, "exponential function"); break;
     case 302: strcpy(str, "sum of 2 exponential functions"); break;
     case 303: strcpy(str, "sum of 3 exponential functions"); break;
@@ -506,6 +569,7 @@ int fitFunctionname(
     case 1312: strcpy(str, "Feng model 2 function with 2 exponentials"); break;
     case 1313: strcpy(str, "Feng model 2 function"); break;
     case 1314: strcpy(str, "Feng model 2 function with 4 exponentials"); break;
+    case 2313: strcpy(str, "Feng M2 function for plasma-to-blood ratio"); break;
     case 321: strcpy(str, "Lundqvist function"); break;
     case 322: strcpy(str, "sum of 2 Lundqvist functions"); break;
     case 323: strcpy(str, "sum of 3 Lundqvist functions"); break;
@@ -514,6 +578,7 @@ int fitFunctionname(
     case 332: strcpy(str, "Kudomi's exponential bolus infusion function for radiowater"); break;
     case 334: strcpy(str, "Exponential bolus function approaching zero"); break;
     case 351: strcpy(str, "Exponential function for [C-11]PK11195 plasma fractions"); break;
+    case 403: strcpy(str, "Inverted gamma cdf for plasma parent fraction"); break;
     case 1401: strcpy(str, "Gamma variate function"); break;
     case 1402: strcpy(str, "Gamma variate with background"); break;
     case 1403: strcpy(str, "Gamma variate bolus plus recirculation"); break;
@@ -528,8 +593,10 @@ int fitFunctionname(
     case 1801: strcpy(str, "Hill function with delay"); break;
     case 1811: strcpy(str, "Derivative of Hill function with delay"); break;
     case 1821: strcpy(str, "Sum of Hill function and derivative with delay"); break;
+    case 1833: strcpy(str, "Surge function with recirculation and delay"); break;
     case 2801: strcpy(str, "Hill function for dose-response curve on linear scale"); break;
     case 2802: strcpy(str, "Hill function for dose-response curve on log scale"); break;
+    case 831: strcpy(str, "Exponential/Power function for parent fractions"); break;
     case 841: strcpy(str, "Hill function"); break;
     case 842: strcpy(str, "Hill function (1-f(x))"); break;
     case 843: strcpy(str, "Hill function (1-f(x)) with ascending or descending end"); break;
@@ -553,7 +620,9 @@ int fitFunctionname(
     case 882: strcpy(str, "1-3 metabolite power function for metab1"); break;
     case 883: strcpy(str, "1-3 metabolite power function for metab2"); break;
     case 884: strcpy(str, "1-3 metabolite power function for metab3"); break;
+    case 1010: strcpy(str, "Step function"); break;
     case 2111: strcpy(str, "Image profile function"); break;
+    case 2841: strcpy(str, "Hill function for plasma-to-blood ratio"); break;
     case 3331: strcpy(str, "Exponential bolus infusion function with delay and dispersion"); break;
     case 9501: strcpy(str, "Graham's input function"); break;
     case 9502: strcpy(str, "Extended Graham's input function"); break;
@@ -742,6 +811,20 @@ int fitEval(
     case 351:
       f=1.0-r->p[0]*(2.0-exp(-r->p[1]*x)-exp(-r->p[2]*x)); *y=f;
       break;
+    case 403:
+      xt=x-r->p[4]; if(xt<0.0) xt=0.0;
+      f=r->p[0]*(1.0 - r->p[1]*igam(r->p[3], r->p[2]*xt));
+      *y=f;
+      break;
+    case 831:
+      xt=x-r->p[0]; if(xt<=0.0) {
+        f=r->p[1];
+      } else {
+        f=r->p[2]*exp(-r->p[3]*xt*xt*xt/(xt*xt+r->p[4])) + (1.0-r->p[2])*exp(-r->p[5]*xt);
+        f*=r->p[1];
+      }
+      *y=f;
+      break;
     case 841:
       f=r->p[0]*pow(x, r->p[1]) / (pow(x, r->p[1]) + r->p[2]);
       *y=f;
@@ -899,13 +982,20 @@ int fitEval(
         *y=mf[2]*(1.0-mf[0]-mf[1]+mf[0]*mf[1])/a;
       }
       break;
+    case 1010: // step functions
+      /* Parameter number must be an even number and >=2 */
+      if(r->parNr<2 || r->parNr&1) return(2);
+      *y=0.0;
+      for(int i=0; i<r->parNr; i+=2) if(x>=r->p[i]) *y=r->p[i+1];
+      break;
     case 2111:
       xt=x-r->p[3]; a=sqrt(2.0)*(r->p[2]/2.355);
       f=r->p[4]+(r->p[0]/2.0)*(erf((xt+r->p[1])/a)-erf((xt-r->p[1])/a));
       *y=f;
       break;
     case 1232:
-      xt=x-r->p[7]; if(xt<=0.0) {
+      xt=x; if(r->parNr>7) xt-=r->p[7];
+      if(xt<=0.0) {
         f=0.0;
       } else {
         sqrx=xt*xt; cubx=sqrx*xt;
@@ -916,7 +1006,8 @@ int fitEval(
       *y=f;
       break;
     case 1312:
-      xt=x-r->p[4]; if(xt<=0.0) {
+      xt=x; if(r->parNr>4) xt-=r->p[4];
+      if(xt<=0.0) {
         f=0.0;
       } else {
         f=0.0;
@@ -926,7 +1017,8 @@ int fitEval(
       *y=f;
       break;
     case 1313:
-      xt=x-r->p[6]; if(xt<=0.0) {
+      xt=x; if(r->parNr>6) xt-=r->p[6];
+      if(xt<=0.0) {
         f=0.0;
       } else {
         f=0.0;
@@ -937,7 +1029,8 @@ int fitEval(
       *y=f;
       break;
     case 1314:
-      xt=x-r->p[8]; if(xt<=0.0) {
+      xt=x; if(r->parNr>8) xt-=r->p[8];
+      if(xt<=0.0) {
         f=0.0;
       } else {
         f=0.0;
@@ -1078,6 +1171,44 @@ int fitEval(
       }
       *y=f;
       break;
+    case 1833:
+      xt=x; if(r->parNr>3) xt-=r->p[3];
+      if(xt<=0.0) {
+        f=0.0;
+      } else {
+        double c=0.0; if(r->parNr>2) c=r->p[2];
+        double e=exp(-r->p[1]*xt);
+        f=xt*e + (c/(r->p[1]*r->p[1]))*(1.0-(r->p[1]*xt+1.0)*e);
+        f*=r->p[0];
+      }
+      *y=f;
+      break;
+    case 2233:
+      if(x<=0.0) {
+        f=1.0/(1.0-r->p[0]);
+      } else {
+        sqrx=x*x; cubx=sqrx*x;
+        a=0.0+r->p[1]*x+r->p[3]*sqrx+r->p[5]*cubx;
+        b=1.0+r->p[2]*x+r->p[4]*sqrx+r->p[6]*cubx;
+        f=1.0/(1.0-r->p[0]*(1.0-(a/b)));
+      }
+      *y=f;
+      break;
+    case 2313:
+      if(r->parNr<3) return(2);
+      if(x<=0.0) {
+        f=0.0;
+      } else {
+        double A1=r->p[1];
+        double L1=r->p[2];
+        double A2=0.0; if(r->parNr>3) A2=r->p[3];
+        double L2=0.0; if(r->parNr>4) L2=r->p[4];
+        double A3=0.0; if(r->parNr>5) A3=r->p[5];
+        double L3=0.0; if(r->parNr>6) L3=r->p[6];
+        f=(A1*x - A2 - A3)*exp(-L1*x) + A2*exp(-L2*x) + A3*exp(-L3*x);
+      }
+      *y=1.0/(1.0-r->p[0]*(1.0-f));
+      break;
     case 2801:
       {
         double top, bottom, ec50, hillslope;
@@ -1095,6 +1226,11 @@ int fitEval(
       }
       *y=f;
       break;
+    case 2841:
+      a=r->p[1]*pow(x, r->p[2]) / (pow(x, r->p[2]) + r->p[3]);
+      f=1.0/(1.0-r->p[0]*(1.0-a));
+      *y=f;
+      break;
     case 3331: *y=nan(""); break; /* cannot be applied to one point only */
     case 9501: *y=nan(""); break; /* cannot be applied to one point only */
     case 9502: *y=nan(""); break; /* cannot be applied to one point only */
@@ -1569,3 +1705,88 @@ unsigned long long int lfactorial(
 /*****************************************************************************/
 
 /*****************************************************************************/
+/** Cumulative gamma distribution, or Regularized gamma function, more specifically, 
+    lower incomplete gamma function divided by gamma function.
+    @details Standard gamma distribution is assumed (Beta=1).
+    f(a,x) = (1/Gamma(a)) * Integral(0,x)(e^-t * t^(a-1))dt
+    @return Returns the value of regularized gamma function, or NaN in case of an error.
+    @sa igamc, inverfc, factorial
+ */
+double igam(
+  /** Shape parameter alpha; must be > 0. */
+  double a,
+  /** Integral from 0 to x; must be >= 0. */
+  double x
+) {
+  /* Check parameters */
+  if(x==0.0) return(0.0);
+  if((x<0.0) || (a<=0.0)) return(nan(""));
+
+  if((x>1.0) && (x>a)) return(1.0 - igamc(a, x));
+
+  /* Left tail of incomplete Gamma function:
+    x^a * e^-x * Sum(k=0,Inf)(x^k / Gamma(a+k+1)) */
+
+  double ans, ax, c, r;
+
+  /* Compute  x**a * exp(-x) / Gamma(a) */
+  ax=a*log(x) - x - lgamma(a);
+  if(ax<-DBL_MAX_10_EXP) return(0.0); // underflow
+  ax=exp(ax);
+
+  /* power series */
+  r=a; c=1.0; ans=1.0;
+  do {
+    r+=1.0;
+    c*=x/r;
+    ans+=c;
+  } while(c/ans > DBL_EPSILON);
+  return(ans*ax/a);
+}
+/*****************************************************************************/
+
+/*****************************************************************************/
+/** Regularized gamma function, more specifically, upper incomplete gamma function divided by 
+    gamma function.
+    @details f(a,x) = (1/Gamma(a)) * Integral(x,Inf)(e^-t * t^(a-1))dt
+    Standard gamma distribution is assumed (Beta=1).
+    @return Returns the value of regularized gamma function, or NaN in case of an error.
+    @sa igam, inverfc, factorial
+ */
+double igamc(
+  /** Shape parameter alpha; must be > 0. */
+  double a,
+  /** Integral from x to infinity; must be >= 0 */
+  double x
+) {
+  /* Check parameters */
+  if((x<0.0) || (a<=0.0)) return(nan(""));
+
+  if((x<1.0) || (x<a)) return(1.0-igam(a, x));
+
+  double ans, ax, c, yc, r, t, y, z;
+  double pk, pkm1, pkm2, qk, qkm1, qkm2;
+  double big=4.503599627370496E+015;
+  double biginv=2.22044604925031308085E-016;
+
+  ax = a*log(x) - x - lgamma(a);
+  if(ax < -DBL_MAX_10_EXP) return(0.0); // underflow
+  ax=exp(ax);
+
+  /* continued fraction */
+  y=1.0-a; z=x+y+1.0; c=0.0;
+  pkm2=1.0; qkm2=x; pkm1=x+1.0; qkm1=z*x;
+  ans=pkm1/qkm1;
+  do {
+    c+=1.0; y+=1.0; z+=2.0;
+    yc=y*c; pk=pkm1*z - pkm2*yc; qk=qkm1*z - qkm2*yc;
+    if(qk!=0.0) {r=pk/qk; t=fabs((ans-r)/r); ans=r;}
+    else t=1.0;
+    pkm2=pkm1; pkm1=pk; qkm2=qkm1; qkm1=qk;
+    if(fabs(pk)>big) {pkm2*=biginv; pkm1*=biginv; qkm2*=biginv; qkm1*=biginv;}
+  } while(t>DBL_EPSILON);
+  return(ans*ax);
+}
+/*****************************************************************************/
+
+/*****************************************************************************/
