@@ -858,7 +858,7 @@ int resWrite(
 /*****************************************************************************/
 /** Write calculation results into specied XHTML 1.1 file.
     If file exists, a backup file (+BACKUP_EXTENSION) is written also.
-    If "stdout" is given as filename, output is directed to stdout
+    If "stdout" is given as filename, output is directed to stdout.
    @return In case of an error, >0 is returned, and a description is written in reserrmsg.
    @sa resWrite
  */
@@ -1096,34 +1096,19 @@ int resWriteHTML_table(
     partype[j]=resParameterPrintType(res, j);
   }
 
-#if(0)
-  int rnameSubfields=resRNameSubfieldExists(res);
-#endif
-
   /* Write the result data to the table body */
   fprintf(fp, "<tbody>\n");
   /* Write the result title line */
-#if(1)
   fprintf(fp,"<tr align=left><th>Region</th>\n");
-#else
-  if(rnameSubfields==0)
-    fprintf(fp,"<tr align=left><th>Region</th>\n");
-  else
-    fprintf(fp,"<tr align=left><th>Region</th><th>Hemisphere</th><th>Plane</th>\n");
-#endif
   for(i=0; i<res->parNr; i++) fprintf(fp, "<th>%s</th>", res->parname[i]);
   fprintf(fp, "</tr>\n");
   /* Write regional results */
   for(i=0; i<res->voiNr; i++) {
     if(i%2) strcpy(tmp, "evenroi"); else strcpy(tmp, "oddroi");
     fprintf(fp, "<tr class=\"%s\">", tmp);
-    fprintf(fp, "<th>%s</th>", res->voi[i].name);
-#if(0)
-    if(rnameSubfields!=0) {
-      fprintf(fp, "<th>%s</th>", res->voi[i].hemisphere);
-      fprintf(fp, "<th>%s</th>", res->voi[i].place);
-    }
-#endif
+    char *senc=strEncodeForXML(res->voi[i].name);
+    if(senc==NULL) fprintf(fp, "<th>%s</th>", res->voi[i].name);
+    else {fprintf(fp, "<th>%s</th>", senc); free(senc);}
     p=res->voi[i].parameter;
     for(j=0; j<res->parNr; j++) switch(partype[j]) {
       case 0: fprintf(fp, "<td>%.0f</td>", p[j]); break;
@@ -1136,9 +1121,6 @@ int resWriteHTML_table(
     if(n>0) {
       fprintf(fp, "<tr class=\"sd\">");
       fprintf(fp, "<th>%s</th>", "SD");
-#if(0)
-      if(rnameSubfields!=0) fprintf(fp, "<th></th><th></th>");
-#endif
       for(j=0; j<res->parNr; j++) {
         if(!isnan(p[j])) switch(partype[j]) {
           case 0: fprintf(fp, "<td>%.0f</td>", p[j]); break;
@@ -1152,14 +1134,7 @@ int resWriteHTML_table(
     p=res->voi[i].cl1; for(j=n=0; j<res->parNr; j++) if(!isnan(p[j])) n++;
     if(n>0) {
       fprintf(fp, "<tr class=\"cl1\">");
-#if(1)
       fprintf(fp, "<th>CL95%%L</th>");
-#else
-      if(rnameSubfields!=0)
-        fprintf(fp, "<th>%s</th><th>%s</th><th>%s</th>", "CL", "95%", "Lower");
-      else
-        fprintf(fp, "<th>CL95%%L</th>");
-#endif
       for(j=0; j<res->parNr; j++) {
         if(!isnan(p[j])) switch(partype[j]) {
           case 0: fprintf(fp, "<td>%.0f</td>", p[j]); break;
@@ -1173,14 +1148,7 @@ int resWriteHTML_table(
     p=res->voi[i].cl2; for(j=n=0; j<res->parNr; j++) if(!isnan(p[j])) n++;
     if(n>0) {
       fprintf(fp, "<tr class=\"cl2\">");
-#if(1)
       fprintf(fp, "<th>CL95%%U</th>");
-#else
-      if(rnameSubfields!=0)
-        fprintf(fp, "<th>%s</th><th>%s</th><th>%s</th>", "CL", "95%", "Upper");
-      else
-        fprintf(fp, "<th>CL95%%U</th>");
-#endif
       for(j=0; j<res->parNr; j++) {
         if(!isnan(p[j])) switch(partype[j]) {
           case 0: fprintf(fp, "<td>%.0f</td>", p[j]); break;
