@@ -762,7 +762,7 @@ int dcmFileReadNextElement(
 
 /*****************************************************************************/
 /** Read a single DICOM file.
-    @sa dcmVerifyMagic, dcmfileInit, dcmfileFree, dcmReadTransferSyntaxUID, dcmFileWrite
+    @sa dcmVerifyMagic, dcmfileInit, dcmfileFree, dcmReadTransferSyntaxUID, dcmFileWrite, dcmFileList
     @return Code tpcerror, TPCERROR_OK (0) when successful.
  */
 int dcmFileRead(
@@ -846,7 +846,7 @@ int dcmFileRead(
 
 /*****************************************************************************/
 /** Write a single DICOM file. 
-    @sa dcmFileRead, dcmfileInit, dcmfileFree
+    @sa dcmFileRead, dcmfileInit, dcmfileFree, dcmFileRemove
     @return Code tpcerror, TPCERROR_OK (0) when successful.
  */
 int dcmFileWrite(
