@@ -389,7 +389,7 @@ int dcmMListRead(
           tag.group=0x0008; tag.element=0x0021;
           DCMITEM *jptr=dcmFindTag(dcm.item, 0, &tag, 0);
           if(jptr!=NULL) {
-            if(dcmDA2intl(iptr->rd, s2)!=NULL && dcmTM2intl(jptr->rd, s1)!=NULL)
+            if(dcmDA2intl(jptr->rd, s1)!=NULL && dcmTM2intl(iptr->rd, s2)!=NULL)
               sprintf(injDateTime, "%s %s", s1, s2);
           }
         }
