@@ -76,6 +76,8 @@ int main(
     fprintf(stderr, "failed (%d).\n", ret); return(i);}
   i++; if((ret=test_strChrCount(&status))!=0) {
     fprintf(stderr, "failed (%d).\n", ret); return(i);}
+  i++; if((ret=test_strUppercaseCount(&status))!=0) {
+    fprintf(stderr, "failed (%d).\n", ret); return(i);}
   i++; if((ret=test_strReplaceChar(&status))!=0) {
     fprintf(stderr, "failed (%d).\n", ret); return(i);}
 #ifndef HAVE_STRNDUP // Test only if own implementation is used
@@ -122,6 +124,10 @@ int main(
     fprintf(stderr, "failed (%d).\n", ret); return(i);}
   i++; if((ret=test_strTrimLeft(&status))!=0) {
     fprintf(stderr, "failed (%d).\n", ret); return(i);}
+  i++; if((ret=test_strEncodeForXML(&status))!=0) {
+    fprintf(stderr, "failed (%d).\n", ret); return(i);}
+  i++; if((ret=test_strCleanForXML(&status))!=0) {
+    fprintf(stderr, "failed (%d).\n", ret); return(i);}
 
   /* decpoint */
   i++; if((ret=test_strIsValidNumber(&status))!=0) {
