@@ -93,7 +93,7 @@ int strTokenNCpy(
     Search is case-sensitive.
     @author Vesa Oikonen
     @return Returns the nr of characters of s2 found in s1. 
-    @sa strReplaceChar, strstrNoQuotation
+    @sa strReplaceChar, strstrNoQuotation, strUppercaseCount
  */
 int strChrCount(
   /** String to search for characters; not modified. */
@@ -110,6 +110,22 @@ int strChrCount(
 }
 /*****************************************************************************/
 
+/*****************************************************************************/
+/** Count how many upper case characters are found in string. 
+    @return Returns the nr of upper case characters found in s. 
+    @sa strChrCount
+ */
+int strUppercaseCount(
+  /** String to search for upper case characters; not modified. */
+  const char *s
+) {
+  unsigned int n=0, i;
+  if(s==NULL || strlen(s)==0) return (int)n;
+  for(i=0; i<strlen(s); i++) if(isupper(s[i])) n++;
+  return (int)n;
+}
+/*****************************************************************************/
+
 /*****************************************************************************/
 /** Replace all characters c1 in string s with character c2.
     @sa strChrCount, strdelstr, strTrimleft, strstrNoQuotation
@@ -705,3 +721,62 @@ char *strTrimLeft(
 /*****************************************************************************/
 
 /*****************************************************************************/
+/** Encode special characters for XML, including SVG.
+    @post Free the memory of returned string pointer.
+    @return Returns pointer to encoded string.
+            NULL is returned in case of an error, or if encoding is not necessary.
+    @sa strCleanForXML
+ */
+char *strEncodeForXML(
+  /** Pointer to the string to be encoded. */
+  const char *s
+) {
+  if(s==NULL) return(NULL);
+  /* Count the characters needing encoding */
+  int n=0;
+  for(size_t i=0; i<strlen(s); i++) {
+    if(s[i]=='&') {n++; continue;}
+    if(s[i]=='\'') {n++; continue;}
+    if(s[i]=='\"') {n++; continue;}
+    if(s[i]=='<') {n++; continue;}
+    if(s[i]=='>') {n++; continue;}
+  }
+  if(n==0) return(NULL);
+  /* Allocate memory for new string (one char to max 6 chars) */
+  n*=5; n+=strlen(s);
+  char *ns=(char*)malloc(n*sizeof(char));
+  if(ns==NULL) return(NULL);
+  /* Process the string */
+  for(int i=0; i<n; i++) ns[i]=(char)0;
+  for(size_t i=0; i<strlen(s); i++) {
+    if(s[i]=='&') {strcat(ns, "&amp;"); continue;}
+    if(s[i]=='\'') {strcat(ns, "&apos;"); continue;}
+    if(s[i]=='\"') {strcat(ns, "&quot;"); continue;}
+    if(s[i]=='<') {strcat(ns, "&lt;"); continue;}
+    if(s[i]=='>') {strcat(ns, "&gt;"); continue;}
+    ns[strlen(ns)]=s[i];
+  }
+  return(ns);
+}
+/*****************************************************************************/
+
+/*****************************************************************************/
+/** Remove from string those characters that would require encoding in XML.
+    Replaced by character '-'. 
+    @sa strEncodeForXML
+ */
+void strCleanForXML(
+  /** Pointer to the string to be cleaned. */
+  char *s
+) {
+  if(s==NULL || *s=='\0') return;
+  strReplaceChar(s, '&', '-');
+  strReplaceChar(s, '\'', '-');
+  strReplaceChar(s, '\"', '-');
+  strReplaceChar(s, '<', '-');
+  strReplaceChar(s, '>', '-');
+  return;
+}
+/*****************************************************************************/
+
+/*****************************************************************************/
