@@ -186,6 +186,63 @@ int test_strChrCount(
 }
 /*****************************************************************************/
 
+/*****************************************************************************/
+int test_strUppercaseCount(
+  TPCSTATUS *status
+) {
+  int verbose=0; if(status!=NULL) verbose=status->verbose;
+  statusSet(status, __func__, __FILE__, __LINE__, 0);
+  if(verbose>0) {
+    printf("\n=====================================\n");
+    printf("\n%s\n", __func__);
+    printf("\n=====================================\n");
+  }
+
+  char str1[256];
+  int n;
+
+  n=strUppercaseCount(NULL); if(verbose>2) printf("  -> n := %d\n", n);
+  if(n!=0) return(1);
+
+  strcpy(str1, "");
+  if(verbose>1) printf("str1 := '%s'\n", str1);
+  n=strUppercaseCount(str1); if(verbose>2) printf("  -> n := %d\n", n);
+  if(n!=0) return(2);
+
+  strcpy(str1, "   ");
+  if(verbose>1) printf("str1 := '%s'\n", str1);
+  n=strUppercaseCount(str1); if(verbose>2) printf("  -> n := %d\n", n);
+  if(n!=0) return(3);
+
+  strcpy(str1, "Bim, Bam, Bum");
+  if(verbose>1) printf("str1 := '%s'\n", str1);
+  n=strUppercaseCount(str1); if(verbose>2) printf("  -> n := %d\n", n);
+  if(n!=3) return(4);
+
+  strcpy(str1, "Bim, bam, bum");
+  if(verbose>1) printf("str1 := '%s'\n", str1);
+  n=strUppercaseCount(str1); if(verbose>2) printf("  -> n := %d\n", n);
+  if(n!=1) return(5);
+
+  strcpy(str1, "abCdefghijKlmnopQRstuvwxyZ");
+  if(verbose>1) printf("str1 := '%s'\n", str1);
+  n=strUppercaseCount(str1); if(verbose>2) printf("  -> n := %d\n", n);
+  if(n!=5) return(6);
+
+  strcpy(str1, "  v := 1.0E-003");
+  if(verbose>1) printf("str1 := '%s'\n", str1);
+  n=strUppercaseCount(str1); if(verbose>2) printf("  -> n := %d\n", n);
+  if(n!=1) return(7);
+
+  strcpy(str1, "  v := 1,0e-003");
+  if(verbose>1) printf("str1 := '%s'\n", str1);
+  n=strUppercaseCount(str1); if(verbose>2) printf("  -> n := %d\n", n);
+  if(n!=0) return(8);
+  
+  return(0);
+}
+/*****************************************************************************/
+
 /*****************************************************************************/
 int test_strReplaceChar(
   TPCSTATUS *status
@@ -1497,3 +1554,111 @@ int test_strTrimLeft(
 /*****************************************************************************/
 
 /*****************************************************************************/
+int test_strEncodeForXML(
+  TPCSTATUS *status
+) {
+  int verbose=0; if(status!=NULL) verbose=status->verbose;
+  statusSet(status, __func__, __FILE__, __LINE__, 0);
+  if(verbose>0) {
+    printf("\n=====================================\n");
+    printf("\n%s\n", __func__);
+    printf("\n=====================================\n");
+  }
+
+  if(verbose>1) {printf("testing with NULL\n"); fflush(stdout);}
+  if(strEncodeForXML(NULL)!=NULL) return(1);
+
+  char s1[256], s2[256];
+
+  if(verbose>1) {printf("testing with strings that do not need encoding\n"); fflush(stdout);}
+
+  strcpy(s1, ""); if(strEncodeForXML(s1)!=NULL) return(2);
+  strcpy(s1, " "); if(strEncodeForXML(s1)!=NULL) return(3);
+  strcpy(s1, "abcdefg"); if(strEncodeForXML(s1)!=NULL) return(4);
+
+  char *so;
+
+  if(verbose>1) {printf("testing with strings that need encoding\n"); fflush(stdout);}
+
+  strcpy(s1, "a&b"); strcpy(s2, "a&amp;b"); so=strEncodeForXML(s1);
+  if(so==NULL) return(11);
+  if(verbose>1) {printf("s1='%s' -> '%s'\n", s1, so); fflush(stdout);}
+  if(strcmp(so, s2)!=0) {free(so); return(11);}
+  free(so); 
+
+  strcpy(s1, "a<b; c>b"); strcpy(s2, "a&lt;b; c&gt;b"); so=strEncodeForXML(s1);
+  if(so==NULL) return(12);
+  if(verbose>1) {printf("s1='%s' -> '%s'\n", s1, so); fflush(stdout);}
+  if(strcmp(so, s2)!=0) {free(so); return(12);}
+  free(so); 
+
+  strcpy(s1, "str='ABC'"); strcpy(s2, "str=&apos;ABC&apos;"); so=strEncodeForXML(s1);
+  if(so==NULL) return(13);
+  if(verbose>1) {printf("s1='%s' -> '%s'\n", s1, so); fflush(stdout);}
+  if(strcmp(so, s2)!=0) {free(so); return(13);}
+  free(so); 
+
+  strcpy(s1, "str=\"ABC\""); strcpy(s2, "str=&quot;ABC&quot;"); so=strEncodeForXML(s1);
+  if(so==NULL) return(14);
+  if(verbose>1) {printf("s1='%s' -> '%s'\n", s1, so); fflush(stdout);}
+  if(strcmp(so, s2)!=0) {free(so); return(14);}
+  free(so); 
+
+  return(0);
+}
+/*****************************************************************************/
+
+/*****************************************************************************/
+int test_strCleanForXML(
+  TPCSTATUS *status
+) {
+  int verbose=0; if(status!=NULL) verbose=status->verbose;
+  statusSet(status, __func__, __FILE__, __LINE__, 0);
+  if(verbose>0) {
+    printf("\n=====================================\n");
+    printf("\n%s\n", __func__);
+    printf("\n=====================================\n");
+  }
+
+  if(verbose>1) {printf("testing with NULL\n"); fflush(stdout);}
+  strCleanForXML(NULL);
+
+  char s1[256], s2[256];
+
+  if(verbose>1) {printf("testing with strings that do not need encoding\n"); fflush(stdout);}
+
+  strcpy(s1, ""); strcpy(s2, ""); strCleanForXML(s1);
+  if(verbose>1) {printf("s1='%s' -> '%s'\n", s1, s2); fflush(stdout);}
+  if(strcmp(s1, s2)!=0) return(2);
+
+  strcpy(s1, " "); strcpy(s2, " "); strCleanForXML(s1);
+  if(verbose>1) {printf("s1='%s' -> '%s'\n", s1, s2); fflush(stdout);}
+  if(strcmp(s1, s2)!=0) return(3);
+
+  strcpy(s1, "abcdef"); strcpy(s2, "abcdef"); strCleanForXML(s1);
+  if(verbose>1) {printf("s1='%s' -> '%s'\n", s1, s2); fflush(stdout);}
+  if(strcmp(s1, s2)!=0) return(4);
+
+  if(verbose>1) {printf("testing with strings that need encoding\n"); fflush(stdout);}
+
+  strcpy(s1, "a&b"); strcpy(s2, "a-b"); strCleanForXML(s1);
+  if(verbose>1) {printf("s1='%s' -> '%s'\n", s1, s2); fflush(stdout);}
+  if(strcmp(s1, s2)!=0) return(11);
+
+  strcpy(s1, "a<b; c>b"); strcpy(s2, "a-b; c-b"); strCleanForXML(s1);
+  if(verbose>1) {printf("s1='%s' -> '%s'\n", s1, s2); fflush(stdout);}
+  if(strcmp(s1, s2)!=0) return(12);
+
+  strcpy(s1, "str='ABC'"); strcpy(s2, "str=-ABC-"); strCleanForXML(s1);
+  if(verbose>1) {printf("s1='%s' -> '%s'\n", s1, s2); fflush(stdout);}
+  if(strcmp(s1, s2)!=0) return(13);
+
+  strcpy(s1, "str=\"ABC\""); strcpy(s2, "str=-ABC-"); strCleanForXML(s1);
+  if(verbose>1) {printf("s1='%s' -> '%s'\n", s1, s2); fflush(stdout);}
+  if(strcmp(s1, s2)!=0) return(14);
+
+  return(0);
+}
+/*****************************************************************************/
+
+/*****************************************************************************/
