@@ -27,6 +27,40 @@ int test_mfEvalY(
   if(verbose>2) printf(" good, did not crash \n");
   if(ret==0) return(2);
 
+  {
+    char *fid="level";
+    if(verbose>1) printf("\n testing '%s' \n", fid);
+    double p[]={1.0};
+    int i, n=3;
+    double x[]={-1.0, 1.0, 10.0};
+    double y[n];
+    double cy[]={1.0, 1.0, 1.0};
+    ret=mfEvalY(fid, 1, p, n, x, y, verbose-2);
+    if(ret!=0) return(11);
+    for(i=0; i<n; i++) {
+      if(verbose>3) printf("  %g :  %g vs %g \n", x[i], cy[i], y[i]);
+      if(!doubleMatch(cy[i], y[i], 1.0E-06)) return(12);
+    }
+    if(verbose>2) printf("\n ok \n");
+  }
+
+  {
+    char *fid="step";
+    if(verbose>1) printf("\n testing '%s' \n", fid);
+    double p[]={0.0, 1.0, 10.0, 0.0, 20.0, 1.0, 30.0, 0.0};
+    int i, n=5;
+    double x[]={0.0, 1.0, 11.0, 29.0, 31.0};
+    double y[n];
+    double cy[]={1.0, 1.0, 0.0, 1.0, 0.0};
+    ret=mfEvalY(fid, 8, p, n, x, y, verbose-2);
+    if(ret!=0) return(13);
+    for(i=0; i<n; i++) {
+      if(verbose>3) printf("  %g :  %g vs %g \n", x[i], cy[i], y[i]);
+      if(!doubleMatch(cy[i], y[i], 1.0E-06)) return(14);
+    }
+    if(verbose>2) printf("\n ok \n");
+  }
+
   {
     char *fid="fengm2";
     if(verbose>1) printf("\n testing '%s' with zero delay \n", fid);
