@@ -75,7 +75,7 @@ char *imgDefaultExtension(
 
 /*****************************************************************************/
 /** Read image file into IMG structure.
-    @remark Stub function.
+    @remark Stub function, mostly.
     @sa imgInit, imgWrite, imgFree
     @return enum tpcerror (TPCERROR_OK when successful).
  */
@@ -157,10 +157,11 @@ int imgRead(
     /* Check if we have NIfTI file, which may be in single file format,
        or dual file format which has similar names as microPET and Analyze */
     if(niftiExists(fname, NULL, NULL, NULL, NULL, status)==1) {
+      if(verbose>2) printf("%s is in NIfTI format.\n", fname);
       /* Read NIfTI image */
-      /*if(verbose>2)*/ printf("%s is in NIfTI format.\n", fname);
-      statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_UNSUPPORTED);
-      return(TPCERROR_UNSUPPORTED);
+      return(imgReadNifti(img, fname, status));
+      /*statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_UNSUPPORTED);
+      return(TPCERROR_UNSUPPORTED);*/
     }
     /* Check if we have Analyze file, which may be in dual file format which 
        has similar names as microPET and dual-file NIfTI */
