@@ -11,7 +11,7 @@
 
 /*****************************************************************************/
 /** Construct the file names for NIfTI image.
-
+   @sa imgReadNifti, imgWriteNifti, niftiRemoveFNameExtension
    @return enum tpcerror (TPCERROR_OK when successful).
  */
 int niftiCreateFNames(
@@ -29,7 +29,8 @@ int niftiCreateFNames(
   /** SIF filename will be written in this char pointer (space needs to allocated by caller);
       enter NULL if not needed. */
   char *siffile,
-  /** NIfTI file format, either IMG_NIFTI_1D, IMG_NIFTI_1S, IMG_NIFTI_2D, or IMG_NIFTI_2S. */
+  /** NIfTI file format, either IMG_FORMAT_NIFTI_1D, IMG_FORMAT_NIFTI_1S, IMG_NIFTI_FORMAT_2D, or 
+      IMG_FORMAT_NIFTI_2S. */
   int fileformat
 ) {
   if(hdrfile!=NULL) strcpy(hdrfile, "");
@@ -62,8 +63,10 @@ int niftiCreateFNames(
 
 /*****************************************************************************/
 /** Read NIfTI into IMG data structure.
+    @note NIfTI may have missing pixel values (NaNs), remove those with imgNaNs(IMG, 1) 
+     when necessary.
     @todo Add tests.
-    @sa imgInit, imgRead, imgWrite, imgFree
+    @sa imgInit, imgRead, imgWrite, imgFree, imgNaNs, niftiCreateFNames
     @return enum tpcerror (TPCERROR_OK when successful).
  */
 int imgReadNifti(
@@ -81,7 +84,6 @@ int imgReadNifti(
     statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_FAIL);
     return(TPCERROR_FAIL);
   }
-
   /* Delete any old contents in data structure */
   imgFree(img);
 
@@ -136,18 +138,30 @@ int imgReadNifti(
     statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_UNSUPPORTED);
     return(TPCERROR_UNSUPPORTED);
   }
+  int bytepix=bitpix/8; if(verbose>2) printf("  bytes per pixel := %d\n", bytepix);
+
+
+  /* Allocate memory for 4D image */
+  {
+  int ret=imgGetNiftiHeader(img, &dsr, verbose-1); // Get the image dimensions
+  if(ret!=TPCERROR_OK) {
+    statusSet(status, __func__, __FILE__, __LINE__, ret);
+    return(ret);
+  }
+  if(verbose>1) printf("allocating memory for 4D image\n");
+  ret=imgAllocate(img, img->dimz, img->dimy, img->dimx, img->dimt, status);
+  if(ret) return(ret);
+  }
 
   /* Copy header contents into IMG structure */
+  {
   int ret=imgGetNiftiHeader(img, &dsr, verbose-1);
   if(ret!=TPCERROR_OK) {
     statusSet(status, __func__, __FILE__, __LINE__, ret);
     return(ret);
   }
-
-  /* Allocate memory for 4D image */
-  if(verbose>1) printf("allocating memory for 4D image\n");
-  ret=imgAllocate(img, img->dimz, img->dimy, img->dimx, img->dimt, status);
-  if(ret) return(ret);
+  if(verbose>2) printf("format: %s\n", imgFormatDescr(img->format));
+  }
 
   /* Open file */
   if(verbose>1) printf("reading pixel data in %s\n", imgfile);
@@ -158,14 +172,18 @@ int imgReadNifti(
     return(TPCERROR_CANNOT_OPEN);
   }
 
-  /* Set intial read position.
+
+  /* Set initial read position.
      Get the image data start location from header, in case of single file format */
   long long start_pos=0;
   {
     long long int s=0;
-    if(img->format==IMG_FORMAT_NIFTI_1D) s=(int)dsr.h1.vox_offset;
-    else if(img->format==IMG_FORMAT_NIFTI_2D) s=(int)dsr.h2.vox_offset;
+    if(dsr.n==1) s=(int)dsr.h1.vox_offset; else s=(int)dsr.h2.vox_offset;
     if(s<0) start_pos=-s; else start_pos=s;
+    /* Check that start location is not earlier than it can by definition; it can be later, though */
+    if(img->format==IMG_FORMAT_NIFTI_1S && s<NIFTI1_HEADER_SIZE) s=NIFTI1_HEADER_SIZE;
+    else if(img->format==IMG_FORMAT_NIFTI_2S && s<NIFTI2_HEADER_SIZE) s=NIFTI2_HEADER_SIZE;
+    start_pos=s;
   }
   if(verbose>2) printf("  image_start_pos := %llu\n", start_pos);
   /* Seek the data position, jumping over possible header */
@@ -206,7 +224,7 @@ int imgReadNifti(
   if(scl_slope==0.0) scl_slope=1.0;
 
   for(int ti=0; ti<img->dimt; ti++) {
-    if(verbose>2) printf("  frame %d\n", 1+ti);
+    if(verbose>3) printf("  frame %d\n", 1+ti);
     if(fread(buf, rawSize, 1, fp) < 1) {
       fclose(fp); imgFree(img); free(buf);
       statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_CANNOT_READ);
@@ -221,7 +239,7 @@ int imgReadNifti(
       default: /* others not supported */ break;
     }
     /* Copy data to float pixel values */
-    ret=0;
+    int ret=0;
     unsigned char *bptr=buf;
     switch(datatype) {
       case NIFTI_DT_UNSIGNED_CHAR:
@@ -242,7 +260,7 @@ int imgReadNifti(
               uint16_t a;
               memcpy(&a, bptr, 2);
               img->m[zi][yi][xi][ti]=scl_inter+scl_slope*(float)a;
-              bptr++;
+              bptr+=bytepix;
             }
         break;
       case NIFTI_DT_SIGNED_SHORT:
@@ -253,7 +271,7 @@ int imgReadNifti(
               int16_t a;
               memcpy(&a, bptr, 2);
               img->m[zi][yi][xi][ti]=scl_inter+scl_slope*(float)a;
-              bptr++;
+              bptr+=bytepix;
             }
         break;
       case NIFTI_DT_SIGNED_INT:
@@ -264,7 +282,7 @@ int imgReadNifti(
               int32_t a;
               memcpy(&a, bptr, 4);
               img->m[zi][yi][xi][ti]=scl_inter+scl_slope*(float)a;
-              bptr++;
+              bptr+=bytepix;
             }
         break;
       case NIFTI_DT_UNSIGNED_INT:
@@ -275,7 +293,7 @@ int imgReadNifti(
               uint32_t a;
               memcpy(&a, bptr, 4);
               img->m[zi][yi][xi][ti]=scl_inter+scl_slope*(float)a;
-              bptr++;
+              bptr+=bytepix;
             }
         break;
       case NIFTI_DT_LONG_LONG:
@@ -286,7 +304,7 @@ int imgReadNifti(
               int64_t a;
               memcpy(&a, bptr, 8);
               img->m[zi][yi][xi][ti]=scl_inter+scl_slope*(float)a;
-              bptr++;
+              bptr+=bytepix;
             }
         break;
       case NIFTI_DT_UNSIGNED_LONG_LONG:
@@ -297,7 +315,7 @@ int imgReadNifti(
               uint64_t a;
               memcpy(&a, bptr, 8);
               img->m[zi][yi][xi][ti]=scl_inter+scl_slope*(float)a;
-              bptr++;
+              bptr+=bytepix;
             }
         break;
       case NIFTI_DT_FLOAT:
@@ -308,7 +326,7 @@ int imgReadNifti(
               float a;
               memcpy(&a, bptr, 4);
               img->m[zi][yi][xi][ti]=scl_inter+scl_slope*a;
-              bptr++;
+              bptr+=bytepix;
             }
         break;
       case NIFTI_DT_DOUBLE:
@@ -319,7 +337,7 @@ int imgReadNifti(
               double a;
               memcpy(&a, bptr, 8);
               img->m[zi][yi][xi][ti]=scl_inter+scl_slope*(float)a;
-              bptr++;
+              bptr+=bytepix;
             }
         break;
       default:
@@ -363,7 +381,7 @@ int imgReadNifti(
    SIF file is saved to store frame times, if frame times are available.
 
    @todo Add tests.
-   @sa imgInit, imgRead, imgWrite, imgFree
+   @sa imgInit, imgRead, imgWrite, imgFree, niftiCreateFNames, niftiWriteHeader
    @return enum tpcerror (TPCERROR_OK when successful).
  */
 int imgWriteNifti(
@@ -541,7 +559,7 @@ int imgWriteNifti(
 /*****************************************************************************/
 
 /*****************************************************************************/
-/** Copy header information in IMG structure into NIfTI header struct.
+/** Copy header information in IMG structure into NIfTI header structure.
 
     Header contents will depend on the output format as specified in IMG->oformat,
     which can be set to IMG_FORMAT_NIFTI_1D, IMG_FORMAT_NIFTI_1S,
@@ -549,14 +567,13 @@ int imgWriteNifti(
     NIFTI_DSR->n will tell whether NIfTI-1 or NIfTI-2 header was filled.
 
    @todo Add tests.
-   @sa imgGetNiftiHeader, imgWriteNifti
+   @sa imgGetNiftiHeader, imgWriteNifti, niftiWriteHeader
    @return enum tpcerror (TPCERROR_OK when successful).
  */
 int imgSetNiftiHeader(
   /** Pointer to IMG structure from which header information is read. */
   IMG *img,
-  /** Pointer to NIfTI header structure to be filled; any previous contents
-      are removed. */
+  /** Pointer to NIfTI header structure to be filled; any previous contents are removed. */
   NIFTI_DSR *dsr,
   /** Verbose level; if zero, then nothing is printed to stderr or stdout. */
   int verbose
@@ -803,8 +820,7 @@ int imgGetNiftiHeader(
   if(dsr->n==1) dimNr=dsr->h1.dim[0]; else dimNr=dsr->h2.dim[0];
   if(dimNr<2 || dimNr>8) return(TPCERROR_INVALID_HEADER);
   if(dimNr>4) {
-    if(verbose>0)
-      fprintf(stderr, "Error: NIfTI image dimension %d is not supported\n", dimNr);
+    if(verbose>0) fprintf(stderr, "Error: NIfTI image dimension %d is not supported\n", dimNr);
     return(TPCERROR_UNSUPPORTED);
   }
 
