@@ -10,9 +10,9 @@
 /** Read ECAT 7 image, volume or 2D sinogram.
  
  @return 0 if ok, 1 invalid input, 2 image status is not 'initialized', 
-  3 failed to open file fiel for reading, 4 recognize file,
+  3 failed to open file field for reading, 4 recognize file,
   5 file type not supported, 6 invalid matrix list,
-  7 invalid number of matrixes/frames, 8 variable matrix size,
+  7 invalid number of matrices/frames, 8 variable matrix size,
   9 failed to read header, 11 failed to allocate memory for data, 
   13 failed to read data.
  */
@@ -475,7 +475,7 @@ int imgWriteEcat7(const char *fname, IMG *img) {
     for(int pi=0; pi<img->dimz; pi++)
       for(int yi=0; yi<img->dimy; yi++)
         for(int xi=0; xi<img->dimx; xi++)
-          *fptr++=img->m[pi][yi][xi][fi];
+          if(isfinite(img->m[pi][yi][xi][fi])) *fptr++=img->m[pi][yi][xi][fi]; else *fptr++=0.0;
 
     /* Write subheader and data */
     fptr=fdata;
@@ -489,8 +489,7 @@ int imgWriteEcat7(const char *fname, IMG *img) {
       ret=ecat7WriteScanMatrix(fp, matrixId, &scan_header, fptr);
     } else if(img->type==IMG_TYPE_IMAGE) {
       image_header.frame_start_time=(int)temp_roundf(1000.*img->start[fi]);
-      image_header.frame_duration=
-        (int)temp_roundf(1000.*(img->end[fi]-img->start[fi]));
+      image_header.frame_duration=(int)temp_roundf(1000.*(img->end[fi]-img->start[fi]));
       if(img->decayCorrection==IMG_DC_CORRECTED)
         image_header.decay_corr_fctr=img->decayCorrFactor[fi];
       else
@@ -612,7 +611,7 @@ int imgWrite2DEcat7(const char *fname, IMG *img) {
     fptr=fdata;
     for(int yi=0; yi<img->dimy; yi++)
       for(int xi=0; xi<img->dimx; xi++)
-        *fptr++=img->m[pi][yi][xi][fi];
+        if(isfinite(img->m[pi][yi][xi][fi])) *fptr++=img->m[pi][yi][xi][fi]; else *fptr++=0.0;
 
     /* Write subheader and data */
     fptr=fdata;
@@ -711,7 +710,7 @@ int imgWritePolarmap(const char *fname, IMG *img) {
     for(int pi=0; pi<img->dimz; pi++)
       for(int yi=0; yi<img->dimy; yi++)
         for(int xi=0; xi<img->dimx; xi++)
-          *fptr++=img->m[pi][yi][xi][fi];
+          if(isfinite(img->m[pi][yi][xi][fi])) *fptr++=img->m[pi][yi][xi][fi]; else *fptr++=0.0;
 
     /* Write subheader and data */
     fptr=fdata;
@@ -1405,7 +1404,7 @@ int imgWriteEcat7Frame(
   for(int zi=0; zi<img->dimz; zi++)
     for(int yi=0; yi<img->dimy; yi++)
       for(int xi=0; xi<img->dimx; xi++)
-        *fptr++=img->m[zi][yi][xi][frame_index];
+        if(isfinite(img->m[zi][yi][xi][frame_index])) *fptr++=img->m[zi][yi][xi][frame_index]; else *fptr++=0.0;
 
   /* Write subheader and data, and set the rest of subheader contents */
   fptr=fdata; ret=-1;
