@@ -36,7 +36,6 @@ int imgRead(
   ECAT7_mainheader ecat7_main_header;
   ECAT63_mainheader ecat63_main_header;
   char temp[FILENAME_MAX];
-  //char *cptr;
 
   if(IMG_TEST) {printf("imgRead(%s, *img)\n", fname); fflush(stdout);}
   /* Check the arguments */
@@ -72,8 +71,7 @@ int imgRead(
     ret=imgReadAnalyze(temp, img);
     if(IMG_TEST) {printf("imgReadAnalyze() := %d\n", ret); fflush(stdout);}
     if(ret==STATUS_OK) {
-      if(IMG_TEST) printf("%s identified as supported Analyze 7.5 format.\n",
-        fname);
+      if(IMG_TEST) printf("%s identified as supported Analyze 7.5 format.\n", fname);
       img->statmsg=imgStatus(STATUS_OK);
       return(0);
     }
@@ -257,8 +255,7 @@ int imgReadHeader(
 
 /*****************************************************************************/
 /*!
-   Read one time frame from a supported PET image or sinogram file into
-   IMG data structure.
+   Read one time frame from a supported PET image or sinogram file into IMG data structure.
 
    This functions can be called repeatedly to read all
    the frames one at a time to conserve memory.
@@ -283,16 +280,14 @@ int imgReadFrame(
       If not occupied, then memory is allocated here. */
   IMG *img,
   /** IMG frame index (0..dimt-1) where data will be placed.
-      If index is >0, then the memory for that frame must be allocated before
-      calling this function. */
+      If index is >0, then the memory for that frame must be allocated before calling this function. */
   int frame_index
 ) {
   IMG test_img;
   int ret=0;
 
   if(IMG_TEST) {
-    printf("\nimgReadFrame(%s, %d, *img, %d)\n",
-           fname, frame_to_read, frame_index);
+    printf("\nimgReadFrame(%s, %d, *img, %d)\n", fname, frame_to_read, frame_index);
     fflush(stdout);
   }
   /*
@@ -300,8 +295,7 @@ int imgReadFrame(
    */
   if(fname==NULL) return STATUS_FAULT;
   if(img==NULL) return STATUS_FAULT;
-  if(img->status!=IMG_STATUS_INITIALIZED && img->status!=IMG_STATUS_OCCUPIED)
-    return STATUS_FAULT;
+  if(img->status!=IMG_STATUS_INITIALIZED && img->status!=IMG_STATUS_OCCUPIED) return STATUS_FAULT;
   if(frame_to_read<1) return STATUS_FAULT;
   if(frame_index<0) return STATUS_FAULT;
   /* if frame_index>0, then there must be sufficient memory allocated for it */
@@ -319,8 +313,7 @@ int imgReadFrame(
   if(img->status==IMG_STATUS_OCCUPIED) {
     ret=imgReadHeader(fname, &test_img, img->_fileFormat); 
     imgSetStatus(&test_img, ret);
-    if(IMG_TEST>1)
-      printf("imgReadHeader() return message := %s\n", test_img.statmsg);
+    if(IMG_TEST>1) printf("imgReadHeader() return message := %s\n", test_img.statmsg);
     if(ret) return(ret);
     if(IMG_TEST>3) imgInfo(&test_img);
     /* Test that file format and type are the same */
@@ -335,8 +328,7 @@ int imgReadFrame(
   } else {
     ret=imgReadHeader(fname, img, IMG_UNKNOWN);
     imgSetStatus(img, ret);
-    if(IMG_TEST>1)
-      printf("imgReadHeader() return message := %s\n", img->statmsg);
+    if(IMG_TEST>1) printf("imgReadHeader() return message := %s\n", img->statmsg);
     if(ret) return(ret);
     if(IMG_TEST>3) imgInfo(img);
     /* Allocate memory for one frame */
@@ -383,8 +375,7 @@ int imgReadFrame(
 /*****************************************************************************/
 
 /*****************************************************************************/
-/** Write one PET frame from IMG data struct into a supported PET image or
-    sinogram file. 
+/** Write one PET frame from IMG data struct into a supported PET image or sinogram file. 
 
     This function can be called repeatedly to write all
     frames one at a time to conserve memory.
@@ -410,9 +401,9 @@ int imgWriteFrame(
       If >0, then frame data is written as specified frame number, overwriting
       any data existing with the same frame number */
   int frame_to_write,
-  /** Pointer to the IMG data struct */
+  /** Pointer to the IMG data structure. */
   IMG *img,
-  /** IMG frame index (0..dimt-1) which will be written */
+  /** IMG frame index (0..dimt-1) which will be written. */
   int frame_index
 ) {
   int ret=0;
@@ -490,8 +481,7 @@ int imgWriteFrame(
    @sa imgRead, imgWrite
  */
 void imgFormatFromFName(
-  /** Target image structure where file format is saved;
-      should have IMG_UNKNOWN as file type. */
+  /** Target image structure where file format is saved; should have IMG_UNKNOWN as file type. */
   IMG *img,
   /** Name of file that is used to determine format. */
   const char *fname
@@ -500,8 +490,7 @@ void imgFormatFromFName(
 
   if(IMG_TEST>2) printf("imgFormatFromFName(img, %s)\n", fname);
   if(img->_fileFormat!=IMG_UNKNOWN && img->_fileFormat>0) {
-    if(IMG_TEST>3)
-      printf("  _fileFormat := %d, not changed\n", img->_fileFormat);
+    if(IMG_TEST>3) printf("  _fileFormat := %d, not changed\n", img->_fileFormat);
     return;
   }
   img->_fileFormat=IMG_E7; /* default */
@@ -542,37 +531,35 @@ void imgFormatFromFName(
     not at all supported by other library functions.
     
     @sa imgRead, imgWrite, imgReadHeader
-    @return Returns 0 when no errors occurred, which does not mean that format
-    was identified.
+    @return Returns 0 when no errors occurred, which does not mean that format was identified.
  */
 int imgFormatDetermine(
-  /** Full name of image file. In case of Analyze or microPET image, hdr or img
-   *  file name, or basename without extension is accepted. Pathname is not
-   *  accepted. */
+  /** Full name of image file. In case of Analyze or microPET image, hdr or img file name, or 
+      basename without extension is accepted. Pathname is not accepted. */
   const char *fname,
   /** Pointer to allocated string where image file name without extensions
-   *  is written (only for Analyze and microPET); enter NULL, if not needed. */ 
+      is written (only for Analyze and microPET); enter NULL, if not needed. */ 
   char *basename,
   /** Pointer to allocated string where header file name without extensions
-   *  is written (only for Analyze and microPET); enter NULL, if not needed. */ 
+      is written (only for Analyze and microPET); enter NULL, if not needed. */ 
   char *hdrfile,
   /** Pointer to allocated string where image data file name without extensions
-   *  is written (only for Analyze and microPET); enter NULL, if not needed. */ 
+      is written (only for Analyze and microPET); enter NULL, if not needed. */ 
   char *imgfile,
   /** Pointer to allocated string where SIF file name without extensions
-   *  is written (only for Analyze), if available; enter NULL, if not needed. */ 
+      is written (only for Analyze), if available; enter NULL, if not needed. */ 
   char *siffile,
   /** Pointer to int where image format ID is written; 0=unknown, for other
-   *  formats see definitions in img.h */
+      formats see definitions in img.h */
   int *file_format,
   /** Pointer to int where scanner ID is written; 0=unknown, for other
-   *  formats see definitions in img.h */
+      formats see definitions in img.h */
   int *scanner,
   /** Pointer to int where image type is written; 0=unknown, 1=image,
-   *  2=sinogram, 3=polarmap, please check definitions in img.h */
+      2=sinogram, 3=polarmap, please check definitions in img.h */
   int *type,
   /** Pointer to int where modality is written; 0=unknown, 1=PET,
-   *  2=MRI, 3=CT, ..., please check definitions in img.h */
+      2=MRI, 3=CT, ..., please check definitions in img.h */
   int *modality,
   /** Verbose level; if zero, then nothing is printed into stdout or stderr */
   int verbose
@@ -582,10 +569,7 @@ int imgFormatDetermine(
   NIFTI_DSR nifti_dsr;
   IMG img;
 
-  if(verbose>0) {
-    printf("imgFormatDetermine(\"%s\", ...)\n", fname);
-    fflush(stdout);
-  }
+  if(verbose>0) {printf("imgFormatDetermine(\"%s\", ...)\n", fname); fflush(stdout);}
   /* Initiate results */
   if(basename!=NULL) strcpy(basename, "");
   if(hdrfile!=NULL) strcpy(hdrfile, "");
@@ -605,25 +589,21 @@ int imgFormatDetermine(
     /* Try to add .nii to the name */
     sprintf(temp, "%s.nii", fname);
     if(access(temp, 0) == -1) {
-      if(verbose>1)
-        printf("  file is not accessible with .nii extension.\n");
+      if(verbose>1) printf("  file is not accessible with .nii extension.\n");
       /* Try to add .img to the name */
       sprintf(temp, "%s.img", fname);
       if(access(temp, 0) == -1) {
-        if(verbose>1)
-          printf("  file is not accessible with .img extension.\n");
+        if(verbose>1) printf("  file is not accessible with .img extension.\n");
         /* Try to add .hdr to the name */
         sprintf(temp, "%s.hdr", fname);
         if(access(temp, 0) == -1) sprintf(temp, "%s.i.hdr", fname);
         if(access(temp, 0) == -1) sprintf(temp, "%s.img.hdr", fname);
         if(access(temp, 0) == -1) {
-          if(verbose>1)
-            printf("  file is not accessible with .hdr extension.\n");
+          if(verbose>1) printf("  file is not accessible with .hdr extension.\n");
           /* Try to add .dcm to the name */
           sprintf(temp, "%s.dcm", fname);
           if(access(temp, 0) == -1) {
-            if(verbose>1)
-              printf("  file is not accessible with .dcm extension.\n");
+            if(verbose>1) printf("  file is not accessible with .dcm extension.\n");
             return STATUS_NOFILE;
           }
         }
@@ -674,8 +654,8 @@ int imgFormatDetermine(
      this must be done before trying Analyze, because dual format NIfTI
      is compatible with Analyze format */
   if(fformat==IMG_UNKNOWN &&
-     niftiExists(fname, hdrfile, imgfile, siffile, &nifti_dsr,
-                 verbose-2, NULL)>0) {
+     niftiExists(fname, hdrfile, imgfile, siffile, &nifti_dsr, verbose-2, NULL)>0)
+  {
     if(verbose>1) printf("file was identified to be in NIfTI format.\n");
     /* Read NIfTI header information into IMG struct */
     ret=imgGetNiftiHeader(&img, &nifti_dsr, verbose-2);
@@ -696,8 +676,7 @@ int imgFormatDetermine(
   }
 
   /* If format was not yet identified, then try to read it as Analyze */
-  if(fformat==IMG_UNKNOWN &&
-     anaDatabaseExists(fname, hdrfile, imgfile, siffile)>0) {
+  if(fformat==IMG_UNKNOWN && anaDatabaseExists(fname, hdrfile, imgfile, siffile)>0) {
     if(verbose>1) printf("file was identified to be in Analyze format.\n");
     fformat=IMG_ANA; if(file_format!=NULL) *file_format=fformat;
     /* Read Analyze header information */
@@ -716,8 +695,7 @@ int imgFormatDetermine(
   }
 
   /* If format was not yet identified, check if it is Interfile */
-  if(fformat==IMG_UNKNOWN &&
-     interfileExists(fname, hdrfile, imgfile, verbose-1)!=0) {
+  if(fformat==IMG_UNKNOWN && interfileExists(fname, hdrfile, imgfile, verbose-1)!=0) {
     fformat=IMG_INTERFILE; if(file_format!=NULL) *file_format=fformat;
     if(verbose>1) printf("file was identified to be in Interfile format\n.");
   }
