@@ -13,7 +13,7 @@
    @return 0 if ok, 1 invalid image status, 2 invalid output pointer, 3 invalid image dimensions.
  */
 int imgMax(
-  /** Pointer to IMG struct. */
+  /** Pointer to IMG structure. */
   IMG *img,
   /** Pointer to output. */
   float *maxvalue
@@ -21,12 +21,12 @@ int imgMax(
   if(img->status<IMG_STATUS_OCCUPIED) return(1);
   if(maxvalue==NULL) return(2); else *maxvalue=0.0;
   if(img->dimt<1 || img->dimz<1 || img->dimy<1 || img->dimx<1) return(3);
-  float f=img->m[0][0][0][0];
+  float f=nanf("");
   for(int pi=0; pi<img->dimz; pi++)
     for(int yi=0; yi<img->dimy; yi++)
       for(int xi=0; xi<img->dimx; xi++)
         for(int fi=0; fi<img->dimt; fi++) {
-          if(!(img->m[pi][yi][xi][fi]<=f)) f=img->m[pi][yi][xi][fi];
+          if(!isfinite(f) || img->m[pi][yi][xi][fi]>f) f=img->m[pi][yi][xi][fi];
         }
   *maxvalue=f;
   return(0);
@@ -42,7 +42,7 @@ int imgMax(
    @return 0 if ok, 1 invalid image status, 2 invalid output pointer, 3 invalid image dimensions.
  */
 int imgAbsMax(
-  /** Pointer to IMG struct. */
+  /** Pointer to IMG structure. */
   IMG *img,
   /** Pointer to output. */
   float *maxvalue
@@ -50,12 +50,12 @@ int imgAbsMax(
   if(img->status<IMG_STATUS_OCCUPIED) return(1);
   if(maxvalue==NULL) return(2); else *maxvalue=0.0;
   if(img->dimt<1 || img->dimz<1 || img->dimy<1 || img->dimx<1) return(3);
-  float f=img->m[0][0][0][0];
+  float f=nanf("");
   for(int pi=0; pi<img->dimz; pi++)
     for(int yi=0; yi<img->dimy; yi++)
       for(int xi=0; xi<img->dimx; xi++)
         for(int fi=0; fi<img->dimt; fi++) {
-          if(!(fabs(img->m[pi][yi][xi][fi])<=fabs(f))) f=img->m[pi][yi][xi][fi];
+          if(!isfinite(f) || fabs(img->m[pi][yi][xi][fi])>fabs(f)) f=img->m[pi][yi][xi][fi];
         }
   *maxvalue=f;
   return(0);
@@ -69,17 +69,17 @@ int imgAbsMax(
    3 inconsistent range dimensions, 4 inconsistent dimensions
  */
 int imgRangeMinMax(
-  /** Pointer to IMG structure */
+  /** Pointer to IMG structure. */
   IMG *img,
-  /** Pointer to image range inside IMG; enter NULL if whole IMG is used */
+  /** Pointer to image range inside IMG; enter NULL if whole IMG is used. */
   IMG_RANGE *r,
-  /** Pixel where max pixel position is written; NULL if not needed */
+  /** Pixel where max pixel position is written; NULL if not needed. */
   IMG_PIXEL *maxp,
-  /** Target for max value; NULL if not needed */
+  /** Target for max value; NULL if not needed. */
   float *maxv,
-  /** Pixel where min pixel position is written; NULL if not needed */
+  /** Pixel where min pixel position is written; NULL if not needed. */
   IMG_PIXEL *minp,
-  /** Target for min value; NULL if not needed */
+  /** Target for min value; NULL if not needed. */
   float *minv
 ) {
   int zi, yi, xi, fi;
@@ -94,38 +94,44 @@ int imgRangeMinMax(
     if(r->z2>img->dimz || r->y2>img->dimy || r->x2>img->dimx || r->f2>img->dimt) return(4);
 
     zi=r->z1-1; yi=r->y1-1; xi=r->x1-1; fi=r->f1-1;
-    lmax=lmin=img->m[zi][yi][xi][fi];
+    lmax=lmin=nanf("");
     if(maxp!=NULL) {maxp->z=zi+1; maxp->y=yi+1; maxp->x=xi+1; maxp->f=fi+1;}
     if(minp!=NULL) {minp->z=zi+1; minp->y=yi+1; minp->x=xi+1; minp->f=fi+1;}
     for(zi=r->z1-1; zi<r->z2; zi++) {
       for(yi=r->y1-1; yi<r->y2; yi++) {
         for(xi=r->x1-1; xi<r->x2; xi++) {
           for(fi=r->f1-1; fi<r->f2; fi++) {
-            if(!(lmax>=img->m[zi][yi][xi][fi])) {
+            if(!isfinite(lmax) || img->m[zi][yi][xi][fi]>lmax) {
               lmax=img->m[zi][yi][xi][fi];
-              if(maxp!=NULL) {maxp->z=zi+1; maxp->y=yi+1; maxp->x=xi+1; maxp->f=fi+1;}
-            } else if(!(lmin<=img->m[zi][yi][xi][fi])) {
+              if(maxp!=NULL && isfinite(img->m[zi][yi][xi][fi])) {
+                maxp->z=zi+1; maxp->y=yi+1; maxp->x=xi+1; maxp->f=fi+1;}
+            }
+            if(!isfinite(lmin) || img->m[zi][yi][xi][fi]<lmin) {
               lmin=img->m[zi][yi][xi][fi];
-              if(minp!=NULL) {minp->z=zi+1; minp->y=yi+1; minp->x=xi+1; minp->f=fi+1;}
+              if(minp!=NULL && isfinite(img->m[zi][yi][xi][fi])) {
+                minp->z=zi+1; minp->y=yi+1; minp->x=xi+1; minp->f=fi+1;}
             }
           }
         }
       }
     }
   } else {
-    zi=yi=xi=fi=0; lmax=lmin=img->m[zi][yi][xi][fi];
+    zi=yi=xi=fi=0; lmax=lmin=nanf("");
     if(maxp!=NULL) {maxp->z=zi+1; maxp->y=yi+1; maxp->x=xi+1; maxp->f=fi+1;}
     if(minp!=NULL) {minp->z=zi+1; minp->y=yi+1; minp->x=xi+1; minp->f=fi+1;}
     for(zi=0; zi<img->dimz; zi++) {
       for(yi=0; yi<img->dimy; yi++) {
         for(xi=0; xi<img->dimx; xi++) {
           for(fi=0; fi<img->dimt; fi++) {
-            if(!(lmax>=img->m[zi][yi][xi][fi])) {
+            if(!isfinite(lmax) || img->m[zi][yi][xi][fi]>lmax) {
               lmax=img->m[zi][yi][xi][fi];
-              if(maxp!=NULL) {maxp->z=zi+1; maxp->y=yi+1; maxp->x=xi+1; maxp->f=fi+1;}
-            } else if(!(lmin<=img->m[zi][yi][xi][fi])) {
+              if(maxp!=NULL && isfinite(img->m[zi][yi][xi][fi])) {
+                maxp->z=zi+1; maxp->y=yi+1; maxp->x=xi+1; maxp->f=fi+1;}
+            }
+            if(!isfinite(lmin) || img->m[zi][yi][xi][fi]<lmin) {
               lmin=img->m[zi][yi][xi][fi];
-              if(minp!=NULL) {minp->z=zi+1; minp->y=yi+1; minp->x=xi+1; minp->f=fi+1;}
+              if(minp!=NULL && isfinite(img->m[zi][yi][xi][fi])) {
+                minp->z=zi+1; minp->y=yi+1; minp->x=xi+1; minp->f=fi+1;}
             }
           }
         }
@@ -134,6 +140,8 @@ int imgRangeMinMax(
   }
   if(maxv!=NULL) *maxv=lmax;
   if(minv!=NULL) *minv=lmin;
+  if(!isfinite(lmax) && (maxp!=NULL || maxv!=NULL)) return(5); 
+  if(!isfinite(lmin) && (minp!=NULL || minv!=NULL)) return(5); 
   return(0);
 }
 /******************************************************************************/
@@ -144,11 +152,11 @@ int imgRangeMinMax(
    @return Returns 0 when successful.
  */
 int imgMinMax(
-  /** Pointer to IMG struct from where min and pixels are searched */
+  /** Pointer to IMG struct from where min and pixels are searched. */
   IMG *img,
-  /** Pointer to min pixel value; Enter NULL if not needed */
+  /** Pointer to min pixel value; Enter NULL if not needed. */
   float *minvalue,
-  /** Pointer to max pixel value; Enter NULL if not needed */
+  /** Pointer to max pixel value; Enter NULL if not needed. */
   float *maxvalue
 ) {
   return (imgRangeMinMax(img, NULL, NULL, maxvalue, NULL, minvalue));
@@ -178,14 +186,15 @@ int imgFrameMinMax(
   if(frame<1) return(4);
 
   float mi, ma;
-  mi=ma=img->m[0][0][0][fi];
+  mi=ma=nanf("");
   for(int pi=0; pi<img->dimz; pi++)
     for(int yi=0; yi<img->dimy; yi++)
       for(int xi=0; xi<img->dimx; xi++) {
-        if(!(img->m[pi][yi][xi][fi]<=ma)) ma=img->m[pi][yi][xi][fi];
-        else if(!(img->m[pi][yi][xi][fi]>=mi)) mi=img->m[pi][yi][xi][fi];
+        if(!isfinite(ma) || img->m[pi][yi][xi][fi]>ma) ma=img->m[pi][yi][xi][fi];
+        if(!isfinite(mi) || img->m[pi][yi][xi][fi]<mi) mi=img->m[pi][yi][xi][fi];
       }
   *minvalue=mi; *maxvalue=ma;
+  if(!isfinite(mi) || !isfinite(ma)) return(5);
   return(0);
 }
 /******************************************************************************/
@@ -303,14 +312,15 @@ int imgGetPeak(
     if(verbose>0) fprintf(stderr, "Error: invalid max search time setting.\n");
     return(4);
   }
-  f=img->m[0][0][0][0]-1.0; mf=img->dimt; p->x=p->y=p->z=p->f=1;
+  f=nanf(""); mf=img->dimt; p->x=p->y=p->z=p->f=1;
   for(zi=0; zi<img->dimz; zi++) {
     for(yi=0; yi<img->dimy; yi++) {
       for(xi=0; xi<img->dimx; xi++) {
         for(fi=0; fi<img->dimt; fi++) if(img->mid[fi]<=beforeTime) {
-          if(img->m[zi][yi][xi][fi]<f) // lower
+          if(!isfinite(img->m[zi][yi][xi][fi])) continue;
+          if(isfinite(f) && img->m[zi][yi][xi][fi]<f) // lower
             continue;
-          if(img->m[zi][yi][xi][fi]==f) { // equal
+          if(isfinite(f) && img->m[zi][yi][xi][fi]==f) { // equal
             // only use this if earlier than in prev max
             if(fi>=mf) continue;
           } 
@@ -321,6 +331,7 @@ int imgGetPeak(
       }
     }
   }
+  if(!isfinite(f)) return(5);
   if(verbose>2) printf("maxval := %g\n", f);
   return(0);
 }
