@@ -18,6 +18,7 @@
 
 /*****************************************************************************/
 /** Remove any extensions from Nifti file name, leaving only base file name.
+   @sa niftiCreateFNames, niftiExists, niftiRemove
  */
 void niftiRemoveFNameExtension(
   /** Full name of file. */
@@ -38,6 +39,7 @@ void niftiRemoveFNameExtension(
 /*****************************************************************************/
 /** Construct the file names for NIfTI image.
     @return Returns 0 if successful, otherwise <>0.
+    @sa niftiExists
  */
 int niftiCreateFNames(
   /** Filename, either header file, image file, or base name without extensions,
@@ -93,12 +95,13 @@ int niftiCreateFNames(
 
     @return Returns 0 when call was successful, otherwise <>0. Call is considered
     successful, if files do not exist initially.
+    @sa niftiExists, niftiRemoveFNameExtension
  */
 int niftiRemove(
   /** NIfTI database name with path, possibly with filename extension */
   const char *dbname,
   /** NIfTI file format, either IMG_NIFTI_1D (31) or IMG_NIFTI_1S (32),
-   *  or IMG_UNKNOWN (0) in case both are to be deleted. */
+      or IMG_UNKNOWN (0) in case both are to be deleted. */
   int fileformat,
   /** Verbose level; if zero, then nothing is printed to stderr or stdout */
   int verbose
@@ -151,8 +154,8 @@ int niftiRemove(
 /*****************************************************************************/
 /** Verify if specified filename is a NIfTI file.
    @return Returns 0 if it is not, 1 if header and image data are found
-   (either as one combined file or as separate files,
-   and 2, if sif file is found too.
+   (either as one combined file or as separate files, and 2, if SIF is found too.
+   @sa niftiRemove
  */
 int niftiExists(
   /** Filename, either header file, image file, or base name without extensions.
@@ -285,6 +288,7 @@ int niftiExists(
 /*****************************************************************************/
 /** Read Nifti header contents. Currently, does not read Nifti-1 header extension.
     @return Returns 0, if successful, otherwise >0.
+    @sa niftiReadImagedata, niftiWriteHeader, niftiExists
  */
 int niftiReadHeader(
   /** Name of file to read (including path and extension) */
@@ -610,6 +614,7 @@ int niftiPrintHeader(
     and scale values to floats. Reads only one frame at a time!
     @return Returns 0 if successful, >1 in case of an error, and specifically
      -1 in case that contents after the last image frame was requested.
+    @sa niftiReadHeader
  */
 int niftiReadImagedata(
   /** File pointer to start of image data file, opened previously in binary mode. */
@@ -831,6 +836,7 @@ int niftiReadImagedata(
     Currently, does not write header extension.
     Header field 'byte_order' is used to determine the required byte order.
    @return Returns 0, if successful, otherwise >0.
+   @sa niftiReadHeader, imgWriteNifti
  */
 int niftiWriteHeader(
   /** Name of file to write (including path and extension). */
