@@ -458,6 +458,7 @@ int liInterpolateForPET(
 /*****************************************************************************/
 
 /*****************************************************************************/
+#if(0) // not useful
 /** @brief Calculate the y value (concentration) at PET frame middle time based on 
     dot-to-dot linear interpolation, assuming that original y values represent the mean value 
     during the frame, i.e. AUC(frame start - frame end time)/frame duration.
@@ -525,8 +526,7 @@ int liFrameMidValue(
     }
   }
 
-  /* Compute data matrix for solving (very simply) the y values at frame middle
-     times */
+  /* Compute data matrix for solving (very simply) the y values at frame middle times */
   double A[2][nr], B[nr], xdif;
   A[0][0]=1.0; A[1][0]=0.0; B[0]=y[0];
   for(size_t i=1; i<nr-1; i++) {
@@ -566,6 +566,7 @@ int liFrameMidValue(
   if(verbose>1) printf("%s() ready\n", __func__);
   return 0;
 }
+#endif
 /*****************************************************************************/
 
 /*****************************************************************************/
