@@ -235,11 +235,6 @@ extern double hlLambda2factor(double lambda, double frametime, double framedur);
 extern float hlLambda2factor_float(float lambda, float frametime, float framedur);
 extern char *hlCorrectIsotopeCode(char *isocode);
 extern int hlIsotopeFromHalflife(double halflife);
-/// @cond
-/* Deprecated function names. Please don't use these any more */
-#define lambda2factor hlLambda2factor
-#define lambda2factor_float hlLambda2factor_float
-/// @endcond
 /*****************************************************************************/
 
 /*****************************************************************************/
