@@ -11,51 +11,48 @@
 /*****************************************************************************/
 
 /*****************************************************************************/
-/** Read DFT format input TAC data to match the time frames in the
-    specified tissue DFT file.
-    Instead of input filename, a reference region name can be given: then all
-    the matching tacs (based on roi names) are moved from the roi data to the
-    input data, with the best match as first tac.
+/** Read DFT format input TAC data to match the time frames in the specified tissue DFT file.
+    Instead of input filename, a reference region name can be given: then all the matching tacs 
+    (based on roi names) are moved from the roi data to the input data, with the best match 
+    as first tac.
     Input data is interpolated (if necessary) and also integrated to y2[].
-    Input time and concentration units are tried to be converted to be the same
-    as in tissue data.
-   @return Returns 0 if succesful, and >0 in case of an error, and specifically
+    Input time and concentration units are tried to be converted to be the same as in tissue data.
+   @return Returns 0 if successful, and >0 in case of an error, and specifically
     101 in case input TAC is not valid.
+   @sa dftReadReference, dftRead, dftReadModelingData, dftVerifyPeak, imgReadModelingData
+
  */
 int dftReadinput(
-  /** Input data, previous contents are cleared */
+  /** Input data, previous contents are cleared. */
   DFT *input,
-  /** PET data containing frames and possible input regions */
+  /** PET data containing frames and possible input regions. */
   DFT *tissue,
-  /** Input data filename, or region name in PET data */
+  /** Input data filename, or region name in PET data. */
   char *filename,
   /** Type of input, as found out here; 1 and 2 =tac, 3=fit, 5=region name;
-      enter NULL, if not needed */
+      enter NULL, if not needed. */
   int *filetype,
   /** First time of input data before interpolation (in tissue time units);
-      use this to check that required time range was measured; 
-      NULL if not needed */
+      use this to check that required time range was measured; NULL if not needed. */
   double *ti1,
   /** Last time of input data before interpolation (in tissue time units);
-      use this to check that required time range was measured; 
-      NULL if not needed */
+      use this to check that required time range was measured; NULL if not needed. */
   double *ti2,
   /** Set to <>0 to verify that input TAC does not start too late and has
-   *  decent peak to provide reliable AUC0-T. */
+      decent peak to provide reliable AUC0-T. */
   int verifypeak,
   /** Pointer to a string (allocated for at least 64 chars) where error message
-      or other execution status will be written; enter NULL, if not needed */   
+      or other execution status will be written; enter NULL, if not needed. */   
   char *status,
-  /** Verbose level; if zero, then nothing is printed to stderr or stdout */
+  /** Verbose level; if zero, then nothing is printed to stderr or stdout. */
   int verbose
 ) {
   int ri, n, ret, ftype=0;
   DFT temp;
   FILE *fp;
 
-  if(verbose>0)
-    printf("dftReadinput(inp, tis, %s, type, ti1, ti2, %d, status, %d)\n",
-           filename, verifypeak, verbose);
+  if(verbose>0) printf("dftReadinput(inp, tis, %s, type, ti1, ti2, %d, status, %d)\n",
+                       filename, verifypeak, verbose);
   if(filetype!=NULL) *filetype=0;
 
   /* Check that PET data is ok */
@@ -77,7 +74,7 @@ int dftReadinput(
   fp=fopen(filename, "r");
   if(fp!=NULL) {
     /* File can be opened for read; close it for now */
-    if(verbose>1) printf("  file can be openened for reading.\n");
+    if(verbose>1) printf("  file can be opened for reading.\n");
     if(filetype!=NULL) *filetype=1;
     fclose(fp);
 
@@ -104,9 +101,7 @@ int dftReadinput(
     (void)dftTimeunitConversion(&temp, tissue->timeunit);
     /* Check the tissue and plasma TAC concentration units */
     ret=dftUnitConversion(&temp, petCunitId(tissue->unit));
-    if(ret!=0) {
-      sprintf(status, "check the units of input and tissue data");
-    }
+    if(ret!=0) {sprintf(status, "check the units of input and tissue data");}
     /* Tell user what was the original input time range */
     if(temp.timetype==DFT_TIME_STARTEND) {
       if(ti1!=NULL) *ti1=temp.x1[0];
@@ -179,8 +174,7 @@ int dftReadinput(
         if(ti2!=NULL) *ti2=input->x2[input->frameNr-1];
       } else {
         ret=interpolate(input->x, input->voi[ri].y, input->frameNr,
-               input->x, NULL, input->voi[ri].y2,
-               input->voi[ri].y3, input->frameNr);
+               input->x, NULL, input->voi[ri].y2, input->voi[ri].y3, input->frameNr);
         if(ti1!=NULL) *ti1=input->x[0];
         if(ti2!=NULL) *ti2=input->x[input->frameNr-1];
       }
@@ -196,32 +190,31 @@ int dftReadinput(
 /*****************************************************************************/
 
 /*****************************************************************************/
-/** Read DFT format reference region TAC data and add it into DFT already
- *  containing other tissue TACs, if reference region TAC(s) are be given
- *  in a separate file. Alternatively the reference region name can be given,
- *  which will then be selected from existing tissue TACs.
- *  Reference TACs are marked in DFT with sw=2 (best name match) or sw=1;
- *  if reference region file contains several TACs then the one which contains 
- *  name 'mean' or 'avg' or has shortest total name length is given value sw=2. 
- *  When necessary, reference data is interpolated and units converted to
- *  match the existing tissue DFT.
- *  Reference TAC is also integrated into y2[].
-\return Returns the number of reference TACs, and <=0 in case of an error.
+/** Read DFT format reference region TAC data and add it into DFT already containing other 
+    tissue TACs, if reference region TAC(s) are be given in a separate file.
+    Alternatively the reference region name can be given, which will then be selected from
+    existing tissue TACs. Reference TACs are marked in DFT with sw=2 (best name match) or sw=1;
+    if reference region file contains several TACs then the one which contains name 'mean' or 'avg'
+    or has shortest total name length is given value sw=2. 
+    When necessary, reference data is interpolated and units converted to match the existing 
+    tissue DFT. Reference TAC is also integrated into y2[].
+   @return Returns the number of reference TACs, and <=0 in case of an error.
+   @sa dftReadinput, dftRead, dftReadModelingData, imgReadModelingData
  */
 int dftReadReference(
-  /** PET data containing existing tissue TACs, possibly also ref regions */
+  /** PET data containing existing tissue TACs, possibly also ref regions. */
   DFT *tissue,
-  /** Reference TAC filename, or region name in previous data */
+  /** Reference TAC filename, or region name in previous data. */
   char *filename,
   /** Type of input, as found out here; 1 and 2 =tac, 3=fit, 5=region name;
-      enter NULL, if not needed */
+      enter NULL, if not needed. */
   int *filetype,
-  /** Index of the best reference region; enter NULL if not needed */
+  /** Index of the best reference region; enter NULL if not needed. */
   int *ref_index,
   /** Pointer to a string (allocated for at least 64 chars) where error message
-      or other execution status will be written; enter NULL, if not needed */     
+      or other execution status will be written; enter NULL, if not needed. */     
   char *status,
-  /** Verbose level; if zero, then nothing is printed to stderr or stdout */
+  /** Verbose level; if zero, then nothing is printed to stderr or stdout. */
   int verbose
 ) {
   int ri, n, ret;
@@ -322,8 +315,7 @@ int dftReadReference(
       ret=petintegrate(tissue->x1, tissue->x2, tissue->voi[ri].y,
               tissue->frameNr, tissue->voi[ri].y2, NULL);
     } else {
-      ret=integrate(tissue->x, tissue->voi[ri].y, tissue->frameNr,
-              tissue->voi[ri].y2);
+      ret=integrate(tissue->x, tissue->voi[ri].y, tissue->frameNr, tissue->voi[ri].y2);
     }
     if(ret) {
       if(status!=NULL) sprintf(status, "cannot integrate input");
@@ -337,41 +329,40 @@ int dftReadReference(
 /*****************************************************************************/
 
 /*****************************************************************************/
-/** Read tissue and input data for modeling. Time units are converted to min
- *  and input calibration units to units of tissue data.
- *  Input data is NOT interpolated to tissue times.
- *  If input data extends much further than fit duration, the last part is 
- *  removed to save computation time in simulations.
- *  Input data is verified not to end too early, and not to start too late.
+/** Read tissue and input data for modeling. Time units are converted to min and input calibration 
+    units to units of tissue data.
+    Input data is NOT interpolated to tissue times.
+    If input data extends much further than fit duration, the last part is 
+    removed to save computation time in simulations.
+    Input data is verified not to end too early, and not to start too late.
 
-\return Returns 0 when successful, otherwise a non-zero value. 
+   @return Returns 0 when successful, otherwise a non-zero value. 
+   @sa dftReadReference, dftRead, dftReadinput, imgReadModelingData
  */ 
 int dftReadModelingData(
-  /** Tissue data filename; one time sample is sufficient here */
+  /** Tissue data filename; one time sample is sufficient here. */
   char *tissuefile,
-  /** 1st input data filename */
+  /** 1st input data filename. */
   char *inputfile1,
-  /** 2nd input data filename (or NULL if only not needed) */
+  /** 2nd input data filename (or NULL if only not needed). */
   char *inputfile2,
-  /** 3rd input data filename (or NULL if only not needed) */
+  /** 3rd input data filename (or NULL if only not needed). */
   char *inputfile3,
-  /** Fit duration (in minutes); shortened if longer than tissue data */
+  /** Fit duration (in minutes); shortened if longer than tissue data. */
   double *fitdur,
-  /** Nr of time frames (samples) in tissue data that are inside fitdur
-   *  will be written here */
+  /** Nr of time frames (samples) in tissue data that are inside fitdur will be written here. */
   int *fitframeNr,
-  /** Pointer to initiated DFT into which tissue data will be written */
+  /** Pointer to initiated DFT into which tissue data will be written. */
   DFT *tis,
-  /** Pointer to initiated DFT into which input data (plasma and/or blood) 
-   *  will be written */
+  /** Pointer to initiated DFT into which input data (plasma and/or blood) will be written. */
   DFT *inp,
   /** Give file pointer (for example stdout) where log information is printed;
-   *  NULL if not needed; warnings will be printed in stderr anyway. */
+      NULL if not needed; warnings will be printed in stderr anyway. */
   FILE *loginfo,
-  /** Verbose level; if zero, then only warnings are printed into stderr */
+  /** Verbose level; if zero, then only warnings are printed into stderr. */
   int verbose,
   /** Pointer to a string (allocated for at least 64 chars) where error message
-      or other execution status will be written; enter NULL, if not needed */     
+      or other execution status will be written; enter NULL, if not needed. */
   char *status
 ) {
   int ret, fi, n, first, last, ii, input_nr=0;
@@ -388,8 +379,7 @@ int dftReadModelingData(
     fprintf(loginfo, "  %s,\n", inputfile2);
     fprintf(loginfo, "  %s,\n", inputfile3);
     fprintf(loginfo, "  %g,\n", *fitdur);
-    fprintf(loginfo, "  *fitframeNr, *tis, *inp, *loginfo, %d, *status\n",
-            verbose);
+    fprintf(loginfo, "  *fitframeNr, *tis, *inp, *loginfo, %d, *status\n", verbose);
     fprintf(loginfo, ")\n");
   }
   /* Check the input */
@@ -413,11 +403,9 @@ int dftReadModelingData(
   /*
    *  Read tissue data
    */
-  if(loginfo!=NULL && verbose>0)
-    fprintf(loginfo, "reading tissue data in %s\n", tissuefile);
+  if(loginfo!=NULL && verbose>0) fprintf(loginfo, "reading tissue data in %s\n", tissuefile);
   if(dftRead(tissuefile, tis)) {
-    if(status!=NULL)
-      sprintf(status, "cannot read '%s': %s", tissuefile, dfterrmsg);
+    if(status!=NULL) sprintf(status, "cannot read '%s': %s", tissuefile, dfterrmsg);
     return(2);
   }
   /* Check for NaN's */
@@ -434,8 +422,7 @@ int dftReadModelingData(
       fprintf(loginfo, "checking frame overlap in %s\n", tissuefile);
     ret=dftDeleteFrameOverlap(tis);
     if(ret) {
-      if(status!=NULL)
-        sprintf(status, "%s has overlapping frame times", tissuefile);
+      if(status!=NULL) sprintf(status, "%s has overlapping frame times", tissuefile);
       dftEmpty(tis); return(2);
     }
   }
@@ -446,11 +433,9 @@ int dftReadModelingData(
   /*
    *  Read first input data
    */
-  if(loginfo!=NULL && verbose>0)
-    fprintf(loginfo, "reading input data in %s\n", inputfile1);
+  if(loginfo!=NULL && verbose>0) fprintf(loginfo, "reading input data in %s\n", inputfile1);
   if(dftRead(inputfile1, inp)) {
-    if(status!=NULL)
-      sprintf(status, "cannot read '%s': %s", inputfile1, dfterrmsg);
+    if(status!=NULL) sprintf(status, "cannot read '%s': %s", inputfile1, dfterrmsg);
     dftEmpty(tis); return(3);
   }
   /* Check and correct the sample time unit */
@@ -461,8 +446,7 @@ int dftReadModelingData(
   }
   if(tis->timeunit!=inp->timeunit &&
      dftTimeunitConversion(inp, tis->timeunit)!=0) {
-    if(status!=NULL)
-      sprintf(status, "tissue and plasma do have different time units");
+    if(status!=NULL) sprintf(status, "tissue and plasma do have different time units");
     dftEmpty(tis); dftEmpty(inp);
     return(3);
   }
@@ -493,8 +477,7 @@ int dftReadModelingData(
 
     /* Read blood data */
     dftInit(&tmpdft);
-    if(loginfo!=NULL && verbose>0)
-      fprintf(loginfo, "reading input data in %s\n", fname);
+    if(loginfo!=NULL && verbose>0) fprintf(loginfo, "reading input data in %s\n", fname);
     if(dftRead(fname, &tmpdft)) {
       if(status!=NULL) sprintf(status, "cannot read '%s': %s", fname, dfterrmsg);
       dftEmpty(tis); dftEmpty(inp); return(4);
@@ -512,8 +495,7 @@ int dftReadModelingData(
     }
     if(inp->timeunit!=tmpdft.timeunit &&
        dftTimeunitConversion(&tmpdft, inp->timeunit)!=0) {
-      if(status!=NULL)
-        sprintf(status, "two input data are in different time units");
+      if(status!=NULL) sprintf(status, "two input data are in different time units");
       dftEmpty(tis); dftEmpty(inp); dftEmpty(&tmpdft);
       return(4);
     }
@@ -540,8 +522,7 @@ int dftReadModelingData(
   } // next input file
 
   /* Set time unit to min */
-  if(loginfo!=NULL && verbose>1)
-    fprintf(loginfo, "setting time units to min.\n");
+  if(loginfo!=NULL && verbose>1)fprintf(loginfo, "setting time units to min.\n");
   ret=dftTimeunitConversion(tis, TUNIT_MIN); if(ret)
     fprintf(wfp, "Warning: check that regional data times are in minutes.\n");
   ret=dftTimeunitConversion(inp, TUNIT_MIN); if(ret)
@@ -550,8 +531,7 @@ int dftReadModelingData(
   /* 
    *  Check the input data
    */
-  if(loginfo!=NULL && verbose>0)
-    fprintf(loginfo, "checking input data\n");
+  if(loginfo!=NULL && verbose>0) fprintf(loginfo, "checking input data\n");
   if(inp->frameNr<4) {
     if(status!=NULL) sprintf(status, "%s contains too few samples", inputfile1);
     dftEmpty(tis); dftEmpty(inp); return(4);
@@ -573,19 +553,15 @@ int dftReadModelingData(
 
   /* Check the tissue and blood TAC concentration units */
   ret=dftUnitConversion(inp, petCunitId(tis->unit));
-  if(ret!=0) {
-    fprintf(wfp, "Note: check the units of input and tissue data.\n");
-  }
+  if(ret!=0) {fprintf(wfp, "Note: check the units of input and tissue data.\n");}
 
   /*
    *  Check and set fit time length
    */
-  if(loginfo!=NULL && verbose>0)
-    fprintf(loginfo, "checking and setting fit time length\n");
+  if(loginfo!=NULL && verbose>0) fprintf(loginfo, "checking and setting fit time length\n");
   /* Set fit duration */
   starttime=0; endtime=*fitdur;
-  *fitframeNr=fittime_from_dft(tis, &starttime, &endtime,
-                               &first, &last, verbose);
+  *fitframeNr=fittime_from_dft(tis, &starttime, &endtime, &first, &last, verbose);
   if(loginfo!=NULL && verbose>1) {
     fprintf(loginfo, "tis.frameNr := %d\n", tis->frameNr);
     fprintf(loginfo, "starttime := %g\n", starttime);
@@ -603,14 +579,13 @@ int dftReadModelingData(
     dftEmpty(inp); dftEmpty(tis); return(5);
   }
   /* Cut off too many input samples to make calculation faster */
-  f=*fitdur; 
+  f=*fitdur+1.0; // One minute extra to allow time delay correction
   if(loginfo!=NULL && verbose>0) printf("Input TAC cutoff at %g min\n", f); 
   for(fi=0; fi<inp->frameNr; fi++) if(inp->x[fi]>f) break;
   if(fi<inp->frameNr) fi++; 
   inp->frameNr=fi;
   if(inp->frameNr<4) {
-    if(status!=NULL)
-      sprintf(status, "too few samples in specified fit duration.\n");
+    if(status!=NULL) sprintf(status, "too few samples in specified fit duration.\n");
     dftEmpty(inp); dftEmpty(tis); return(5);
   }
   if(loginfo!=NULL && verbose>1) {
@@ -626,32 +601,32 @@ int dftReadModelingData(
 
 /*****************************************************************************/
 /** Robust search of the min and max values of DFT TAC data.
- *  Data may contain NaN's, and individual outliers are not taken as min or max.
- * @sa dftMinMaxTAC, dftMinMax
- * @return Returns 0 if successful.
+    Data may contain NaN's, and individual outliers are not taken as min or max.
+   @sa dftMinMaxTAC, dftMinMax
+   @return Returns 0 if successful.
  */
 int dftRobustMinMaxTAC(
-  /** Pointer to the DFT TAC data to search */
+  /** Pointer to the DFT TAC data to search. */
   DFT *dft,
-  /** Index of the only TAC which is searched for min and max; <0 if all */
+  /** Index of the only TAC which is searched for min and max; <0 if all. */
   int tacindex,
-  /** Pointer to X at TAC min; set to NULL if not needed */
+  /** Pointer to X at TAC min; set to NULL if not needed. */
   double *minx,
-  /** Pointer to X at TAC max; set to NULL if not needed */
+  /** Pointer to X at TAC max; set to NULL if not needed. */
   double *maxx,
-  /** Pointer to min Y; set to NULL if not needed */
+  /** Pointer to min Y; set to NULL if not needed. */
   double *miny,
-  /** Pointer to max Y; set to NULL if not needed */
+  /** Pointer to max Y; set to NULL if not needed. */
   double *maxy,
-  /** Index of min TAC; set to NULL if not needed */
+  /** Index of min TAC; set to NULL if not needed. */
   int *mini,
-  /** Index of max TAC; set to NULL if not needed */
+  /** Index of max TAC; set to NULL if not needed. */
   int *maxi,
-  /** Index of min sample; set to NULL if not needed */
+  /** Index of min sample; set to NULL if not needed. */
   int *mins,
-  /** Index of max sample; set to NULL if not needed */
+  /** Index of max sample; set to NULL if not needed. */
   int *maxs,
-  /** Verbose level; if zero, then nothing is printed to stderr or stdout */
+  /** Verbose level; if zero, then nothing is printed to stderr or stdout. */
   int verbose
 ) {
   int ri, fi, i1, i2, s1, s2;
@@ -689,8 +664,7 @@ int dftRobustMinMaxTAC(
     } else {
       ym=dmedian(list, n);
       //fprintf(stderr, "median := %g\n", ym);
-      /* Search the longest run of values which are larger/smaller than
-         the median */
+      /* Search the longest run of values which are larger/smaller than the median */
       runnh=maxrunnh=run1h=run2h=maxrun1h=maxrun2h=0;
       runns=maxrunns=run1s=run2s=maxrun1s=maxrun2s=0;
       for(fi=0; fi<dft->frameNr; fi++) {
@@ -721,10 +695,8 @@ int dftRobustMinMaxTAC(
       if(maxrunns<2) {maxrunns=dft->frameNr; maxrun1s=0; maxrun2s=dft->frameNr-1;}
     }
     if(verbose>12) {
-      fprintf(stderr, "longest run for max: %g - %g\n",
-        dft->x[maxrun1h], dft->x[maxrun2h]);
-      fprintf(stderr, "longest run for min: %g - %g\n",
-        dft->x[maxrun1s], dft->x[maxrun2s]);
+      fprintf(stderr, "longest run for max: %g - %g\n", dft->x[maxrun1h], dft->x[maxrun2h]);
+      fprintf(stderr, "longest run for min: %g - %g\n", dft->x[maxrun1s], dft->x[maxrun2s]);
     }
     /* Inside the range, search for max */
     for(fi=maxrun1h; fi<=maxrun2h; fi++) {
@@ -736,8 +708,7 @@ int dftRobustMinMaxTAC(
         if(isnan(dft->x[fi])) continue;
         x=dft->x[fi];
       }
-      if(isnan(y2) || y2<dft->voi[ri].y[fi]) {
-        y2=dft->voi[ri].y[fi]; i2=ri; x2=x; s2=fi;}
+      if(isnan(y2) || y2<dft->voi[ri].y[fi]) {y2=dft->voi[ri].y[fi]; i2=ri; x2=x; s2=fi;}
     }
     /* Inside the range, search for min */
     for(fi=maxrun1s; fi<=maxrun2s; fi++) {
@@ -749,8 +720,7 @@ int dftRobustMinMaxTAC(
         if(isnan(dft->x[fi])) continue;
         x=dft->x[fi];
       }
-      if(isnan(y1) || y1>dft->voi[ri].y[fi]) {
-        y1=dft->voi[ri].y[fi]; i1=ri; x1=x; s1=fi;}
+      if(isnan(y1) || y1>dft->voi[ri].y[fi]) {y1=dft->voi[ri].y[fi]; i1=ri; x1=x; s1=fi;}
     }
 
   } /* next TAC */
@@ -770,18 +740,19 @@ int dftRobustMinMaxTAC(
 /*****************************************************************************/
 /** Verify that specified (input) TAC contains peak and that it does not
     start too late to get reliable estimate of AUC.
-    @return Returns 0 in case data is suitable, < 0 if there may be a problem,
+   @return Returns 0 in case data is suitable, < 0 if there may be a problem,
     1 in case of an error, and 2 if peak seems to be missed. 
+   @sa dftReadModelingData, imgReadModelingData
  */
 int dftVerifyPeak(
-  /** Pointer to TAC data which is verified */
+  /** Pointer to TAC data which is verified. */
   DFT *dft,
-  /** Index of TAC to be verified; <0 in case all are (separately) verified */
+  /** Index of TAC to be verified; <0 in case all are (separately) verified. */
   int index,
-  /** Verbose level; if zero, then nothing is printed to stderr or stdout */
+  /** Verbose level; if zero, then nothing is printed to stderr or stdout. */
   int verbose,
   /** Pointer to a string (allocated for at least 64 chars) where error message
-      or other execution status will be written; enter NULL, if not needed */     
+      or other execution status will be written; enter NULL, if not needed. */
   char *status
 ) {
   int ri, fi, ret, mini, maxi, starti, warn=0;
@@ -808,8 +779,7 @@ int dftVerifyPeak(
     if(verbose>1) printf("checking region %d: %s\n", 1+ri, dft->voi[ri].name);
 
     /* Get the TAC min and max */
-    ret=dftMinMaxTAC(dft, ri, &minx, &maxx, &miny, &maxy, NULL, NULL,
-                     &mini, &maxi);
+    ret=dftMinMaxTAC(dft, ri, &minx, &maxx, &miny, &maxy, NULL, NULL, &mini, &maxi);
     if(ret!=0) {
       if(verbose>0) printf("Error %d in dftMinMaxTAC()\n", ret);
       if(status!=NULL) strcpy(status, "invalid TAC");
@@ -849,8 +819,7 @@ int dftVerifyPeak(
     }
     if(verbose>2) printf("first time sample at %g\n", startx);
 
-    /* If the first sample is the peak, then check that sample time is not too
-       late */
+    /* If the first sample is the peak, then check that sample time is not too late */
     if(maxi==starti) {
       if(verbose>2) printf("Peak at the first sample.\n");
       if(status!=NULL) strcpy(status, "input TAC should start at time zero");
@@ -883,8 +852,7 @@ int dftVerifyPeak(
       if(dft->voi[ri].y[fi]<lowesty) lowesty=dft->voi[ri].y[fi];
     if(verbose>2) printf("lowest value before peak: %g\n", lowesty);
 
-    /* If first sample is closer to peak and relatively high, then that is
-       or may be a problem */
+    /* If first sample is closer to peak and relatively high, then that is or may be a problem */
     if(maxi>starti && startx>0.001 && startx>0.75*maxx) {
       if(dft->voi[ri].y[starti]>0.66*maxy && lowesty>0.05*maxy && mini>maxi) {
         if(verbose>0) printf("The first sample is relatively late and high.\n");
