@@ -13,56 +13,56 @@
 
     Input calibration units are converted to units of tissue data.
     Input data is optionally interpolated to tissue times.
-    If input data extends much further than fit duration, the last part is 
-    removed to save computation time in simulations.
-    Input data is optionally verified not to end too early, and not to
-    start too late.
+    If input data extends much further than fit duration, the last part is removed to save 
+    computation time in simulations.
+    Input data is optionally verified not to end too early, and not to start too late.
 
     @return Returns 0 when successful, otherwise a non-zero value. 
+
+    @sa imgRead, dftRead, dftReadinput, dftReadModelingData, dftEndtime, imgEndtime
  */ 
 int imgReadModelingData(
-  /** PET dynamic image filename; one time frame is sufficient here */
+  /** PET dynamic image filename; one time frame is sufficient here. */
   char *petfile,
   /** Optional SIF. SIF is automatically read with NIfTI and Analyze formats,
-   *  if found in the same folder and files are consistently named.
-   *  SIF filename needs to be specified here only if that is not the case,
-   *  or if other image formats do not contain information on frame times or
-   *  tracer isotope, or if weights from SIF are needed.
-   *  Enter NULL if not needed. */
+      if found in the same folder and files are consistently named.
+      SIF filename needs to be specified here only if that is not the case,
+      or if other image formats do not contain information on frame times or
+      tracer isotope, or if weights from SIF are needed.
+      Enter NULL if not needed. */
   char *siffile,
-  /** 1st input data filename */
+  /** 1st input data filename. */
   char *inputfile1,
-  /** 2nd input data filename (or NULL if only not needed) */
+  /** 2nd input data filename (or NULL if only not needed). */
   char *inputfile2,
-  /** 3rd input data filename (or NULL if only not needed) */
+  /** 3rd input data filename (or NULL if only not needed). */
   char *inputfile3,
   /** Fit duration (in minutes); shortened if longer than PET data;
-   *  enter <=0 to use all data in image; input is verified to not be much
-   *  shorter than fitfur. */
+      enter <=0 to use all data in image; input is verified to not be much shorter than fitdur. */
   double *fitdur,
   /** Nr of time frames (samples) in PET data that are inside fitdur
-   *  will be written here; pointer MUST be provided. */
+      will be written here; pointer MUST be provided. */
   int *fitframeNr,
-  /** Pointer to initiated IMG struct into which PET data will be written */
+  /** Pointer to initiated IMG structure into which PET data will be written. */
   IMG *img,
   /** Pointer to initiated DFT into which input data (plasma, blood, and/or
-   *  reference tissue TAC) will be written without interpolation;
-   *  enter NULL if not needed. Times will be in seconds, like in image. */
+      reference tissue TAC) will be written without interpolation;
+      enter NULL if not needed. Times will be in seconds, like in image. */
   DFT *inp,
   /** Pointer to initiated DFT into which input data (plasma, blood, and/or
-   *  reference tissue TAC) will be written, interpolated to PET frames;
-   *  enter NULL if not needed.  Times will be in seconds, like in image. */
+      reference tissue TAC) will be written, interpolated to PET frames;
+      enter NULL if not needed.  Times will be in seconds, like in image. */
   DFT *iinp,
   /** Set to <>0 to verify that input TAC does not start too late and has
-   *  decent peak to provide reliable AUC0-T. */
+      decent peak to provide reliable AUC0-T. */
   int verifypeak,
   /** Give file pointer (for example stdout) where log information is printed;
-   *  NULL if not needed; warnings will be printed in stderr anyway. */
+      NULL if not needed; warnings will be printed in stderr anyway. */
   FILE *loginfo,
-  /** Verbose level; if zero, then only warnings are printed into stderr */
+  /** Verbose level; if zero, then only warnings are printed into stderr. */
   int verbose,
   /** Pointer to a string (allocated for at least 256 chars) where error message
-      or other execution status will be written; enter NULL, if not needed */     
+      or other execution status will be written; enter NULL, if not needed. */
   char *status
 ) {
   int ret, fi, n, first, last, ii, input_nr=0;
@@ -99,8 +99,7 @@ int imgReadModelingData(
   /* Warnings will be printed into stderr */
   wfp=stderr;
 
-  /* Check that input file(s) exist, because image is read first, and it
-     might take a while */
+  /* Check that input file(s) exist, because image is read first, and it might take a while */
   if(loginfo!=NULL && verbose>1) fprintf(loginfo, "checking access to input files\n");
   if(access(inputfile1, 0) == -1) {
     sprintf(tmp, "cannot read '%s'", inputfile1);
@@ -201,7 +200,7 @@ int imgReadModelingData(
     imgEmpty(img); return(5);
   }
   /* Check fit end time with the PET image */
-  if(*fitdur<=0.0) *fitdur=1.0E+99;
+  if(!(*fitdur>0.0)) *fitdur=1.0E+99;
   else if(*fitdur<1.0E+10) *fitdur*=60.0; // fit time must be in sec
   *fitframeNr=fittime_from_img(img, fitdur, verbose-2);
   if(*fitframeNr<1 || *fitdur<=3.5) {
@@ -356,8 +355,7 @@ int imgReadModelingData(
     }
     /* Copy to input data */
     if(loginfo!=NULL && verbose>1)
-      fprintf(loginfo, "interpolating %d samples into %d samples.\n",
-        tmpdft.frameNr, dft.frameNr);
+      fprintf(loginfo, "interpolating %d samples into %d samples.\n", tmpdft.frameNr, dft.frameNr);
     ret=dftInterpolateInto(&tmpdft, &dft, tmp, verbose);
     if(ret) {
       if(loginfo!=NULL) fprintf(loginfo, "dftInterpolateInto() := %d\n", ret);
@@ -411,16 +409,15 @@ int imgReadModelingData(
            dft.x[0], dft.x[dft.frameNr-1], petTunit(dft.timeunit));
     printf("fitdur := %g min\n", *fitdur);
   }
-  f=*fitdur*60.0;
+  f=*fitdur*60.0+60.0; // add 60 s to allow time delay correction
   if(dftEndtime(&dft)>f) {
     if(loginfo!=NULL && verbose>0) fprintf(loginfo, "Input TAC cutoff at %g sec\n", f); 
     for(fi=0; fi<dft.frameNr; fi++) if(dft.x[fi]>f) break;
     if(fi<dft.frameNr) fi++; 
     dft.frameNr=fi;
   }
-  if(verbose>10)
-    printf("input time range := %g - %g %s\n",
-           dft.x[0], dft.x[dft.frameNr-1], petTunit(dft.timeunit));
+  if(verbose>10) printf("input time range := %g - %g %s\n",
+                        dft.x[0], dft.x[dft.frameNr-1], petTunit(dft.timeunit));
 
   /* Copy input data to given pointer, if required */
   if(inp!=NULL) {
