@@ -807,7 +807,8 @@ int svg_write_tac(
   /* Set the curve title */
   sprintf(tmp, "      <%s", ilc);
   sprintf(line, "title>"); strcat(tmp, line);
-  strcat(tmp, tac_title);
+  char *senc=svg_str_encode(tac_title);
+  if(senc==NULL) strcat(tmp, tac_title); else {strcat(tmp, senc); free(senc);}
   strcat(tmp, "</"); strcat(tmp, ilc); strcat(tmp, "title>\n");
   if(svg_write(fp, tmp, errmsg, verbose-5)!=0) {return(12);}
 
