@@ -300,6 +300,12 @@ int main(
     statusPrint(stderr, &status); statusFree(&status);
     return(i);
   }
+  /* 4dmio */
+  i++; if((ret=test_tacRead4DM(&status))!=0) {
+    fprintf(stderr, "failed (%d).\n", ret);
+    statusPrint(stderr, &status); statusFree(&status);
+    return(i);
+  }
   /* matio */
   i++; if((ret=test_tacReadMat(&status))!=0) {
     fprintf(stderr, "failed (%d).\n", ret);
@@ -606,6 +612,21 @@ int main(
     statusPrint(stderr, &status); statusFree(&status);
     return(i);
   }
+  i++; if((ret=test_tacFramesToSteps(&status))!=0) {
+    fprintf(stderr, "failed (%d).\n", ret);
+    statusPrint(stderr, &status); statusFree(&status);
+    return(i);
+  }
+  i++; if((ret=test_tacIsXContiguous(&status))!=0) {
+    fprintf(stderr, "failed (%d).\n", ret);
+    statusPrint(stderr, &status); statusFree(&status);
+    return(i);
+  }
+  i++; if((ret=test_tacSetXContiguous(&status))!=0) {
+    fprintf(stderr, "failed (%d).\n", ret);
+    statusPrint(stderr, &status); statusFree(&status);
+    return(i);
+  }
   /* tacy */
   i++; if((ret=test_tacYRange(&status))!=0) {
     fprintf(stderr, "failed (%d).\n", ret);
