@@ -96,22 +96,22 @@ int tacWritePMOD(
   for(int fi=0, n=0; fi<tac->sampleNr; fi++) {
     /* Time(s) (x, x1, x2) */
     if(tac->isframe==0) v=tac->x[fi]; else v=tac->x1[fi];
-    if(isnan(v)) n=fprintf(fp, "."); else n=fprintf(fp, "%.5f", v);
+    if(!isfinite(v)) n=fprintf(fp, "."); else n=fprintf(fp, "%.5f", v);
     if(n<1) break;
     if(tac->isframe!=0) {
       v=tac->x2[fi];
-      if(isnan(v)) n=fprintf(fp, "\t."); else n=fprintf(fp, "\t%.5f", v);
+      if(!isfinite(v)) n=fprintf(fp, "\t."); else n=fprintf(fp, "\t%.5f", v);
       if(n<1) break;
     }
     /* Concentrations (y values) */
     for(int ri=0; ri<tac->tacNr; ri++) {
-      if(isnan(tac->c[ri].y[fi])) n=fprintf(fp, "\t.");
+      if(!isfinite(tac->c[ri].y[fi])) n=fprintf(fp, "\t.");
       else fprintf(fp, "\t%.*e", prec, tac->c[ri].y[fi]);
       if(n<1) break;
     }
     /* Weight */
     if(tacIsWeighted(tac)) {
-      if(isnan(tac->w[fi])) n=fprintf(fp, "\t.");
+      if(!isfinite(tac->w[fi])) n=fprintf(fp, "\t.");
       else n=fprintf(fp, "\t%.*e", prec, tac->w[fi]);
       if(n<1) break;
     }
@@ -258,7 +258,7 @@ int tacReadPMOD(
     if(csv->c[i].col<0) {ret++; continue;}
     ri=csv->c[i].col-1; if(tac->isframe) ri--; 
     if(ri>=tac->tacNr) {ret++; continue;}
-    v=atofVerified(csv->c[i].content); if(!isnan(v)) oknr++;
+    v=atofVerified(csv->c[i].content); if(isfinite(v)) oknr++;
     if(verbose>10) printf("   -> fi=%d\tri=%d\t=\t%g\n", fi, ri, v);
     if(ri<0) {
       if(tac->isframe) {
@@ -266,8 +266,7 @@ int tacReadPMOD(
       } else tac->x[fi]=v;
     } else tac->c[ri].y[fi]=v;
   }
-  if(verbose>0 && ret>0)
-    printf("%d error(s) in reading PMOD file format.\n", ret);
+  if(verbose>0 && ret>0) printf("%d error(s) in reading PMOD file format.\n", ret);
   if(oknr<1) {
     statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_INVALID_FORMAT);
     return TPCERROR_INVALID_FORMAT;
@@ -282,7 +281,7 @@ int tacReadPMOD(
   while(ci>0) {
     if(strlen(tac->c[ci].name)>0) break;
     int i;
-    for(i=0; i<tac->sampleNr; i++) if(!isnan(tac->c[ci].y[i])) break;
+    for(i=0; i<tac->sampleNr; i++) if(isfinite(tac->c[ci].y[i])) break;
     if(i<tac->sampleNr) break;
     tac->tacNr--; ci--;
   }
