@@ -330,8 +330,7 @@ int tacReadCSV(
   for(i=2; i<csv->nr; i++) if(csv->c[i].row==2) break;
   for(; i<csv->nr; i++) {
     if(verbose>10)
-      printf("i=%d\trow=%d\tcol=%d\t'%s'\n",
-             i, csv->c[i].row, csv->c[i].col, csv->c[i].content);
+      printf("i=%d\trow=%d\tcol=%d\t'%s'\n", i, csv->c[i].row, csv->c[i].col, csv->c[i].content);
     if(csv->c[i].col==0 && strcasecmp(csv->c[i].content, "volume")==0)
       break; // stop if VOI volume line is encountered
     fi=csv->c[i].row-2; if(fi<0 || fi>=tac->sampleNr) {ret++; continue;}
@@ -356,8 +355,7 @@ int tacReadCSV(
   }
   tac->sampleNr=maxfi+1;
   if(verbose>2) printf("  sampleNr=%d\n", tac->sampleNr);
-  if(verbose>0 && ret>0)
-    printf("%d error(s) in reading CSV file format.\n", ret);
+  if(verbose>0 && ret>0) printf("%d error(s) in reading CSV file format.\n", ret);
   if(oknr<1) {
     statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_INVALID_FORMAT);
     return TPCERROR_INVALID_FORMAT;
