@@ -27,7 +27,7 @@ int tacGetHeaderStudynr(
   /** Pointer to TAC header struct */
   IFT *h,
   /** Pointer to preallocated string of length MAX_STUDYNR_LEN+1 (at least);
-   *  enter NULL if you only want to test whether header contains studynr */
+      enter NULL if you only want to test whether header contains studynr */
   char *s,
   /** Pointer to status data; enter NULL if not needed */
   TPCSTATUS *status
