@@ -44,6 +44,7 @@ static const char *tac_format[] = {
   "Carimas-txt",        // TAC_FORMAT_CARIMAS_TXT
   "QView",              // TAC_FORMAT_QVIEW
   "Mat",                // TAC_FORMAT_MAT
+  "4DM",                // TAC_FORMAT_4DM
   "HRRT-HC",            // TAC_FORMAT_HRRT_HC
   "HRPLUS-HC",          // TAC_FORMAT_HRPLUS_HC
   "ABSS-Scanditronics", // TAC_FORMAT_ABSS_SCANDITRONICS
@@ -77,6 +78,7 @@ static const char *tac_fn_ext[] = {
   ".txt",    // TAC_FORMAT_CARIMAS_TXT
   ".csv",    // TAC_FORMAT_QVIEW
   ".mat",    // TAC_FORMAT_MAT
+  ".csv",    // TAC_FORMAT_4DM
   ".hc",     // TAC_FORMAT_HRRT_HC
   ".r",      // TAC_FORMAT_HRPLUS_HC
   ".lis",    // TAC_FORMAT_ABSS_SCANDITRONICS
@@ -163,6 +165,7 @@ int tacFormatDetermine(
   TPCSTATUS *status
 ) {
   int verbose=0; if(status!=NULL) verbose=status->verbose;
+
   if(fname==NULL || strlen(fname)<1) {
     statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_FAIL);
     return TAC_FORMAT_UNKNOWN;
@@ -226,6 +229,8 @@ int tacFormatDetermine(
     format=TAC_FORMAT_NCI;
   } else if(strcmp(line, "directory,file name,num,slice,mean,sd,cov,max,min,pixel,total,group")==0) {
     format=TAC_FORMAT_QVIEW;
+  } else if(strncmp(line, "PatientName,", 12)==0) {
+    format=TAC_FORMAT_4DM;
   } else if(strstr(line, " - Time")!=NULL && strstr(line, "(upper bound)")!=NULL &&
             strstr(line, "(lower bound)")!=NULL && strstr(line, "(standard deviation)")!=NULL) {
     format=TAC_FORMAT_INVEON;
@@ -492,6 +497,9 @@ int tacRead(
             strcasecmp(csv.c[10].content, "total")==0 &&
             strcasecmp(csv.c[11].content, "group")==0) {
     format=TAC_FORMAT_QVIEW;
+  } else if(csv.nr>10 && strcasecmp(csv.c[0].content, "PatientName")==0 &&
+            strcasecmp(csv.c[2].content, "Patient MRN")==0 ) {
+    format=TAC_FORMAT_4DM;
   } else if(csv.nr>5 && strstr(csv.c[0].content, " - Time")!=NULL &&
             strstr(csv.c[2].content, "(upper bound)")!=NULL &&
             strstr(csv.c[3].content, "(lower bound)")!=NULL &&
@@ -555,8 +563,7 @@ int tacRead(
     { 
       format=TAC_FORMAT_ABSS_ALLOGG;
     /* Try Scanditronics and GEMS ABSS */
-    } else if(iftSearchValue(&hdr, "AUX", 0)>=0 && iftSearchValue(&hdr, "1st detector pair", 0)>=0) 
-    {
+    } else if(iftSearchValue(&hdr, "AUX", 0)>=0 && iftSearchValue(&hdr, "1st detector pair", 0)>=0) {
       if(iftSearchValue(&hdr, "Scanditronics", 0)>=0)
         format=TAC_FORMAT_ABSS_SCANDITRONICS;
       else
@@ -564,8 +571,7 @@ int tacRead(
     } else if(iftFindKey(&hdr, "Discriminators", 0)>=0) { // Try old Allogg
       format=TAC_FORMAT_ABSS_ALLOGG_OLD;
     /* Try another Inveon format */
-    } else if(iftSearchValue(&hdr, "Subject Weight", 0)>=0 &&
-              iftSearchValue(&hdr, "Subject Sex", 0)>=0) {
+    } else if(iftSearchValue(&hdr, "Subject Weight", 0)>=0 && iftSearchValue(&hdr, "Subject Sex", 0)>=0) {
       format=TAC_FORMAT_INVEON;
     }
   }
@@ -611,25 +617,28 @@ int tacRead(
       fp=fopen(fname, "r");
       if(fp!=NULL) {iftRead(&hdr, fp, 0, 2, status); fclose(fp);}
       ret=tacReadSimple(d, &csv, &hdr, status);
-      break;   
+      break;
     case TAC_FORMAT_DFT:
       iftFree(&hdr);
       fp=fopen(fname, "r");
       if(fp!=NULL) {iftRead(&hdr, fp, 0, 2, status); fclose(fp);}
       ret=tacReadDFT(d, &csv, &hdr, status);
-      break;   
+      break;
     case TAC_FORMAT_PMOD:
       iftFree(&hdr);
       fp=fopen(fname, "r");
       if(fp!=NULL) {iftRead(&hdr, fp, 0, 2, status); fclose(fp);}
       ret=tacReadPMOD(d, &csv, &hdr, status);
-      break;   
+      break;
     case TAC_FORMAT_QVIEW:
       ret=tacReadQView(d, &csv, 0, status);
-      break;   
+      break;
     case TAC_FORMAT_MAT:
       ret=tacReadMat(d, &csv, status);
-      break;   
+      break;
+    case TAC_FORMAT_4DM:
+      ret=tacRead4DM(d, &csv, status);
+      break;
     case TAC_FORMAT_CSV_UK:
     case TAC_FORMAT_TSV_UK:
     case TAC_FORMAT_CSV_INT:
@@ -638,40 +647,40 @@ int tacRead(
       fp=fopen(fname, "r");
       if(fp!=NULL) {iftRead(&hdr, fp, 0, 2, status); fclose(fp);}
       ret=tacReadCSV(d, &csv, &hdr, status);
-      break;   
+      break;
     case TAC_FORMAT_CARIMAS_TXT:
       ret=tacReadCarimasTxt(d, &csv, status);
-      break;   
+      break;
     case TAC_FORMAT_INVEON:
       ret=tacReadInveonCSV(d, &csv, status);
-      break;   
+      break;
     case TAC_FORMAT_SIF:
       iftFree(&hdr);
       fp=fopen(fname, "r");
       if(fp!=NULL) {iftRead(&hdr, fp, 0, 2, status); fclose(fp);}
       ret=tacReadSIF(d, &csv, &hdr, status);
-      break;   
+      break;
     case TAC_FORMAT_HRRT_HC:
       ret=tacReadHRRTHC(d, &csv, status);
-      break;   
+      break;
     case TAC_FORMAT_HRPLUS_HC:
       ret=tacReadHRPLUSHC(d, &csv, status);
-      break;   
+      break;
     case TAC_FORMAT_ABSS_ALLOGG:
       //iftFree(&hdr);
       //fp=fopen(fname, "r");
       //if(fp!=NULL) {iftRead(&hdr, fp, 0, 1, status); fclose(fp);}
       ret=tacReadAllogg(d, &hdr, status);
-      break;   
+      break;
     case TAC_FORMAT_ABSS_ALLOGG_OLD:
       ret=tacReadOldAllogg(d, &hdr, status);
-      break;   
+      break;
     case TAC_FORMAT_ABSS_SCANDITRONICS:
       ret=tacReadScanditronics(d, &hdr, status);
-      break;   
+      break;
     case TAC_FORMAT_ABSS_GEMS:
       ret=tacReadGEMS(d, &hdr, status);
-      break;   
+      break;
     default:
     /* The rest of formats are not supported */
     if(verbose>0) printf("identified as %s file\n", tacFormattxt(format));
@@ -704,7 +713,8 @@ int tacRead(
     }
   }
   
-  return ret;
+  statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_OK);
+  return(TPCERROR_OK);
 }
 /*****************************************************************************/
 
