@@ -652,3 +652,32 @@ int create_tac2(
 /******************************************************************************/
 
 /******************************************************************************/
+/** Create test input TAC data */
+int create_inp1(
+  TAC *tac
+) {
+  int ret, fi, ri;
+  
+  /* Allocate memory */
+  ret=tacAllocate(tac, 4, 1); if(ret!=TPCERROR_OK) return ret;
+  tac->tacNr=1; tac->sampleNr=4;
+  /* Set TAC information */
+  tac->weighting=WEIGHTING_OFF;
+  tac->cunit=UNIT_KBQ_PER_ML;
+  tac->tunit=UNIT_MIN;
+  tac->isframe=1;
+  /* Set region names */
+  for(ri=0; ri<tac->tacNr; ri++) sprintf(tac->c[ri].name, "inp%d", 1+ri);
+  /* Set volumes */
+  for(ri=0; ri<tac->tacNr; ri++) tac->c[ri].size=(double)(100*(ri+1));
+  /* Set data contents */
+  ri=0;
+  fi=0; tac->x1[fi]=0.0; tac->x2[fi]=2.0;   tac->x[fi]=1.0;   tac->c[ri].y[fi]=0.0;
+  fi=1; tac->x1[fi]=2.0; tac->x2[fi]=4.0;   tac->x[fi]=3.0;   tac->c[ri].y[fi]=50.0;
+  fi=2; tac->x1[fi]=4.0; tac->x2[fi]=6.0;   tac->x[fi]=5.0;   tac->c[ri].y[fi]=0.0;
+  fi=3; tac->x1[fi]=6.0; tac->x2[fi]=194.0; tac->x[fi]=100.0; tac->c[ri].y[fi]=0.0;
+  return TPCERROR_OK;
+}
+/******************************************************************************/
+
+/******************************************************************************/
