@@ -1474,3 +1474,471 @@ int test_tacToBars(
 /*****************************************************************************/
 
 /*****************************************************************************/
+#if(1)
+int test_tacFramesToSteps(
+  TPCSTATUS *status
+) {
+  int verbose=0; if(status!=NULL) verbose=status->verbose;
+  statusSet(status, __func__, __FILE__, __LINE__, 0);
+  if(verbose>0) {
+    printf("\n=====================================\n");
+    printf("\n%s\n", __func__);
+    printf("\n=====================================\n");
+  }
+
+  int ret;
+
+  if(verbose>1) printf("\n testing with NULL data \n");
+  ret=tacFramesToSteps(NULL, NULL, NULL);
+  if(ret==TPCERROR_OK) return(1);
+
+  TAC tac1, tac2; tacInit(&tac1); tacInit(&tac2);
+
+  if(verbose>1) printf("\n testing with empty data \n");
+  ret=tacFramesToSteps(&tac1, &tac2, NULL);
+  if(ret==TPCERROR_OK) return(2);
+
+  if(verbose>1) printf("\n making test data \n");
+  if(create_inp1(&tac1)) {tacFree(&tac1); tacFree(&tac2); return(10);}
+
+  if(verbose>1) printf("\n original data has no frames\n");
+  tac1.isframe=0;
+  ret=tacFramesToSteps(&tac1, &tac2, NULL);
+  if(ret!=TPCERROR_OK) {tacFree(&tac1); tacFree(&tac2); return(11);}
+  ret=tacCompareTimes(&tac1, &tac2, 1.0E-20, 1.0E-20, NULL);
+  if(ret==0) tacCompareConc(&tac1, &tac2, -1, 1.0E-20, 1.0E-20, NULL);
+  if(ret!=0) {tacFree(&tac1); tacFree(&tac2); return(12);}
+
+  if(verbose>1) printf("\n original data has frames\n");
+  tac1.isframe=1;
+  if(verbose>2) {
+    printf("\ninput:\n");
+    tacWrite(&tac1, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
+  }
+  ret=tacFramesToSteps(&tac1, &tac2, NULL);
+  if(ret!=TPCERROR_OK) {tacFree(&tac1); tacFree(&tac2); return(21);}
+  if(verbose>2) {
+    printf("\noutput:\n");
+    tacWrite(&tac2, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
+  }
+  if(tac2.sampleNr!=7) {tacFree(&tac1); tacFree(&tac2); return(22);}
+  ret= !doubleMatch(tac2.x[0], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[1], 2.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[2], 2.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[3], 4.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[4], 4.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[5], 6.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[6], 194.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[0], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[1], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[2], 50.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[3], 50.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[4], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[5], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[6], 0.0, 1.0E-12);
+  if(ret!=0) {tacFree(&tac1); tacFree(&tac2); return(23);}
+
+  if(verbose>1) printf("\n original data has frame overlap\n");
+  tac1.isframe=1;
+  tac1.x2[0]=2.5; tac1.x1[1]=1.5;
+  if(verbose>2) {
+    printf("\ninput:\n");
+    tacWrite(&tac1, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
+  }
+  ret=tacFramesToSteps(&tac1, &tac2, NULL);
+  if(ret!=TPCERROR_OVERLAPPING_DATA) {tacFree(&tac1); tacFree(&tac2); return(31);}
+
+  if(verbose>1) printf("\n more than one TAC\n");
+  tacFree(&tac1); if(create_inp1(&tac1)) {tacFree(&tac1); tacFree(&tac2); return(100);}
+  if(tacAllocateMore(&tac1, 1)!=0) {tacFree(&tac1); tacFree(&tac2); return(100);}
+  for(int i=0; i<tac1.sampleNr; i++) tac1.c[1].y[i]=2.0*tac1.c[0].y[i];
+  tac1.tacNr=2;
+  if(verbose>2) {
+    printf("\ninput:\n");
+    tacWrite(&tac1, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
+  }
+  ret=tacFramesToSteps(&tac1, &tac2, NULL);
+  if(ret!=TPCERROR_OK) {tacFree(&tac1); tacFree(&tac2); return(101);}
+  if(verbose>2) {
+    printf("\noutput:\n");
+    tacWrite(&tac2, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
+  }
+  if(tac2.sampleNr!=7) {tacFree(&tac1); tacFree(&tac2); return(102);}
+  ret= !doubleMatch(tac2.x[0], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[1], 2.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[2], 2.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[3], 4.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[4], 4.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[5], 6.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[6], 194.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[0], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[1], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[2], 50.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[3], 50.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[4], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[5], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[6], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[1].y[0], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[1].y[1], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[1].y[2], 100.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[1].y[3], 100.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[1].y[4], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[1].y[5], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[1].y[6], 0.0, 1.0E-12);
+  if(ret!=0) {tacFree(&tac1); tacFree(&tac2); return(103);}
+
+
+  tacFree(&tac1); tacFree(&tac2);
+  statusSet(status, __func__, __FILE__, __LINE__, 0);
+  return(0);
+}
+#else
+int test_tacFramesToSteps(
+  TPCSTATUS *status
+) {
+  int verbose=0; if(status!=NULL) verbose=status->verbose;
+  statusSet(status, __func__, __FILE__, __LINE__, 0);
+  if(verbose>0) {
+    printf("\n=====================================\n");
+    printf("\n%s\n", __func__);
+    printf("\n=====================================\n");
+  }
+
+  int ret;
+
+  if(verbose>1) printf("\n testing with NULL data \n");
+  ret=tacFramesToSteps(NULL, NULL, NULL);
+  if(ret==TPCERROR_OK) return(1);
+
+  TAC tac1, tac2; tacInit(&tac1); tacInit(&tac2);
+
+  if(verbose>1) printf("\n testing with empty data \n");
+  ret=tacFramesToSteps(&tac1, &tac2, NULL);
+  if(ret==TPCERROR_OK) return(2);
+
+  if(verbose>1) printf("\n making test data \n");
+  if(create_inp1(&tac1)) {tacFree(&tac1); tacFree(&tac2); return(10);}
+
+  if(verbose>1) printf("\n original data has no frames\n");
+  tac1.isframe=0;
+  ret=tacFramesToSteps(&tac1, &tac2, NULL);
+  if(ret!=TPCERROR_OK) {tacFree(&tac1); tacFree(&tac2); return(11);}
+  ret=tacCompareTimes(&tac1, &tac2, 1.0E-20, 1.0E-20, NULL);
+  if(ret==0) tacCompareConc(&tac1, &tac2, -1, 1.0E-20, 1.0E-20, NULL);
+  if(ret!=0) {tacFree(&tac1); tacFree(&tac2); return(12);}
+
+  if(verbose>1) printf("\n original data has frames\n");
+  tac1.isframe=1;
+  if(verbose>2) {
+    printf("\ninput:\n");
+    tacWrite(&tac1, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
+  }
+  ret=tacFramesToSteps(&tac1, &tac2, NULL);
+  if(ret!=TPCERROR_OK) {tacFree(&tac1); tacFree(&tac2); return(21);}
+  if(verbose>2) {
+    printf("\noutput:\n");
+    tacWrite(&tac2, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
+  }
+  if(tac2.sampleNr!=8) {tacFree(&tac1); tacFree(&tac2); return(22);}
+  ret= !doubleMatch(tac2.x[0], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[1], 2.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[2], 2.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[3], 4.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[4], 4.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[5], 6.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[6], 6.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[7], 194.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[0], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[1], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[2], 50.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[3], 50.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[4], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[5], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[6], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[7], 0.0, 1.0E-12);
+  if(ret!=0) {tacFree(&tac1); tacFree(&tac2); return(23);}
+
+  if(verbose>1) printf("\n original data has small frame overlap\n");
+  tac1.isframe=1;
+  tac1.x2[0]=2.5; tac1.x1[1]=1.5;
+  if(verbose>2) {
+    printf("\ninput:\n");
+    tacWrite(&tac1, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
+  }
+  ret=tacFramesToSteps(&tac1, &tac2, NULL);
+  if(ret!=TPCERROR_OK) {tacFree(&tac1); tacFree(&tac2); return(31);}
+  if(verbose>2) {
+    printf("\noutput:\n");
+    tacWrite(&tac2, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
+  }
+  if(tac2.sampleNr!=8) {tacFree(&tac1); tacFree(&tac2); return(32);}
+  ret= !doubleMatch(tac2.x[0], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[1], 2.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[2], 2.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[3], 4.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[4], 4.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[5], 6.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[6], 6.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[7], 194.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[0], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[1], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[2], 50.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[3], 50.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[4], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[5], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[6], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[7], 0.0, 1.0E-12);
+  if(ret!=0) {tacFree(&tac1); tacFree(&tac2); return(33);}
+
+  if(verbose>1) printf("\n original data has large frame overlap\n");
+  tac1.isframe=1;
+  tac1.x1[0]=0.0; tac1.x2[0]=2.0; 
+  tac1.x1[1]=2.0; tac1.x2[1]=2.1; 
+  tac1.x1[2]=1.0;
+  if(verbose>2) {
+    printf("\ninput:\n");
+    tacWrite(&tac1, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
+  }
+  ret=tacFramesToSteps(&tac1, &tac2, NULL);
+  if(ret==TPCERROR_OK && verbose>2) {
+    printf("\noutput:\n");
+    tacWrite(&tac2, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
+  }
+  if(ret==TPCERROR_OK) {tacFree(&tac1); tacFree(&tac2); return(41);}
+
+
+  if(verbose>1) printf("\n original data has gaps\n");
+  tac1.isframe=1;
+  tac1.x1[0]=1.0;   tac1.x2[0]=2.0;
+  tac1.x1[1]=2.0;   tac1.x2[1]=4.0;
+  tac1.x1[2]=4.0;   tac1.x2[2]=6.0;
+  tac1.x1[3]=190.0; tac1.x2[3]=194.0;
+  if(verbose>2) {
+    printf("\ninput:\n");
+    tacWrite(&tac1, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
+  }
+  ret=tacFramesToSteps(&tac1, &tac2, NULL);
+  if(ret!=TPCERROR_OK) {tacFree(&tac1); tacFree(&tac2); return(51);}
+  if(verbose>2) {
+    printf("\noutput:\n");
+    tacWrite(&tac2, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
+  }
+  if(tac2.sampleNr!=9) {tacFree(&tac1); tacFree(&tac2); return(52);}
+  ret= !doubleMatch(tac2.x[0], 1.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[1], 1.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[2], 2.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[3], 2.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[4], 4.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[5], 4.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[6], 6.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[7], 190.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[8], 194.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[0], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[1], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[2], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[3], 50.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[4], 50.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[5], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[6], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[7], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[8], 0.0, 1.0E-12);
+  if(ret!=0) {tacFree(&tac1); tacFree(&tac2); return(53);}
+
+
+  if(verbose>1) printf("\n more than one TAC\n");
+  tacFree(&tac1); if(create_inp1(&tac1)) {tacFree(&tac1); tacFree(&tac2); return(100);}
+  if(tacAllocateMore(&tac1, 1)!=0) {tacFree(&tac1); tacFree(&tac2); return(100);}
+  for(int i=0; i<tac1.sampleNr; i++) tac1.c[1].y[i]=2.0*tac1.c[0].y[i];
+  tac1.tacNr=2;
+  if(verbose>2) {
+    printf("\ninput:\n");
+    tacWrite(&tac1, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
+  }
+  ret=tacFramesToSteps(&tac1, &tac2, NULL);
+  if(ret!=TPCERROR_OK) {tacFree(&tac1); tacFree(&tac2); return(101);}
+  if(verbose>2) {
+    printf("\noutput:\n");
+    tacWrite(&tac2, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
+  }
+  if(tac2.sampleNr!=8) {tacFree(&tac1); tacFree(&tac2); return(102);}
+  ret= !doubleMatch(tac2.x[0], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[1], 2.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[2], 2.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[3], 4.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[4], 4.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[5], 6.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[6], 6.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.x[7], 194.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[0], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[1], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[2], 50.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[3], 50.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[4], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[5], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[6], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[0].y[7], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[1].y[0], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[1].y[1], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[1].y[2], 100.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[1].y[3], 100.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[1].y[4], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[1].y[5], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[1].y[6], 0.0, 1.0E-12);
+  ret+=!doubleMatch(tac2.c[1].y[7], 0.0, 1.0E-12);
+  if(ret!=0) {tacFree(&tac1); tacFree(&tac2); return(103);}
+
+
+  tacFree(&tac1); tacFree(&tac2);
+  statusSet(status, __func__, __FILE__, __LINE__, 0);
+  return(0);
+}
+#endif
+/*****************************************************************************/
+
+/*****************************************************************************/
+int test_tacIsXContiguous(
+  TPCSTATUS *status
+) {
+  int verbose=0; if(status!=NULL) verbose=status->verbose;
+  statusSet(status, __func__, __FILE__, __LINE__, 0);
+  if(verbose>0) {
+    printf("\n=====================================\n");
+    printf("\n%s\n", __func__);
+    printf("\n=====================================\n");
+  }
+
+  if(verbose>1) printf("\n  mostly tested with application tacfcont\n");
+  int ret=0;
+
+  if(verbose>1) printf("\n testing with NULL data \n");
+  ret=tacIsXContiguous(NULL);
+  if(ret==TPCERROR_OK) return(1);
+
+  TAC tac; tacInit(&tac);
+
+  if(verbose>1) printf("\n testing with empty data \n");
+  ret=tacIsXContiguous(&tac);
+  if(ret==TPCERROR_OK) return(2);
+
+  if(verbose>1) printf("\n making test data \n");
+  if(create_inp1(&tac)) {tacFree(&tac); return(10);}
+
+  if(verbose>1) printf("\n data has no frames\n");
+  tac.isframe=0;
+  ret=tacIsXContiguous(&tac);
+  if(ret!=TPCERROR_OK) {tacFree(&tac); return(11);}
+
+  if(verbose>1) printf("\n data has frames\n");
+  tac.isframe=1;
+  ret=tacIsXContiguous(&tac);
+  if(ret!=TPCERROR_OK) {tacFree(&tac); return(12);}
+
+  if(verbose>1) printf("\n missing x value\n");
+  tac.x2[0]=nan("");
+  ret=tacIsXContiguous(&tac);
+  if(ret==TPCERROR_OK) {tacFree(&tac); return(13);}
+
+  if(verbose>1) printf("\n gap\n");
+  tac.x2[0]=tac.x[0];
+  ret=tacIsXContiguous(&tac);
+  if(ret!=TPCERROR_LARGE_GAP) {tacFree(&tac); return(14);}
+
+  if(verbose>1) printf("\n overlap\n");
+  tac.x2[0]=tac.x[1];
+  ret=tacIsXContiguous(&tac);
+  if(ret!=TPCERROR_OVERLAPPING_DATA) {tacFree(&tac); return(15);}
+
+  tacFree(&tac);
+  statusSet(status, __func__, __FILE__, __LINE__, 0);
+  return(0);
+}
+/*****************************************************************************/
+
+/*****************************************************************************/
+int test_tacSetXContiguous(
+  TPCSTATUS *status
+) {
+  int verbose=0; if(status!=NULL) verbose=status->verbose;
+  statusSet(status, __func__, __FILE__, __LINE__, 0);
+  if(verbose>0) {
+    printf("\n=====================================\n");
+    printf("\n%s\n", __func__);
+    printf("\n=====================================\n");
+  }
+
+  if(verbose>1) printf("\n  tested also with application tacfcont\n");
+  int ret=0;
+
+  if(verbose>1) printf("\n testing with NULL data \n");
+  ret=tacSetXContiguous(NULL);
+  if(ret==TPCERROR_OK) return(1);
+
+  TAC tac; tacInit(&tac);
+
+  if(verbose>1) printf("\n testing with empty data \n");
+  ret=tacSetXContiguous(&tac);
+  if(ret==TPCERROR_OK) return(2);
+
+  if(verbose>1) printf("\n making test data \n");
+  if(create_inp1(&tac)) {tacFree(&tac); return(10);}
+
+  if(verbose>1) printf("\n contiguous data with no frames\n");
+  tac.isframe=0;
+  ret=tacSetXContiguous(&tac);
+  if(ret!=TPCERROR_OK) {tacFree(&tac); return(11);}
+
+  if(verbose>1) printf("\n contiguous data with frames\n");
+  tac.isframe=1;
+  ret=tacSetXContiguous(&tac);
+  if(ret!=TPCERROR_OK) {tacFree(&tac); return(12);}
+
+  if(verbose>1) printf("\n making copy of test data \n");
+  TAC tac2; tacInit(&tac2);
+  if(tacDuplicate(&tac, &tac2)) {tacFree(&tac); return(20);}
+
+  if(verbose>1) printf("\n small gap should be fixed\n");
+  tac.x1[1]+=0.1*(tac.x2[1]-tac.x1[1]);
+  ret=tacSetXContiguous(&tac);
+  if(ret!=TPCERROR_OK) {tacFree(&tac); tacFree(&tac2); return(21);}
+  if(tacCompareTimes(&tac, &tac2, 1.0E-20, 1.0E-20, NULL) || tacCompareConc(&tac, &tac2, -1, 1.0E-20, 1.0E-20, NULL)) {
+    tacFree(&tac); tacFree(&tac2); return(22);}
+
+  if(verbose>1) printf("\n small overlap should be fixed\n");
+  tac.x2[1]+=0.1*(tac.x2[1]-tac.x1[1]);
+  ret=tacSetXContiguous(&tac);
+  if(ret!=TPCERROR_OK) {tacFree(&tac); tacFree(&tac2); return(23);}
+  if(tacCompareTimes(&tac, &tac2, 1.0E-20, 1.0E-20, NULL) || tacCompareConc(&tac, &tac2, -1, 1.0E-20, 1.0E-20, NULL)) {
+    tacFree(&tac); tacFree(&tac2); return(24);}
+
+  if(verbose>1) printf("\n large overlap should lead to an error\n");
+  tac.x2[1]+=0.5*(tac.x2[1]-tac.x1[1]);
+  ret=tacSetXContiguous(&tac);
+  if(ret!=TPCERROR_OVERLAPPING_DATA) {tacFree(&tac); tacFree(&tac2); return(25);}
+  tacFree(&tac); tacFree(&tac2);
+
+  if(verbose>1) printf("\n large gap is filled with new frame\n");
+  if(tacAllocate(&tac, 3, 2)!=TPCERROR_OK) return(30);
+  tac.tacNr=2; tac.sampleNr=3; tac.isframe=1;
+  tac.x1[0]=0.0;  tac.x2[0]=10.0;  tac.x[0]=5.0;  tac.c[0].y[0]=20.0; tac.c[1].y[0]=0.0;
+  tac.x1[1]=10.0; tac.x2[1]=60.0;  tac.x[1]=35.0; tac.c[0].y[1]=14.0; tac.c[1].y[1]=32.0;
+  tac.x1[2]=60.0; tac.x2[2]=100.0; tac.x[2]=80.0; tac.c[0].y[2]=5.0;  tac.c[1].y[2]=80.0;
+  if(tacDuplicate(&tac, &tac2)) {tacFree(&tac); return(31);}
+  if(tacDeleteSample(&tac, 1)) {tacFree(&tac); tacFree(&tac2); return(32);}
+  if(verbose>2) {
+    tacWritePMOD(&tac2, stdout, 0, NULL);
+    tacWritePMOD(&tac, stdout, 0, NULL);
+  }
+  ret=tacSetXContiguous(&tac);
+  if(ret!=TPCERROR_OK) {tacFree(&tac); tacFree(&tac2); return(33);}
+  if(tacCompareTimes(&tac, &tac2, 1.0E-20, 1.0E-20, NULL) || tacCompareConc(&tac, &tac2, -1, 1.0E-20, 1.0E-20, NULL)) {
+    tacWritePMOD(&tac, stdout, 0, NULL);
+    tacFree(&tac); tacFree(&tac2); return(34);
+  }
+
+  tacFree(&tac); tacFree(&tac2);
+  statusSet(status, __func__, __FILE__, __LINE__, 0);
+  return(0);
+}
+/*****************************************************************************/
+
+/*****************************************************************************/
