@@ -18,8 +18,55 @@
 /*****************************************************************************/
 
 /*****************************************************************************/
-/** @brief Interpolate and/or integrate TACs from one TAC struct into a new TAC struct, 
-    using sample times from another TAC struct which is not changed.
+/** @brief Integrate TACs from one TAC structure into a new TAC structure. 
+    @details PET frame lengths are taken into account, if available.
+    @sa liIntegrate, liIntegratePET, tacInterpolate, tacInterpolateInto
+    @return enum tpcerror (TPCERROR_OK when successful).
+    @author Vesa Oikonen
+ */ 
+int tacIntegrate(
+  /** Pointer to source TAC structure.
+      @pre Data must be sorted by increasing x. */
+  TAC *inp,
+  /** Pointer to target TAC structure into which the integrated TAC(s) are written.
+      Structure must be initiated; any previous contents are deleted. */
+  TAC *out,
+  /** Pointer to status data; enter NULL if not needed. */
+  TPCSTATUS *status
+) {
+  int verbose=0; if(status!=NULL) verbose=status->verbose;
+  if(verbose>0) printf("%s()\n", __func__);
+  if(inp==NULL || out==NULL) {
+    statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_FAIL);
+    return TPCERROR_FAIL;
+  }
+  tacFree(out);
+  int ret=TPCERROR_OK;
+  ret=tacDuplicate(inp, out);
+  if(ret!=TPCERROR_OK) {
+    statusSet(status, __func__, __FILE__, __LINE__, ret);
+    return(ret);
+  }
+  if(inp->isframe==0) {
+    for(int i=0; i<inp->tacNr; i++) {
+      ret=liIntegrate(inp->x, inp->c[i].y, inp->sampleNr, out->c[i].y, 3, 0);
+      if(ret!=TPCERROR_OK) break;
+    }
+  } else {
+    for(int i=0; i<inp->tacNr; i++) {
+      ret=liIntegratePET(inp->x1, inp->x2, inp->c[i].y, inp->sampleNr, out->c[i].y, NULL, 0);
+      if(ret!=TPCERROR_OK) break;
+    }
+  }
+  if(ret!=TPCERROR_OK) tacFree(out);
+  statusSet(status, __func__, __FILE__, __LINE__, ret);
+  return(ret);
+}
+/*****************************************************************************/
+
+/*****************************************************************************/
+/** @brief Interpolate and/or integrate TACs from one TAC structure into a new TAC structure, 
+    using sample times from another TAC structure which is not changed.
     @details PET frame lengths of output TACs are taken into account in interpolation, if available.
     Input frame lengths are taken into account if the framing is same as with output TACs, 
     otherwise frame middle times are used.
@@ -28,23 +75,24 @@
     @author Vesa Oikonen
  */ 
 int tacInterpolate(
-  /** Pointer to source TAC struct; make sure that x (time) and y (concentration) units are the same 
-      as in output TAC struct, because input time range is verified to cover the output data range. 
+  /** Pointer to source TAC structure; make sure that x (time) and y (concentration) units are 
+      the same as in output TAC structure, because input time range is verified to cover the output 
+      data range. 
       Detailed verification of suitability of TAC for interpolation must be done elsewhere.
       @pre Data must be sorted by increasing x. */
   TAC *inp,
-  /** Pointer to TAC struct which contains the x values (sample times) for the
-      interpolation and integration. Data in this TAC struct is not modified.
+  /** Pointer to TAC structure which contains the x values (sample times) for the
+      interpolation and integration. Data in this TAC structure is not modified.
       @pre Data must be sorted by increasing x. */
   TAC *xinp,
-  /** Pointer to target TAC struct into which the interpolated input TAC(s) are added.
-      Struct must be initiated; any previous contents are deleted. Enter NULL if not needed. */
+  /** Pointer to target TAC structure into which the interpolated input TAC(s) are added.
+      Structure must be initiated; any previous contents are deleted. Enter NULL if not needed. */
   TAC *tac,
-  /** Pointer to target TAC struct into which the integrated input TAC(s) are added.
-      Struct must be initiated; any previous contents are deleted. Enter NULL if not needed. */
+  /** Pointer to target TAC structure into which the integrated input TAC(s) are added.
+      Structure must be initiated; any previous contents are deleted. Enter NULL if not needed. */
   TAC *itac,
-  /** Pointer to target TAC struct into which 2nd integrals of input TAC(s) are added.
-      Struct must be initiated; any previous contents are deleted. Enter NULL if not needed. */
+  /** Pointer to target TAC structure into which 2nd integrals of input TAC(s) are added.
+      Structure must be initiated; any previous contents are deleted. Enter NULL if not needed. */
   TAC *iitac,
   /** Pointer to status data; enter NULL if not needed. */
   TPCSTATUS *status
@@ -74,9 +122,7 @@ int tacInterpolate(
 
   /* If input data have similar x values as requested already, then
      copy x1 and x2 into input if available */
-  if(xinp->isframe && tacXMatch(inp, xinp, verbose-2) &&
-     inp->sampleNr<=xinp->sampleNr)
-  {
+  if(xinp->isframe && tacXMatch(inp, xinp, verbose-2) && inp->sampleNr<=xinp->sampleNr) {
     for(int i=0; i<inp->sampleNr; i++) {
       inp->x[i]=xinp->x[i]; inp->x1[i]=xinp->x1[i]; inp->x2[i]=xinp->x2[i];
     }
@@ -92,8 +138,7 @@ int tacInterpolate(
       return TPCERROR_INVALID_X;
     }
     range2=end2-start2;
-    if(verbose>2) 
-      printf("time ranges: %g - %g vs %g - %g\n", start1, end1, start2, end2);
+    if(verbose>2) printf("time ranges: %g - %g vs %g - %g\n", start1, end1, start2, end2);
     if(start1>start2+0.2*range2 || end1<end2-0.3*range2) {
       statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_INVALID_XRANGE);
       return TPCERROR_INVALID_XRANGE;
@@ -147,7 +192,7 @@ int tacInterpolate(
 
   /* Check if TACs have the same frame times already */
   if(tacXMatch(inp, tac, verbose-2) && inp->sampleNr>=xinp->sampleNr) {
-    if(verbose>2) printf("same frame times\n");
+    if(verbose>2) printf("  same frame times\n");
     int ret=0, ri, fi;
     double *i1, *i2;
     /* copy the values directly and integrate in place, if requested */
@@ -180,6 +225,7 @@ int tacInterpolate(
 
   /* Interpolate and/or integrate inp data to tac sample times,
      taking into account tac frame lengths if available */
+  if(verbose>2) printf("  different frame times\n");
   ret=0;
   double *i0, *i1, *i2;
   for(int ri=0; ri<inp->tacNr && ret==0; ri++) {
@@ -208,8 +254,8 @@ int tacInterpolate(
 /*****************************************************************************/
 
 /*****************************************************************************/
-/** @brief Add TACs from one TAC struct into another TAC struct, interpolating the input TACs and 
-    allocating space if necessary.
+/** @brief Add TACs from one TAC structure into another TAC structure, interpolating the input TACs 
+    and allocating space if necessary.
     @details PET frame lengths of output TACs are taken into account in interpolation, if available.
     Input frame lengths are taken into account if the framing is same as with
     output TACs, otherwise frame middle times are used.
@@ -448,7 +494,7 @@ int tacInterpolateToEqualLengthFrames(
   /* Set X (sample time) information */
   tac->isframe=1;
   for(int i=0; i<nreq; i++) tac->x1[i]=(double)i*freq;
-  for(int i=0; i<nreq; i++) tac->x2[i]=tac->x1[i]+freq;
+  for(int i=0; i<nreq; i++) tac->x2[i]=(double)(i+1)*freq;
   for(int i=0; i<nreq; i++) tac->x[i]=0.5*(tac->x1[i]+tac->x2[i]);
 
   /* Calculate mean value during each interval */
@@ -468,91 +514,6 @@ int tacInterpolateToEqualLengthFrames(
 }
 /*****************************************************************************/
 
-/*****************************************************************************/
-/** @brief Transform TAC with frames into TAC with frames represented with
-           stepwise changing dot-to-dot data. 
-
-    @details Gaps are replaced with lines connecting the corners of frame rectangles.
-     Small frame overlaps are replaced by step at the midpoint of the overlap.
-    @sa tacInterpolate, tacToBars, tacInterpolateToEqualLengthFrames, liInterpolate
-    @return enum tpcerror (TPCERROR_OK when successful).
- */ 
-int tacFramesToSteps(
-  /** Pointer to source TAC struct.
-      @pre Data must be sorted by increasing x. */
-  TAC *inp,
-  /** Pointer to the initiated target TAC struct; any previous contents are deleted. */
-  TAC *out,
-  /** Pointer to status data; enter NULL if not needed. */
-  TPCSTATUS *status
-) {
-  int verbose=0; if(status!=NULL) verbose=status->verbose;
-  if(verbose>0) printf("%s()\n", __func__);
-  if(inp==NULL || out==NULL) {
-    statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_FAIL);
-    return TPCERROR_FAIL;
-  }
-  /* Check the function input */
-  if(inp->sampleNr<1 || inp->tacNr<1) {
-    statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_NO_DATA);
-    return TPCERROR_NO_DATA;
-  }
-
-  /* Check that input does not have any missing values */
-  if(tacNaNs(inp)>0) {
-    statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_MISSING_DATA);
-    return TPCERROR_MISSING_DATA;
-  } 
-
-  /* First, duplicate the TAC data */
-  if(tacDuplicate(inp, out)!=TPCERROR_OK) {
-    statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_FAIL);
-    return TPCERROR_FAIL;
-  }
-
-  /* Make sure that frame start and end times are present */
-  if(inp->isframe==0) return(TPCERROR_OK); // if not, consider that work is done
-
-  /* Add room for more frames */
-  if(tacAllocateMoreSamples(out, 1+2*out->sampleNr)!=0) {
-    tacFree(out);
-    statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_OUT_OF_MEMORY);
-    return TPCERROR_OUT_OF_MEMORY;
-  }
-
-  /* Make separate 'samples' for each frame start and end time */
-  out->isframe=0;
-  int fi=0, fj=0;
-  if(fabs(inp->x1[fi])>1.0E-20) { // add zero sample, if data does not already have it
-    out->x[fj]=inp->x1[fi];
-    for(int ri=0; ri<out->tacNr; ri++) out->c[ri].y[fj]=0.0;
-    fj++;
-  }
-  for(fi=0; fi<inp->sampleNr; fi++) {
-    if(fi>0 && inp->x1[fi]<inp->x2[fi-1]) { // overlap
-      double x=0.5*(inp->x1[fi]+inp->x2[fi-1]);
-      if(x<out->x[fj-2]) { // too large overlap
-        tacFree(out);
-        statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_OVERLAPPING_DATA);
-        return TPCERROR_OVERLAPPING_DATA;
-      }
-      out->x[fj-1]=out->x[fj]=x;
-    } else { // no overlap
-      out->x[fj]=inp->x1[fi];
-    }
-    for(int ri=0; ri<out->tacNr; ri++) out->c[ri].y[fj]=inp->c[ri].y[fi];
-    fj++;
-    out->x[fj]=inp->x2[fi];
-    for(int ri=0; ri<out->tacNr; ri++) out->c[ri].y[fj]=inp->c[ri].y[fi];
-    fj++;
-  }
-  out->sampleNr=fj;
-
-  statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_OK);
-  return(TPCERROR_OK);
-}
-/*****************************************************************************/
-
 /*****************************************************************************/
 /** @brief Move TAC y values (concentrations) in time, keeping sample times (x values) intact.
 
@@ -561,7 +522,8 @@ int tacFramesToSteps(
  */ 
 int tacDelay(
   /** Pointer to TAC structure.
-      @pre Data must be sorted by increasing x.
+      @pre Data must be sorted by increasing x. No gaps or overlap between frames allowed. 
+      @sa tacSortByTime, tacSetXContiguous
       @post Data y values are modified, x values will stay the same. */
   TAC *tac,
   /** Time (in TAC tunit's) to move the TAC forward (negative time moves TAC backward). */
@@ -664,7 +626,9 @@ int tacDelay(
  */ 
 double tacAUC(
   /** Pointer to TAC structure.
-      @pre Data must be sorted by increasing x. */
+      @pre Data must be sorted by increasing x. No gaps or overlap between frames allowed. 
+      @sa tacSortByTime, tacSetXContiguous
+   */
   TAC *tac,
   /** Index [0..tacNr-1] of the TAC to calculate AUC from. */
   int ti,
@@ -760,7 +724,7 @@ int tacVb(
       0 : Cpet = (1-Vb)*Ct + Vb*Cb, or
       1 : Cpet = Ct + Vb*Cb */
   const int petVolume,
-  /** Pointer to status data; enter NULL if not needed. */
+  /** Pointer to status data; obligatory. */
   TPCSTATUS *status
 ) {
   int verbose=0; if(status!=NULL) verbose=status->verbose;
