@@ -219,9 +219,9 @@ int main(int argc, char **argv)
     printf("ptacfile := %s\n", ptacfile);
     printf("ttacfile := %s\n", ttacfile);
     printf("resfile := %s\n", resfile);
-    printf("fitfile := %s\n", fitfile);
-    printf("svgfile := %s\n", svgfile);
-    printf("lpfile := %s\n", lpfile);
+    if(fitfile[0]) printf("fitfile := %s\n", fitfile);
+    if(svgfile[0]) printf("svgfile := %s\n", svgfile);
+    if(lpfile[0]) printf("lpfile := %s\n", lpfile);
     printf("model := %s\n", model_str[model]);
     printf("vb_model := %s\n", vb_model_str[vb_model]);
     printf("method := %s\n", method_str[method]);
@@ -299,6 +299,7 @@ int main(int argc, char **argv)
   TAC input0; tacInit(&input0); // interpolated PTAC
   TAC input1; tacInit(&input1); // 1st integral 
   TAC input2; tacInit(&input2); // 2nd integral
+  TAC input3; tacInit(&input3); // 3rd integral
   ret=tacInterpolate(&ptac, &ttac0, &input0, &input1, &input2, &status);
   if(ret!=TPCERROR_OK) {
     fprintf(stderr, "Error: %s\n", errorMsg(status.error));
@@ -306,7 +307,6 @@ int main(int argc, char **argv)
     tacFree(&input0); tacFree(&input1); tacFree(&input2);
     return(3);
   }
-  TAC input3; tacInit(&input3); // 3rd integral
   ret=tacDuplicate(&input2, &input3);
   if(ret==TPCERROR_OK)
     ret=liIntegrate(input2.x, input2.c[0].y, input2.sampleNr, input3.c[0].y, 3, 0);
@@ -319,17 +319,18 @@ int main(int argc, char **argv)
   /* Original PTAC should not be needed any more */
   tacFree(&ptac);
 
+
   /* Integrate TTAC */
   if(verbose>1) printf("integrating TTAC\n");
   TAC ttac1; tacInit(&ttac1); // 1st integral 
   TAC ttac2; tacInit(&ttac2); // 2nd integral
+  TAC ttac3; tacInit(&ttac3); // 3rd integral
   ret=tacInterpolate(&ttac0, &ttac0, NULL, &ttac1, &ttac2, &status);
   if(ret!=TPCERROR_OK) {
     fprintf(stderr, "Error: %s\n", errorMsg(status.error));
     tacFree(&ttac0);  tacFree(&ttac1);  tacFree(&ttac2);
     tacFree(&input0); tacFree(&input1); tacFree(&input2); tacFree(&input3);
   }
-  TAC ttac3; tacInit(&ttac3); // 3rd integral
   ret=tacDuplicate(&ttac2, &ttac3);
   if(ret==TPCERROR_OK) {
     for(int i=0; i<ttac2.tacNr; i++) {
