@@ -191,6 +191,13 @@ int main(int argc, char **argv)
       }
     }
     if(verbose>2) printf("res.voiNr := %d\n", res[vi].voiNr);
+    /* Make sure that TAC names do not need encoding in XML */
+    for(int i=0; i<res[vi].voiNr; i++) {
+      strCleanForXML(res[vi].voi[i].name);
+      strCleanForXML(res[vi].voi[i].voiname);
+      strCleanForXML(res[vi].voi[i].hemisphere);
+      strCleanForXML(res[vi].voi[i].place);
+    }
     /* sort rois */
     if(doMode!=1) resSortByName(res+vi);
     /* make sure that there are no duplicate rois */
@@ -277,8 +284,7 @@ int main(int argc, char **argv)
    */
   if(doMode==2) {
     if(resNr>=MAX_RESPARAMS-3) {
-      fprintf(stderr, "Error: too many result files; %d allowed.\n",
-              MAX_RESPARAMS);
+      fprintf(stderr, "Error: too many result files; %d allowed.\n", MAX_RESPARAMS);
       for(ri=0; ri<resNr; ri++) resEmpty(res+ri);
       return(1);
     }
@@ -428,10 +434,9 @@ int main(int argc, char **argv)
       strcpy(coll.voi[coll.voiNr-1].name, res[ri].studynr);
       /* set the calculation date */
       st=localtime(&res[ri].time);
-      if(st!=NULL) strftime(tmp, 256, "%Y-%m-%d", st);
-      else strcpy(tmp, "          ");
-      sprintf(coll.voi[coll.voiNr-1].voiname, "%6.6s", tmp);
-      sprintf(coll.voi[coll.voiNr-1].hemisphere, "%s", tmp+6);
+      if(st!=NULL) strftime(tmp, 256, "%Y-%m-%d", st); else strcpy(tmp, "          ");
+      strlcpy(coll.voi[coll.voiNr-1].voiname, tmp, 7);
+      strlcpy(coll.voi[coll.voiNr-1].hemisphere, tmp+6, 7);
       /* parameter values */
       for(pi=0; pi<res[ri].parNr; pi++)
         coll.voi[coll.voiNr-1].parameter[pi]=resvoi1->parameter[pi];
@@ -546,12 +551,12 @@ int main(int argc, char **argv)
 /*****************************************************************************/
 /** Get the next study region from a list of study results.
     This function depends on sw2 in result structures.
-\return Returns NULL in case of error, or if there are no more regions.
+    @return Returns NULL in case of error, or if there are no more regions.
  */
 ResVOI *resGetNextResVOI(
-  /** Input: pointer to the list of RES structs */
+  /** Input: pointer to the list of RES structures */
   RES *reslist,
-  /** Input: Nr of RES structs */
+  /** Input: Nr of RES structures */
   int resNr,
   /** Input: pointer to the last VOI */
   ResVOI *lastResVOI,
@@ -592,13 +597,12 @@ ResVOI *resGetNextResVOI(
 /*****************************************************************************/
 /** Tabulate the collected results of a single region.
     Calculates and tabulates also the statistics.
-\return Retuns zero if successful, otherwise non-zero.
+    @return Returns zero if successful, otherwise non-zero.
  */
 int rescoll_tabulate(
-  /** Pointer to an opened file, where XHTML headers etc have already
-      been written */
+  /** Pointer to an opened file, where XHTML headers etc have already been written */
   FILE *fp,
-  /** Pointer to the struct that contains the collected data */
+  /** Pointer to the structure that contains the collected data */
   RES *coll,
   /** Number of regions collected this far, including this one */
   int collNr
@@ -643,8 +647,9 @@ int rescoll_tabulate(
   fprintf(fp, "  <thead>\n");
 
   /* Write the region name */
-  fprintf(fp, "  <tr><th colspan=\"%d\">%s</th></tr>\n",
-    3+coll->parNr, coll->datafile);
+  fprintf(fp, "  <tr><th colspan=\"%d\">", 3+coll->parNr);
+  fprintf(fp, "%s", coll->datafile);
+  fprintf(fp, "</th></tr>\n");
 
   /* Write the titles */
   fprintf(fp, "  <tr>\n    <td>Nr</td><td>Study</td><td>Date</td>\n");
@@ -665,8 +670,7 @@ int rescoll_tabulate(
     fprintf(fp, "  <tr class=\"%s\">\n", tmp);
     fprintf(fp, "    <td>%-3d</td>\n", si+1);
     fprintf(fp, "    <td>%s</td>\n", coll->voi[si].name);
-    fprintf(fp, "    <td>%s%s</td>\n",
-      coll->voi[si].voiname,  coll->voi[si].hemisphere);
+    fprintf(fp, "    <td>%s%s</td>\n", coll->voi[si].voiname, coll->voi[si].hemisphere);
     for(pi=0; pi<coll->parNr; pi++) {
       if(coll->voi[si].parameter[pi]>=0) n=4; else n=3;
       switch(partype[pi]) {
