@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_tacweigh
-#: Date       : 2019-09-11
+#: Date       : 2022-03-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -74,7 +74,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
 printf "are there weights?\n"
-$PROGRAM -L temp1.dft > stdout.txt
+$PROGRAM -L -d3 temp1.dft > stdout.txt
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt contains_weights yes
