@@ -381,7 +381,7 @@ int main(int argc, char **argv)
       punit=par.n[i].unit;
       if(punit==UNIT_UNKNOWN) {
         double pmax=0.0; (void)parValueRange(&par, i, NULL, &pmax);
-        if(pmax>=1.0) punit=UNIT_PERCENTAGE; else punit=UNIT_UNITLESS;
+        if(pmax>1.0) punit=UNIT_PERCENTAGE; else punit=UNIT_UNITLESS;
       }
       if(punit==UNIT_PERCENTAGE) {
         if(verbose>1) printf("Note: converting Vb from percentage to fractions.\n");
@@ -540,7 +540,7 @@ int main(int argc, char **argv)
     if(k5==0.0) k6=0.0;
     if(isnan(Vb) || Vb==0.0) {Flow=fA=nan("");}
     if(isnan(Flow) || Flow==0.0 || isnan(fA) || fA==0.0 || fA==1.0) {Flow=fA=nan("");}
-    if(Vb<0.0 || Vb>=1.0) {
+    if(Vb<0.0 || Vb>1.0) {
       fprintf(stderr, "Error: invalid vascular volume.\n");
       tacFree(&sim); tacFree(&input); parFree(&par); return(5);
     }
@@ -617,7 +617,13 @@ int main(int argc, char **argv)
     if(isnan(k4)) k4=0.0;
     if(isnan(k5)) k5=0.0; 
     if(isnan(k6)) k6=0.0;
-    if(Vb>0.0) {
+    if(Vb==1.0) {
+      for(int i=0; i<sim.sampleNr; i++) ppet[i]=pby[i];
+      if(isnan(fA)) fA=1.0;
+      if(pcab!=NULL) for(int i=0; i<sim.sampleNr; i++) pcab[i]=fA*pby[i];
+      if(fA<1.0 && pcab!=NULL) for(int i=0; i<sim.sampleNr; i++) pcvb[i]=(1.0-fA)*pby[i];
+      ret=0;
+    } else if(Vb>0.0) {
       if(isnan(Flow)) Flow=0.0;
       if(isnan(fA)) fA=1.0;
       if(parallel==0)
