@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_simframe
-#: Date       : 2019-09-02
+#: Date       : 2023-03-19
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -39,7 +39,7 @@ if [ ! -f frames7.dat ] || [ ! -f frames7b.dat ] || [ ! -f frames7c.dat ]; then
   printf "Failed: required test data do not exist.\n"
   exit 1
 fi
-if [ ! -f frames3.sif ] || [ ! -f frames4.sif ]; then
+if [ ! -f frames.sif ] || [ ! -f frames3.sif ] || [ ! -f frames4.sif ]; then
   printf "Failed: required test data do not exist.\n"
   exit 1
 fi
@@ -55,6 +55,10 @@ if [ ! -f t01.dat ] || [ ! -f t11.dat ] || [ ! -f t21.dat ]; then
   printf "Failed: required test data do not exist.\n"
   exit 1
 fi
+if [ ! -f frames3_trailingspaces.sif ] || [ ! -f frames3_trailingspace.sif ] || [ ! -f frames3_tabs.sif ]; then
+  printf "Failed: required test data do not exist.\n"
+  exit 1
+fi
 
 
 
@@ -63,6 +67,7 @@ printf "testing %s\n" $PROGRAM
 printf "=====================================================================\n"
 
 
+
 printf "\n1.1.0 Unknown option\n\n"
 
 rm -f stdout.txt
@@ -351,6 +356,22 @@ tacmatch -abs=0.001 -x=y -y=y correct_6_1_1.dft output.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n"
 
+printf "\n 6.1.2 \n"
+printf " Test case: SIF contains isotope. Isotope not given on command line \n"
+printf " Expected result: Isotope not used but written in output file. \n\n"
+
+rm -f output.dat
+$PROGRAM t01.dat frames.sif output.dat
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+iftisval output.dat isotope C-11
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+tacmatch -abs=0.001 -x=y -y=y correct_6_1_1.dft output.dat
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n"
+
+
 
 printf "\n6.2.1 Another frame file with frame durations\n\n"
 
@@ -362,12 +383,18 @@ tacmatch -abs=0.001 -x=y -y=y correct_6_2_1.dft output.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n"
 
-printf "\n6.2.2 Another frame file with frame durations - with isotope\n\n"
+printf "\n 6.2.2 \n"
+printf " Test case: Another frame file with frame durations - with isotope\n"
+printf " Expected result 1: Output file contains isotope. \n"
+printf " Expected result 2: Correct results. \n\n"
 
 rm -f output.dat
 $PROGRAM t11.dat frames2.dat output.dat C-11
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
+iftisval output.dat isotope C-11
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
 # Note that decay correction of frames does not give exactly same result
 tacmatch -abs=1 -x=y -y=y correct_6_2_2.dft output.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -575,6 +602,46 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n"
 
 
+printf "\n===================================================================\n"
+
+
+
+printf "\n 8.0.0 \n"
+printf " Test case: SIF has no study number or isotope but space(s) instead. \n"
+printf " Expected result: works like without trailing spaces. \n\n"
+
+rm -f output.tac
+$PROGRAM t01.dat frames3_trailingspaces.sif output.tac
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+tacmatch -abs=0.001 -x=y -y=y correct_6_1_1.dft output.tac
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n"
+
+rm -f output.tac
+$PROGRAM t01.dat frames3_trailingspace.sif output.tac
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+tacmatch -abs=0.001 -x=y -y=y correct_6_1_1.dft output.tac
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n"
+
+
+printf "\n 8.0.1 \n"
+printf " Test case: SIF has normal title line with spaces but tabs in data rows. \n"
+printf " Expected result: works normally. \n\n"
+
+rm -f output.tac
+$PROGRAM t01.dat frames3_tabs.sif output.tac
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+tacmatch -abs=0.001 -x=y -y=y correct_6_1_1.dft output.tac
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n"
+
+
+
+
 printf "\n===================================================================\n"
 printf "   All passed! \n"
 printf "===================================================================\n"
