@@ -238,6 +238,11 @@ int main(int argc, char **argv)
   /* Sort data by sample time */
   tacSortByTime(&ttac, &status);
   tacSortByTime(&btac, &status);
+  /* Fix any gaps and overlap in data if possible and if not then quit with error */
+  if(tacSetXContiguous(&ttac) || tacSetXContiguous(&btac)) {
+    fprintf(stderr, "Error: invalid data sample times.\n");
+    tacFree(&ttac); tacFree(&ttac); return(2);
+  }
   /* Convert sample times into seconds */
   if(tacXUnitConvert(&ttac, UNIT_SEC, &status)!=TPCERROR_OK ||
      tacXUnitConvert(&btac, UNIT_SEC, &status)!=TPCERROR_OK) 
