@@ -82,7 +82,7 @@ static char *info[] = {
   "     Fitted and measured TACs are plotted in specified SVG file.",
   " -stdoptions", // List standard options like --help, -v, etc
   " ",
-  "See also: fit_sinf, fit_feng, fit_ratf, fit2dat, extrapol",
+  "See also: fit_sinf, fit_feng, fit_suri, fit_ratf, fit2dat, extrapol",
   " ",
   "Keywords: TAC, curve fitting",
   0};
