@@ -210,9 +210,8 @@ int main(int argc, char **argv)
       /* Error does not matter, if user told so */
       if(!checkUnits) ret=TPCERROR_OK;
       /* Neither does it matter if unitless, and multiplication or division */
-      if(tac2.cunit==UNIT_UNITLESS && (operation==3 || operation==4)) 
-        ret=TPCERROR_OK; 
-      /* If none of the previous excuses can be accepted, then exit */    
+      if(tac2.cunit==UNIT_UNITLESS && (operation==3 || operation==4)) ret=TPCERROR_OK; 
+      /* If none of the previous excuses can be accepted, then exit */
       if(ret!=TPCERROR_OK) {
         fprintf(stderr, "Error: %s.\n", errorMsg(status.error));
         tacFree(&tac1); tacFree(&tac2); return(3);
@@ -321,15 +320,26 @@ int main(int argc, char **argv)
             itac2.c[ri].y[fi]=tac2.c[ri].y[fi];
       } else {
         if(verbose>1) printf("interpolating\n");
+
+        /* Check the time range */
+        double xmin1, xmin2, xmax1, xmax2, xmin, xmax, xrange;
+        tacXRange(&tac1, &xmin1, &xmax1);
+        tacXRange(&tac2, &xmin2, &xmax2);
+        xmin=xmin1; if(xmin2<xmin) xmin=xmin2;
+        xmax=xmax1; if(xmax2>xmax) xmax=xmax2;
+        xrange=xmax-xmin;
+        if((xmin2>xmin1 && (xmin2-xmin1)/xrange>0.05) || (xmax2<xmax1 && (xmin1-xmax2)/xrange>0.10)) {
+          fprintf(stderr, "Warning: check the time ranges.\n");
+        }
+
+        /* Interpolate */
         for(ri=0, ret=0; ri<itac2.tacNr && ret==0; ri++) {
           if(itac2.isframe)
             ret=liInterpolateForPET(tac2.x, tac2.c[ri].y, tac2.sampleNr,
-                  itac2.x1, itac2.x2, itac2.c[ri].y, NULL, NULL, 
-                  itac2.sampleNr, 4, 1, verbose-6);
+                  itac2.x1, itac2.x2, itac2.c[ri].y, NULL, NULL, itac2.sampleNr, 4, 1, verbose-6);
           if(itac2.isframe==0 || ret!=0)
             ret=liInterpolate(tac2.x, tac2.c[ri].y, tac2.sampleNr,
-                  itac2.x, itac2.c[ri].y, NULL, NULL, 
-                  itac2.sampleNr, 4, 1, verbose-6);
+                  itac2.x, itac2.c[ri].y, NULL, NULL, itac2.sampleNr, 4, 1, verbose-6);
         }
         if(ret!=0) {
           fprintf(stderr, "Error: cannot interpolate TAC %d.\n", 1+ri);
@@ -392,8 +402,7 @@ int main(int argc, char **argv)
           y1=tac1.c[ri].y;
           if(itac2.tacNr==1) y2=itac2.c[0].y; else y2=itac2.c[ri].y;
           for(fi=0; fi<tac1.sampleNr; fi++)
-            if(!isnan(y1[fi]) && !isnan(y2[fi])) y1[fi]+=y2[fi];
-            else y1[fi]=nan("");
+            if(isfinite(y1[fi]) && isfinite(y2[fi])) y1[fi]+=y2[fi]; else y1[fi]=nan("");
         }
         break;
       case 2:  /* Subtract */
@@ -401,8 +410,7 @@ int main(int argc, char **argv)
           y1=tac1.c[ri].y;
           if(itac2.tacNr==1) y2=itac2.c[0].y; else y2=itac2.c[ri].y;
           for(fi=0; fi<tac1.sampleNr; fi++)
-            if(!isnan(y1[fi]) && !isnan(y2[fi])) y1[fi]-=y2[fi];
-            else y1[fi]=nan("");
+            if(isfinite(y1[fi]) && isfinite(y2[fi])) y1[fi]-=y2[fi]; else y1[fi]=nan("");
         }
         break;
       case 3:  /* Multiply */
@@ -410,8 +418,7 @@ int main(int argc, char **argv)
           y1=tac1.c[ri].y;
           if(itac2.tacNr==1) y2=itac2.c[0].y; else y2=itac2.c[ri].y;
           for(fi=0; fi<tac1.sampleNr; fi++)
-            if(!isnan(y1[fi]) && !isnan(y2[fi])) y1[fi]*=y2[fi];
-            else y1[fi]=nan("");
+            if(isfinite(y1[fi]) && isfinite(y2[fi])) y1[fi]*=y2[fi]; else y1[fi]=nan("");
         }
         break;
       case 4:  /* Divide */
@@ -419,7 +426,7 @@ int main(int argc, char **argv)
           y1=tac1.c[ri].y;
           if(itac2.tacNr==1) y2=itac2.c[0].y; else y2=itac2.c[ri].y;
           for(fi=0; fi<tac1.sampleNr; fi++) {
-            if(isnan(y1[fi]) || isnan(y2[fi])) {y1[fi]=nan(""); continue;}
+            if(!isfinite(y1[fi]) || !isfinite(y2[fi])) {y1[fi]=nan(""); continue;}
             if(fabs(y2[fi])<1.0E-12) y1[fi]=0.0; else y1[fi]/=y2[fi];
           }
         }
