@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_taccalc
-#: Date       : 2014-08-29
+#: Date       : 2023-04-18
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -226,12 +226,15 @@ printf "\n2.0.1\n"
 
 printf "\n Substract. Same TAC nr, different sample nr \n\n"
 
-rm -f output.dft
-$PROGRAM -d calc1.dft - calc2.dft output.dft
+rm -f output.dft stdout.txt
+$PROGRAM calc1.dft - calc2.dft output.dft &> stdout.txt
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "ok\n"
 tacmatch -abs=0.01 -rel=0.5 calc2a.dft output.dft
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "ok\n"
+iftisval stdout.txt Warning "check the time ranges."
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 printf "\n2.1.0\n"
