@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_taccat
-#: Date       : 2021-11-17
+#: Date       : 2022-03-15
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -446,7 +446,7 @@ printf " Expected result: Second dataset is converted to units of first dataset.
 
 cp -f test1b.tac temp1b.tac
 rm -f output.tac
-tacunit -xset=sec -yset=kBq/cc temp1b.tac
+tacunit -xconv=min -yconv=kBq/cc temp1b.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
